#!/usr/bin/env python
'''
If you use this package, please cite:
Horne, B. D., Nørregaard, J., & Adali, S. (2019).
Robust Fake News Detection Over Time and Attack.
ACM Transactions on Intelligent Systems and Technology (TIST), 11(1), 1-23.

If you use an older version, please cite:
Horne, B. D., Dron, W., Khedr, S., & Adali, S. (2018, April).
Assessing the news landscape: A multi-module toolkit for evaluating the credibility of news.
In Companion Proceedings of the The Web Conference 2018 (pp. 235-238).
'''

import os
import string, re
import math
from vaderSentiment.vaderSentiment import SentimentIntensityAnalyzer
from nltk import tokenize, word_tokenize, sent_tokenize, ne_chunk, pos_tag
from nltk.corpus import stopwords
from nltk.util import ngrams
from nltk.stem.porter import *
from nltk.tree import Tree
import collections
import datefinder

# ##Constants##
ACL13_DICT = {'bias_words': {'match', 'speed', 'illegal', 'bring', 'act', 'end', 'claim', 'range', 'best', 'group', 'assert', 'true', 'king', 'deny', 'day', 'affirm', 'steam', 'detail', 'school', 'report', 'root', 'separatist', 'bad', 'global', 'kingdom', 'palestinian', 'pro-life', 'south', 'sex', 'israel', 'genocide', 'allow', 'indian', 'individual', 'accusation', 'note', 'question', 'usa', 'confirm', 'debunk', 'hostile', 'refer', 'complex', 'improve', 'soviet', 'capture', 'modern', 'various', 'thought', 'clear', 'world', 'concept', 'disasterous', 'participation', 'impressive', 'occupy', 'mexican', 'radical', 'conclude', 'involve', 'criticism', 'part', 'demand', 'article', 'country', 'hindu', 'heart', 'sit', 'warming', 'restriction', 'correspondent', 'hand', 'excellent', 'serbian', 'increase', 'historically', 'war', 'variety', 'economic', 'indicate', 'happen', 'scandal', 'away', 'way', 'today', 'different', 'general', 'conservative', 'scholar', 'opponent', 'korean', 'communist', 'violate', 'later', 'controversial', 'tactic', 'refuse', 'specific', 'house', 'mother', 'research', 'historian', 'settlement', 'establish', 'minority', 'release', 'state', 'blame', 'institution', 'suggest', 'value', 'dispute', 'appear', 'notoriety', 'ethnic', 'explain', 'great', 'imposition', 'lie', 'regard', 'finding', 'seat', 'young', 'correct', 'popular', 'attempt', 'reputation', 'green', 'homeland', 'title', 'make', 'nineteenth', 'service', 'certain', 'apply', 'target', 'city', 'regardless', 'effort', 'document', 'expose', 's', 'persistent', 'wwius', 'law', 'effect', 'deal', 'earmark', 'far', 'russium', 'website', 'islamic', 'north', 'politician', 'lead', 'martyr', 'create', 'concern', 'larouche', 'best-selling', 'successful', 'jew', 'fanaticism', 'protestant', 'fan', 'invasion', 'return', 'example', 'building', 'speculate', 'allegedly', 'century', 'say', 'liberal', 'open', 'soldier', 'supporter', 'affair', 'warrior', 'response', 'international', 'abortion', 'word', 'common', 'point', 'america', 'marriage', 'region', 'run', 'fyrom', 'polish', 'western', 'japan', 'pirate', 'legalization', 'unfortunately', 'east', 'movement', 'award', 'refute', 'keep', 'essential', 'threat', 'distortion', 'alternative', 'sect', 'death', 'very', 'crowd', 'faith', 'allegation', 'meet', 'person', 'process', 'leader', 'former', 'need', 'take', 'usually', 'strident', 'thousand', 'area', 'control', 'population', 'fight', 'rate', 'see', 'write', 'insist', 'tax', 'migration', 'france', 'action', 'muhammad', 'content', 'convert', 'break', 'problem', 'murder', 'homosexuality', 'believe', 'notorious', 'original', 'separate', 'include', 'theory', 'islam', 'civilian', 'agree', 'yazid', 'reject', 'struggle', 'charge', 'people', 'disagree', 'source', 'bus', 'declare', 'exile', 'kill', 'abusive', 'so-called', 'important', 'peace', 'plan', 'hear', 'policy', 'sell', 'abuse', 'design', 'means', 'victim', 'japanese', 'lack', 'massacre', 'anti-semitism', 'nation', 'republic', 'amazing', 'traditionally', 'god', 'try', 'pat', 'shortcoming', 'imply', 'defender', 'regime', 'fighter', 'use', 'palestine', 'arab', 'ensure', 'idea', 'fascist', 'current', 'form', 'nationalist', 'obviously', 'small', 'party', 'vojvodina', 'saddam', 'follow', 'retaliation', 'colony', 'opposition', 'old', 'socialist', 'come', 'scrutiny', 'future', 'contradict', 'lose', 'researcher', 'serve', 'social', 'media', 'provide', 'tiny', 'corruption', 'order', 'survivor', 'addition', 'respect', 'monarchy', 'label', 'term', 'west', 'church', 'christian', 'critic', 'adhere', 'citizen', 'time', 'purported', 'bombing', 'pbuh', 'denomination', 'begin', 'new', 'consider', 'pressure', 'cleanse', 'democratic', 'impose', 'defend', 'investigation', 'advocate', 'legend', 'business', 'place', 'kke', 'china', 'strongly', 'challenge', 'indium', 'internationally', 'fake', 'study', 'behavior', 'estimate', 'clearly', 'thing', 'technique', 'long', 'myth', 'natural', 'instance', 'controversy', 'print', 'race', 'neighborhood', 'propaganda', 'acknowledge', 'rule', 'winner', 'cost', 'independent', 'ireland', 'yahweh', 'defense', 'formation', 'justice', 'hope', 'standard', 'instead', 'leftist', 'light', 'legitimate', 'number', 'prejudice', 'early', 'start', 'forum', 'racist', 'american', 'criminal', 'unborn', 'irish', 'experience', 'criticize', 'influence', 'participate', 'violent', 'cornerstone', 'system', 'base', 'personal', 'supremacist', 'national', 'man', 'work', 'chauvenistic', 'bestiality', 'mock', 'protect', 'force', 'community', 'ideology', 'prishtina', 'militant', 'barbarian', 'recently', 'authority', 'event', 'reform', 'independence', 'reach', 'vietnam', 'live', 'allege', 'muslim', 'evacuation', 'club', 'prompt', 'same-sex', 'homosexual', 'cite', 'liberation', 'life', 'right', 'historic', 'obama', 'hold', 'help', 'branch', 'currently', 'destructive', 'moscow', 'military', 'reveal', 'pass', 'intervention', 'culture', 'exist', 'feature', 'account', 'maintain', 'government', 'buy', 'resort', 'attack', 'status', 'failure', 'piracy', 'dictator', 'launch', 'inappropriate', 'powerful', 'revival', 'betrayal', 'enemy', 'majority', 'image', 'british', 'promote', 'oppose', 'call', 'goal', 'freedom', 'subject', 'member', 'author', 'mercenary', 'result', 'free', 'year', 'aggression', 'involvement', 'thinker', 'lawyer', 'occur', 'rights', 'extremist', 'know', 'recognize', 'threaten', 'second', 'focus', 'st', 'historical', 'vietnamese', 'seem', 'possibility', 'poor', 'right-wing', 'woman', 'persecution', 'issue', 'commentator', 'characterize', 'terrorism', 'expulsion', 'religion', 'suspect', 'present', 'fact', 'name', 'drop', 'macedonian', 'operation', 'show', 'condemn', 'perceive', 'remark', 'post', 'monk', 'text', 'army', 'riot', 'territory', 'baby', 'traditional', 'undocumented', 'bear', 'despite', 'prove', 'victory', 'aim', 'biblical', 'relation', 'development', 'advance', 'bishop', 'organization', 'close', 'case', 'collapse', 'positive', 'invade', 'news', 'cult', 'profile', 'widely', 'political', 'relationship', 'saw', 'white', 'execute', 'tell', 'main', 'catholic', 'gay', 'religious', 'find', 'identity', 'vast', 'left-wing', 'terrorist', 'record', 'accept', 'win', 'march', 'wing', 'literally', 'little', 'reaction', 'quality', 'left', 'honor', 'style', 'famous', 'tormentor', 'anti-terrorist', 'annex', 'book', 'commence', 'film', 'demonstrate', 'violence', 'crime', 'land', 'suppose', 'conspiracy', 'mosque', 'wage', 'dynasty', 'child', 'sexual', 'human', 'reason', 'belief', 'exodus', 'extermination', 'total', 'view', 'journal', 'apologetic', 'united', 'hijack', 'zionist', 'large', 'theorist', 'sign', 'misuse', 'admit', 'summer', 'twentieth', 'immigrant', 'hero', 'occupation', 'change', 'prisoner', 'accuse', 'remove', 'university', 'rebel', 'communal', 'history', 'define', 'prophet', 'mr', 'friend', 'function', 'condition', 'argue', 'society', 'creation', 'escape', 'liberate', 'support', 'province', 'croatium', 'similarly', 'intervene', 'comment', 'vote', 'attribute', 'revolution', 'bank', 'far-right', 'good', 'identify', 'mean'}, 'assertatives': {'hypothesize', 'intimate', 'theorize', 'guess', 'indicate', 'verify', 'remark', 'explain', 'admit', 'estimate', 'clear', 'postulate', 'suspect', 'grant', 'claim', 'sure', 'decide', 'figure', 'divulge', 'reply', 'expect', 'surmise', 'assert', 'believe', 'mention', 'acknowledge', 'affirm', 'emphasize', 'obvious', 'seem', 'evident', 'think', 'argue', 'guarantee', 'imply', 'maintain', 'agree', 'afraid', 'certain', 'say', 'charge', 'report', 'predict', 'vow', 'answer', 'point out', 'certify', 'suppose', 'hint', 'hope', 'testify', 'imagine', 'presume', 'prophesy', 'calculate', 'declare', 'state', 'deduce', 'assure', 'swear', 'contend', 'write', 'allege', 'suggest', 'insist', 'appear'}, 'factives': {'observe', 'bother', 'odd', 'forget', 'perceive', 'resent', 'find out', 'exciting', 'recall', 'remember', 'regret', 'know', 'realize', 'strange', 'amuse', 'reveal', 'notice', 'interesting', 'suffice', 'sorry', 'care', 'relevant', 'learn', 'discover', 'note', 'make sense', 'see'}, 'hedges': {'', 'argues', 'generally', 'probably', 'postulate', 'indicates', 'quite', 'claim', 'frequently', 'fairly', 'might', 'somewhat', 'indicated', 'likely', 'presumably', 'in my view', 'largely', 'from this perspective', 'mainly', 'from our perspective', 'may', 'possibly', 'in general', 'relatively', 'broadly', 'supposed', 'seems', 'postulates', 'assumed', 'unclear', 'suggested', 'suspect', 'should', 'in our view', 'roughly', 'suggests', 'estimate', 'plausibly', 'perhaps', 'felt', 'ought', 'typically', 'claims', 'estimated', '# Continuum, London and New York.', 'feels', 'doubtful', 'apparent', 'tended to', 'in our opinion', 'probable', 'usually', 'supposes', 'could', 'mostly', 'doubt', 'guess', 'indicate', 'to my knowledge', 'approximately', 'claimed', 'plausible', 'tends to', 'would', 'typical', 'certain level', 'often', 'suppose', 'in this view', 'in my opinion', 'in most instances', '# List of hedges', 'assume', '# Ken Hyland. 2005. Metadiscourse: Exploring Interaction in Writing.', 'suggest', 'in most cases', 'appear', 'unclearly', 'suspects', 'maybe', '#########################################################################', 'about', 'presumable', 'certain amount', 'certain extent', 'appeared', 'appears', 'essentially', 'on the whole', 'feel', 'argue', '# extracted from:', 'unlikely', 'sometimes', 'from my perspective', 'tend to', 'rather', 'uncertainly', 'apparently', "couldn't", 'almost', 'postulated', 'argued', 'uncertain', 'around', 'possible'}, 'implicatives': {'able', 'fit', 'bother', 'get', 'succeed', 'dare', 'forget', 'happen', 'remember', 'fail', 'misfortune', 'attempt', 'condescend', 'force', 'hesitate', 'keep', 'preclude', 'manage', 'care', 'refrain', 'neglect', 'choose', 'deign', 'venture', 'prevent', 'allow', 'cause', 'avoid', 'sense', 'careful', 'decline', 'can'}, 'report_verbs': {'boast', 'protest', 'contradict', 'interview', 'instruct', 'warn', 'announce', 'remember', 'slam', 'order', 'claim', 'beg', 'decide', 'negotiate', 'threaten', 'assert', 'deny', 'mention', 'praise', 'encourage', 'caution', 'speculate', 'wonder', 'teach', 'say', 'urge', 'report', 'debate', 'hint', 'repeat', 'issue', 'defend', 'note', 'gather', 'persuade', 'question', 'confirm', 'convey', 'suspect', 'present', 'refer', 'sing', 'request', 'show', 'disclose', 'forget', 'point', 'remark', 'estimate', 'restate', 'spread', 'concede', 'prove', 'endorse', 'respond', 'refute', 'acknowledge', 'propose', 'underline', 'conclude', 'complain', 'rule', 'underscore', 'interpret', 'counter', 'demand', 'congratulate', 'invite', 'predict', 'answer', 'raise', 'add', 'quote', 'promise', 'hope', 'discover', 'equate', 'insert', 'ask', 'reiterate', 'voice', 'write', 'see', 'doubt', 'insist', 'observe', 'tell', 'guess', 'stress', 'indicate', 'command', 'find', 'pray', 'rally', 'criticize', 'rebut', 'illustrate', 'surmise', 'expect', 'alert', 'emphasize', 'signal', 'compare', 'agree', 'offer', 'reject', 'disregard', 'charge', 'forbid', 'vow', 'demonstrate', 'discount', 'discuss', 'point out', 'refuse', 'suppose', 'disagree', 'determine', 'declare', 'inform', 'state', 'blame', 'extoll', 'prefer', 'relate', 'realise', 'assure', 'dismiss', 'swear', 'allege', 'suggest', 'worry', 'forecast', 'dispute', 'contend', 'uncover', 'describe', 'prompt', 'reaffirm', 'recommend', 'hear', 'cite', 'explain', 'admit', 'spoke', 'recall', 'pledge', 'remind', 'accuse', 'apologize', 'foretell', 'realize', 'wish', 'reply', 'advise', 'fear', 'reveal', 'clarify', 'feel', 'argue', 'guarantee', 'imply', 'maintain', 'think', 'express', 'support', 'told', 'reflect', 'learn', 'read', 'confront', 'welcome', 'provoke', 'testify', 'imagine', 'comment', 'stipulate', 'oppose', 'reckon', 'justify', 'mean'}, 'positive': {'hallowed', 'terrifically', 'adoringly', 'renowned', 'fastest', 'ovation', 'effusion', 'resilient', 'superbly', 'excellant', 'generously', 'rational', 'best', 'redeeming', 'gorgeously', 'pinnacle', 'steadfast', 'toughest', 'lovable', 'unselfish', 'hearten', 'productive', 'miracle', 'refreshed', 'wonderful', 'master', 'edify', 'endorsing', 'revolutionize', 'reassure', 'affection', 'advocates', 'convienient', 'tempting', 'rapturously', 'revitalize', 'astutely', 'mesmerize', 'revere', 'nifty', 'glitz', 'exceptional', 'amazement', 'meticulous', 'innovative', 'merit', 'trusting', 'cleanly', 'adaptive', 'grateful', 'charmingly', 'famously', 'enrich', 'adulation', 'charming', 'lovely', 'variety', 'appealing', 'beneficent', 'overtakes', 'fav', 'cooperative', 'marvel', 'altruistically', 'capability', 'improved', 'poignant', 'well-known', 'enough', 'maturity', 'suavely', 'plentiful', 'irreplaceable', 'easiest', 'fecilitous', 'luxurious', 'empathize', 'diplomatic', 'pluses', 'romantically', 'admirable', 'excellently', 'chivalry', 'trustingly', 'ftw', 'courageously', 'rectify', 'fantastic', 'compatible', 'entertain', 'affability', 'constructive', 'exultant', 'handsome', 'masterpiece', 'resounding', 'radiant', 'believeable', 'incredible', 'intriguing', 'headway', 'uplift', 'reputation', 'enhances', 'mercifully', 'helping', 'positives', 'promising', 'reward', 'afford', 'fresher', 'energize', 'freed', 'intriguingly', 'reputable', 'lucidly', 'rosy', 'beckons', 'law-abiding', 'lavishly', 'dreamland', 'thoughtfully', 'valuable', 'noble', 'paradise', 'articulate', 'rapport', 'expansive', 'heartening', 'relaxed', 'upgraded', 'awesomely', 'deginified', 'swift', 'elite', 'unreal', 'unbiased', 'versatility', 'boost', 'heartfelt', 'intimacy', 'stellar', 'refunded', 'slammin', 'warmer', 'toll-free', 'inspire', 'glamorous', 'handsomely', 'rectifying', 'audible', 'comprehensive', 'exalted', 'skillful', 'trusted', 'gain', 'greatness', 'praiseworthy', 'prefered', 'glow', 'favorable', 'fervidly', 'harmoniously', 'substantive', 'pardon', 'overjoyed', 'loyalty', 'adore', 'supple', 'beneficially', 'civilize', 'magnanimously', 'distinguished', 'steadfastness', 'comforting', 'shimmering', 'willingly', 'gladly', 'realistic', 'unequivocal', 'prudent', 'prettily', 'hail', 'tops', 'won', 'painless', 'enhanced', 'agilely', 'marvellous', 'benevolent', 'high-spirited', 'outdo', 'subsidizes', 'god-send', 'invigorate', 'graceful', 'reaffirm', 'godsend', 'exhilarate', 'humble', 'venerate', 'nicer', 'dedicated', 'productively', 'doubtless', 'unaffected', 'prodigy', 'exaltation', 'delightfully', 'neatly', 'refund', 'sophisticated', 'tolerable', 'effortlessly', 'amazing', 'ebulliently', 'dignify', 'flatteringly', 'famed', 'stylized', 'ameliorate', 'beautiful', 'awsome', 'inspiring', 'jovial', 'easy', 'fortunately', 'fastest-growing', 'rapid', 'extol', 'comfy', 'durable', 'premier', 'proves', 'geekier', 'well-run', 'eventful', 'glowing', 'surpass', 'undisputable', 'trendy', 'plusses', 'low-price', 'achievible', 'pleasantly', 'renaissance', 'survivor', 'respect', 'saintly', 'compact', 'sensible', 'assurance', 'gorgeous', 'gallantly', 'beautifully', 'dependably', 'gusto', 'pampered', 'vivid', 'eyecatching', 'perseverance', 'safely', 'undamaged', 'smartly', 'hardy', 'gold', 'civility', 'kindness', 'commodious', 'effusive', 'straighten', 'evenly', 'passionately', 'eloquent', 'ease', 'dexterous', 'supreme', 'keenly', 'delightfulness', 'inpressed', 'problem-solver', 'unconditional', 'dawn', 'enjoying', 'sane', 'winner', 'navigable', 'excitedness', 'smart', 'beutifully', 'beckon', 'insightful', 'promise', 'luckiest', 'adoring', 'congratulation', 'flawless', 'humorously', 'meaningful', 'sparkle', 'raptureously', 'rapt', 'lively', 'well-rounded', 'gracious', 'scenic', 'tantalizing', 'mesmerized', 'hotcakes', 'straightforward', 'mastery', 'titillatingly', 'rightfully', 'cornerstone', 'solidarity', 'earnestness', 'well-connected', 'greatest', 'protect', 'nurturing', 'significant', 'enviousness', 'beneficiary', 'sturdier', 'enterprising', 'succeeds', 'tranquility', 'worthiness', 'sagacity', 'immaculate', 'worthwhile', 'conciliate', 'hopeful', 'charm', 'sweetly', 'affluence', 'trump', 'phenomenally', 'sparkling', 'thrill', 'resourceful', 'roomier', 'unfettered', 'right', 'stupendously', 'brighten', 'inspirational', 'eminent', 'amuse', 'keenness', 'rich', 'accomplishments', 'saver', 'irresistible', 'harmless', 'solid', 'leverage', 'guarantee', 'rewarding', 'danken', 'enrichment', 'elated', 'properly', 'reverent', 'subsidize', 'pleased', 'soft', 'outshone', 'triumphal', 'sweetheart', 'agreeably', 'gratify', 'astonishingly', 'unbeatable', 'fiery', 'remarkable', 'righteousness', 'led', 'grandeur', 'opulent', 'unquestionably', 'convenience', 'timely', 'super', 'precious', 'spellbound', 'luminous', 'foresight', 'entranced', 'dead-on', 'celebratory', 'lover', 'solicitous', 'endearing', 'outshine', 'state-of-the-art', 'chivalrous', 'fancy', 'simplifying', 'benefits', 'heroic', 'innovation', 'nicely', 'reaffirmation', 'stable', 'keen', 'rejuvenating', 'exhilaratingly', 'correctly', 'satisfactory', 'mesmerizing', 'razor-sharp', 'wondrous', 'useful', 'fascination', 'positive', 'amicable', 'subsidized', 'unbound', 'fancinating', 'generosity', 'breeze', 'overture', 'expeditiously', 'reclaim', 'loved', 'non-violence', 'vouch', 'indulgent', 'low-priced', 'reconciliation', 'eases', 'admirably', 'diligently', 'outperform', 'fearlessly', 'affirmation', 'feisty', 'engaging', 'marvels', 'captivate', 'effortless', 'enhancement', 'softer', 'precisely', 'posh', 'outstanding', 'improvements', 'sustainable', 'felicity', 'boom', 'fervent', 'wellbeing', 'earnest', 'pure', 'recommended', 'plush', 'champ', 'prestigious', 'backbone', 'coolest', 'likable', 'compassionate', 'finest', 'sociable', 'recommend', 'admirer', 'miraculous', 'convenient', 'equitable', 'enviable', 'endorses', 'humor', 'captivating', 'bless', 'favored', 'wholeheartedly', 'fascinating', 'respectable', 'amicably', 'enviably', 'favorited', 'brilliant', 'relish', 'geeky', 'unquestionable', 'talented', 'enlightenment', 'divine', 'matchless', 'ingeniously', 'worth-while', 'easier', 'tremendously', 'admire', 'applaud', 'mature', 'excitement', 'recommendation', 'user-friendly', 'optimistic', 'truthful', 'exuberant', 'relent', 'privileged', 'finer', 'flutter', 'accolades', 'exquisitely', 'spellbindingly', 'detachable', 'excallent', 'adequate', 'splendor', 'zest', 'eloquence', 'dazzling', 'regally', 'uplifting', 'enchant', 'acclamation', 'bargain', 'feature-rich', 'a+', 'raptureous', 'ingenuously', 'decisiveness', 'fervid', 'enjoyably', 'nourishing', 'purify', 'praising', 'unabashedly', 'improve', 'avidly', 'triumphantly', 'illuminati', 'aver', 'fairness', 'affable', 'windfall', 'cheery', 'examplar', 'genuine', 'impressive', 'dumbfounding', 'simplest', 'alluring', 'success', 'guiltless', 'well-wishers', 'suffice', 'delicacy', 'revolutionizes', 'honored', 'encouragingly', 'intricate', 'kudos', 'heavenly', 'proving', 'obsessions', 'fearless', 'world-famous', 'flawlessly', 'willingness', 'gratefully', 'crisper', 'silent', 'legendary', 'responsibly', 'enhance', 'amaze', 'liked', 'available', 'love', 'tenacious', 'conveniently', 'suave', 'portable', 'cohesive', 'exhilarating', 'trustworthy', 'energetic', 'thrills', 'wieldy', 'perfection', 'comfortably', 'advantages', 'attractively', 'elegance', 'protection', 'friendliness', 'remedy', 'refresh', 'appreciate', 'accomodative', 'hotcake', 'user-replaceable', 'beautify', 'elan', 'hospitable', 'pleasure', 'extoll', 'thrilled', 'infallibly', 'poised', 'favorite', 'reasonably', 'infallible', 'clearer', 'engrossing', 'favor', 'humourous', 'fond', 'deservedly', 'excited', 'simplify', 'laud', 'successes', 'outstrip', 'ingenuous', 'futurestic', 'relief', 'ecstasy', 'stately', 'individualized', 'euphoria', 'strikingly', 'courageous', 'optimal', 'dirt-cheap', 'comfortable', 'savvy', 'hard-working', 'whooa', 'well-positioned', 'acclaim', 'futuristic', 'excellence', 'clean', 'loving', 'obsession', 'dexterously', 'prosper', 'efficiently', 'amiable', 'imaginative', 'sumptuous', 'best-selling', 'angel', 'high-quality', 'astounding', 'transparent', 'fantastically', 'principled', 'mercy', 'assuredly', 'upheld', 'eye-catching', 'ebullience', 'modest', 'resplendent', 'sufficient', 'entertains', 'well', 'cuteness', 'striving', 'unrestricted', 'masters', 'lush', 'bullish', 'thrift', 'talent', 'peach', 'achievable', 'stunningly', 'invincibility', 'instrumental', 'daringly', 'jubilation', 'enthral', 'deft', 'successfully', 'fabulously', 'reasoned', 'gutsy', 'enrapt', 'brilliantly', 'prefers', 'clarity', 'liking', 'affluent', 'splendid', 'counter-attacks', 'suitable', 'stylish', 'beckoned', 'well-established', 'wealthy', 'soulful', 'astounded', 'smoother', 'sleek', 'brilliance', 'danke', 'cure-all', 'judicious', 'fair', 'top-quality', 'prodigious', 'agility', 'gleeful', 'pep', 'stylishly', 'agreeableness', 'advantageous', 'important', 'luckier', 'dominate', 'upbeat', 'succeed', 'trivially', 'remunerate', 'complemented', 'refreshing', 'outperformed', 'fine', 'consistently', 'simplifies', 'ecenomical', 'luster', 'illuminate', 'lionhearted', 'defender', 'astoundingly', 'smitten', 'survival', 'meticulously', 'firmer', 'wisely', 'well-made', 'magnificently', 'destiny', 'amply', 'approve', 'propitious', 'tidy', 'well-informed', 'skill', 'fortitude', 'astonishment', 'exceeded', 'helped', 'unforgettable', 'gratification', 'gaiety', 'prodigiously', 'recommendations', 'rectification', 'indebted', 'thoughtfulness', 'preeminent', 'hooray', 'complements', 'resourcefulness', 'personages', 'achievement', 'humility', 'undisputed', 'sweeping', 'courage', 'contrasty', 'compliment', 'noteworthy', 'inviolable', 'cleared', 'conciliatory', 'restructure', 'valiantly', 'clearly', 'heroine', 'patiently', 'euphorically', 'luxuriate', 'swankiest', 'affirmative', 'mesmerizingly', 'redeem', 'fragrant', 'originality', 'magnificence', 'assuring', 'consistent', 'astound', 'exquisite', 'sufficed', 'simplified', 'autonomous', 'worthy', 'dote', 'peacekeepers', 'excel', 'prudence', 'handily', 'traction', 'qualified', 'prestige', 'goood', 'work', 'convience', 'breathtaking', 'fertile', 'mind-blowing', 'glorious', 'idolized', 'avid', 'sublime', 'marveled', 'peaceable', 'helpful', 'eminence', 'fortunate', 'prefer', 'elation', 'hot', 'goodly', 'attraction', 'tender', 'gratifying', 'satisfactorily', 'record-setting', 'well-backlit', 'unfazed', 'flattering', 'cajole', 'ergonomical', 'sagely', 'spacious', 'effusiveness', 'glad', 'miraculously', 'eased', 'personalized', 'fame', 'smiling', 'thinner', 'sharper', 'appreciated', 'intrigue', 'vivacious', 'blameless', 'honest', 'top', 'heartily', 'excellency', 'innocuous', 'enjoys', 'pride', 'outstandingly', 'breathlessness', 'invulnerable', 'refine', 'strong', 'cheerful', 'diversified', 'exceedingly', 'renewed', 'cleanliness', 'palatial', 'acumen', 'cleaner', 'well-educated', 'genius', 'quieter', 'contribution', 'faithfully', 'delicious', 'fashionable', 'jubiliant', 'triumphant', 'jolly', 'complementary', 'compactly', 'cohere', 'verifiable', 'economical', 'works', 'better-known', 'oasis', 'rapture', 'goodwill', 'convient', 'richer', 'steadfastly', 'smooth', 'heaven', 'complement', 'rejuvenated', 'eager', 'tantalizingly', 'endorse', 'breathtakingly', 'majestic', 'entrancing', 'sufficiently', 'virtuous', 'masterfully', 'err-free', 'well-bred', 'graciousness', 'fervor', 'steadiness', 'first-rate', 'swankier', 'glitter', 'cashbacks', 'perfect', 'pain-free', 'richly', 'roomy', 'poetic', 'amiabily', 'terrific', 'poise', 'conscientious', 'quaint', 'swiftness', 'wonderously', 'guidance', 'mighty', 'enchanted', 'fulfillment', 'energy-saving', 'fashionably', 'wonderous', 'all-around', 'champion', 'reasonable', 'accommodative', 'easiness', 'replaceable', 'fascinate', 'delicate', 'tenaciously', 'adroit', 'visionary', 'astonished', 'statuesque', 'hug', 'adjustable', 'beauteous', 'congratulations', 'attractive', 'exemplary', 'staunch', 'speedily', 'enjoyment', 'thrifty', 'providence', 'prize', 'flexibility', 'restored', 'commend', 'fast-growing', 'gaily', 'exultation', 'understandable', 'accessible', 'spiritual', 'swanky', 'desiring', 'persevere', 'sincerity', 'impartiality', 'earnestly', 'sexy', 'galore', 'privilege', 'dashing', 'calmness', 'eagerly', 'fortune', 'gumption', 'sporty', 'well-mannered', 'integral', 'approval', 'merciful', 'dominates', 'luck', 'memorable', 'flexible', 'gratitude', 'brightest', 'convincing', 'reachable', 'bonus', 'rockstar', 'exceeding', 'undisputably', 'savings', 'cost-effective', 'upliftment', 'defeated', 'stimulative', 'enthrall', 'bliss', 'affably', 'fine-looking', 'affirm', 'smiles', 'auspicious', 'pepped', 'dumbfounded', 'sincerely', 'decent', 'exceeds', 'distinctive', 'tingle', 'spontaneous', 'honesty', 'appropriate', 'luxuriant', 'pamperedly', 'courageousness', 'glisten', 'striking', 'eyecatch', 'respite', 'sturdy', 'ideally', 'exult', 'enthusiastically', 'exemplar', 'benefit', 'victorious', 'cleverly', 'kindly', 'excites', 'modern', 'worked', 'clear', 'excels', 'blossom', 'progressive', 'satisfied', 'enthuse', 'prowess', 'worth', 'merriness', 'convincingly', 'joyous', 'devout', 'electrify', 'wows', 'stupendous', 'congratulate', 'effectual', 'stunning', 'fancier', 'rock-star', 'trusty', 'honorable', 'intelligible', 'inventive', 'excellent', 'dextrous', 'proud', 'magnificent', 'capable', 'humane', 'brighter', 'foremost', 'blissful', 'impeccable', 'panoramic', 'nice', 'generous', 'thrive', 'flourishing', 'authoritative', 'exonerate', 'faultless', 'winning', 'contentment', 'gladness', 'upgradable', 'marvelousness', 'creative', 'influential', 'elatedly', 'coherence', 'distinction', 'golden', 'magic', 'smilingly', 'bravo', 'afordable', 'soundness', 'regard', 'invincible', 'popular', 'glorify', 'brisk', 'warmly', 'ambitious', 'trouble-free', 'progress', 'patriotic', 'handier', 'enticed', 'cushy', 'redemption', 'veritable', 'effectively', 'invaluable', 'flashy', 'passionate', 'seasoned', 'flourish', 'appreciable', 'upscale', 'wise', 'excitedly', 'abound', 'masterpieces', 'desirous', 'sumptuousness', 'bonuses', 'lead', 'unlimited', 'priceless', 'first-class', 'recover', 'selective', 'low-cost', 'evaluative', 'desirable', 'outdone', 'phenomenal', 'richness', 'coherent', 'feasible', 'realizable', 'glee', 'magnanimous', 'vouchsafe', 'openness', 'preferably', 'vigilance', 'bravery', 'pleasing', 'adulate', 'adulatory', 'dignified', 'brand-new', 'unassailable', 'dazzle', 'award', 'luxuriously', 'sweetness', 'responsive', 'retractable', 'colorful', 'revives', 'morality', 'comfort', 'loyal', 'courteous', 'exultingly', 'considerate', 'charisma', 'fondness', 'meritorious', 'refinement', 'non-violent', 'loves', 'dominated', 'credence', 'wisdom', 'serenity', 'apotheosis', 'humour', 'prospros', 'zippy', 'prominence', 'outperforms', 'blessing', 'stainless', 'well-intentioned', 'slick', 'receptive', 'erudite', 'precise', 'affordably', 'amicability', 'crisp', 'awe', 'booming', 'righten', 'embolden', 'splendidly', 'fondly', 'rejoicingly', 'reliable', 'assure', 'reformed', 'serene', 'unity', 'decisive', 'faithfulness', 'elate', 'impartial', 'acclaimed', 'lyrical', 'admiration', 'poeticize', 'succes', 'openly', 'dummy-proof', 'beautifullly', 'ardently', 'altruistic', 'laudable', 'god-given', 'saint', 'jubilant', 'protective', 'clear-cut', 'nourish', 'affectionate', 'healthful', 'dependable', 'tougher', 'efficient', 'fans', 'defeating', 'examplary', 'friendly', 'enviously', 'frolic', 'joy', 'shine', 'lucid', 'pleases', 'abundance', 'heartwarming', 'jubilantly', 'qualify', 'commendable', 'idealize', 'enjoyed', 'glory', 'balanced', 'zenith', 'credible', 'orderly', 'revolutionized', 'snazzy', 'awed', 'virtue', 'astonish', 'outsmart', 'encourage', 'happier', 'concise', 'witty', 'awards', 'restructuring', 'stronger', 'enthusiast', 'affordable', 'freshest', 'halcyon', 'politeness', 'promises', 'exceed', 'interests', 'illumine', 'respectful', 'exhilaration', 'whoa', 'advocate', 'appreciates', 'supurbly', 'classy', 'enthusiastic', 'sweeten', 'tempt', 'congratulatory', 'gratified', 'refined', 'freedoms', 'skillfully', 'lucrative', 'agreeable', 'polite', 'kid-friendly', 'chaste', 'thankful', 'rockstars', 'everlasting', 'best-performing', 'blissfully', 'spectacular', 'carefree', 'peppy', 'sprightly', 'extraordinarily', 'masterful', 'beauty', 'salute', 'exalt', 'ilu', 'bolster', 'proficiently', 'impresses', 'inestimably', 'illuminating', 'jubilate', 'agile', 'remission', 'reverently', 'envy', 'prosperous', 'self-determination', 'frugal', 'intelligent', 'self-satisfaction', 'wowed', 'illustrious', 'exellent', 'grand', 'excelled', 'goodness', 'titillating', 'accolade', 'gained', 'staunchly', 'rightness', 'recovery', 'tough', 'congenial', 'gentle', 'subsidizing', 'well-balanced', 'accomplish', 'faithful', 'radiance', 'beckoning', 'unparalleled', 'quicker', 'marvelled', 'easygoing', 'gush', 'hottest', 'empower', 'reform', 'succeeding', 'integrated', 'rejuvenate', 'securely', 'risk-free', 'divinely', 'restructured', 'romantic', 'lovably', 'prompt', 'yay', 'comely', 'hilarious', 'amity', 'dazzled', 'elevate', 'inestimable', 'loveliness', 'enchanting', 'idyllic', 'restful', 'aspiration', 'readily', 'merrily', 'powerful', 'better', 'cherished', 'maturely', 'freedom', 'immense', 'sharpest', 'rapturous', 'ample', 'audibly', 'free', 'revolutionary', 'exceptionally', 'enticing', 'delighted', 'patience', 'smile', 'genial', 'laudably', 'enlighten', 'recomend', 'skilled', 'gracefully', 'low-risk', 'heros', 'celebration', 'liberty', 'well-received', 'handy', 'levity', 'exuberantly', 'unencumbered', 'lawfully', 'prosperity', 'felicitate', 'smoothest', 'cool', 'tranquil', 'glimmering', 'ready', 'knowledgeable', 'aspirations', 'enrapture', 'cheer', 'profusion', 'respectfully', 'intuitive', 'simpler', 'darling', 'prominent', 'pleasant', 'adroitly', 'gifted', 'endorsed', 'exalting', 'steady', 'reforming', 'luckiness', 'amusingly', 'awestruck', 'exaltingly', 'benevolence', 'gentlest', 'breakthroughs', 'fortuitous', 'fidelity', 'renown', 'merriment', 'hale', 'irresistibly', 'encouraging', 'rejoice', 'peps', 'flatter', 'win', 'luxury', 'cure', 'ingenuity', 'immaculately', 'spectacularly', 'amazingly', 'prudently', 'spirited', 'winners', 'honor', 'harmonious', 'impartially', 'famous', 'supremacy', 'bonny', 'superiority', 'valiant', 'enchantingly', 'continuity', 'stellarly', 'warmhearted', 'hardier', 'awarded', 'viewable', 'overtaken', 'secure', 'problem-free', 'adorer', 'courtly', 'hero', 'peaceful', 'profound', 'amenity', 'commendably', 'reassurance', 'favour', 'majesty', 'support', 'empathy', 'benefactor', 'glistening', 'cost-saving', 'compliant', 'groundbreaking', 'cheaper', 'impressiveness', 'well-being', 'unrivaled', 'enthralled', 'entice', 'picturesque', 'spotless', 'twinkly', 'rightly', 'supurb', 'angelic', 'abounds', 'joyful', 'woo', 'sensationally', 'better-than-expected', 'nicest', 'issue-free', 'celebrate', 'lustrous', 'ebullient', 'trust', 'energy-efficient', 'jollify', 'hallmarks', 'first-in-class', 'pre-eminent', 'wonder', 'adventurous', 'outwit', 'tantalize', 'endear', 'euphoric', 'proactive', 'appreciatively', 'idolize', 'cleanest', 'calm', 'complimentary', 'holy', 'accessable', 'achievements', 'fun', 'impressively', 'daring', 'smoothly', 'amiability', 'beneficial', 'feasibly', 'educated', 'unmatched', 'grin', 'smarter', 'defeats', 'improves', 'invaluablely', 'whoooa', 'attune', 'bountiful', 'sensation', 'impress', 'superb', 'preferable', 'humorous', 'neat', 'accomplishment', 'temptingly', 'encouragement', 'effective', 'enticingly', 'mesmerizes', 'deserving', 'wonderfully', 'homage', 'brotherly', 'adorable', 'long-lasting', 'motivated', 'shiny', 'uphold', 'talents', 'chic', 'cherish', 'elegantly', 'gems', 'invigorating', 'virtuously', 'thank', 'ingenious', 'positively', 'ardor', 'blockbuster', 'authentic', 'lower-priced', 'great', 'believable', 'charitable', 'proven', 'correct', 'fabulous', 'warm', 'heroically', 'entertaining', 'envious', 'marvelous', 'consummate', 'modesty', 'top-notch', 'well-managed', 'easy-to-use', 'marvelously', 'enliven', 'like', 'eloquently', 'sumptuously', 'fortuitously', 'benifits', 'satisfy', 'gratifyingly', 'sensational', 'calming', 'undaunted', 'appeal', 'alluringly', 'patient', 'sensibly', 'amazes', 'facilitate', 'joyfully', 'steadiest', 'noiseless', 'fairly', 'brainy', 'winnable', 'adored', 'standout', 'trustworthiness', 'neatest', 'dotingly', 'foolproof', 'infallibility', 'affinity', 'affectation', 'logical', 'magical', 'successful', 'fast-paced', 'quiet', 'ardent', 'buoyant', 'advantageously', 'piety', 'self-sufficient', 'superior', 'youthful', 'glowingly', 'boundless', 'surmount', 'preferring', 'elegant', 'usable', 'pampers', 'salutary', 'supporter', 'improving', 'readable', 'astonishing', 'punctual', 'overtook', 'stabilize', 'fast', 'grace', 'soothingly', 'warmth', 'trophy', 'delight', 'fanfare', 'lawful', 'nimble', 'solace', 'feat', 'cute', 'formidable', 'monumentally', 'capably', 'gladden', 'delightful', 'amenable', 'truthfully', 'vigilant', 'revelation', 'faith', 'multi-purpose', 'valor', 'patriot', 'reforms', 'pamper', 'brilliances', 'irreproachable', 'miracles', 'ecstatic', 'gaining', 'hallmark', 'staunchness', 'zeal', 'speedy', 'healthy', 'cherub', 'effusively', 'defeat', 'eagerness', 'gloriously', 'perfectly', 'ecstatically', 'fruitful', 'breakthrough', 'deference', 'leading', 'clever', 'happily', 'confidence', 'ecstasies', 'paramount', 'topnotch', 'resolute', 'ideal', 'brave', 'well-behaved', 'lighter', 'excitingly', 'stimulating', 'hands-down', 'excelent', 'peace', 'gleefully', 'thrillingly', 'passion', 'endorsement', 'stirringly', 'heal', 'enjoy', 'profoundly', 'large-capacity', 'strongest', 'resound', 'obtainable', 'suffices', 'merry', 'versatile', 'fervently', 'workable', 'likes', 'proper', 'unwavering', 'novelty', 'bright', 'decency', 'instructive', 'celebrated', 'pretty', 'confident', 'happiness', 'impassioned', 'unabashed', 'diligent', 'pleasurable', 'blithe', 'gainfully', 'ultra-crisp', 'light-hearted', 'useable', 'trumpet', 'exciting', 'uncomplicated', 'time-honored', 'amazed', 'compassion', 'gem', 'praise', 'sensitive', 'happy', 'savior', 'interesting', 'prolific', 'diligence', 'upliftingly', 'lucky', 'rock-stars', 'inviolate', 'adaptable', 'triumph', 'preferes', 'seamless', 'cozy', 'exceled', 'miraculousness', 'togetherness', 'supports', 'reconcile', 'jaw-droping', 'streamlined', 'easing', 'promised', 'polished', 'aspire', 'soothe', 'reliably', 'impressed', 'attentive', 'optimism', 'self-sufficiency', 'propitiously', 'cashback', 'smartest', 'pepping', 'remarkably', 'stunned', 'empowerment', 'upgradeable', 'wins', 'dauntless', 'assurances', 'titillate', 'bloom', 'fascinatingly', 'amusing', 'sustainability', 'intelligence', 'reverence', 'awesomeness', 'heroize', 'advantage', 'purposeful', 'succeeded', 'supporting', 'effectiveness', 'cheapest', 'pleasingly', 'supported', 'outperforming', 'accomplished', 'advanced', 'profuse', 'satisfying', 'leads', 'overtaking', 'powerfully', 'admiring', 'playful', 'spellbinding', 'admiringly', 'appreciative', 'satisfies', 'fresh', 'satisified', 'spellbind', 'peerless', 'clears', 'lavish', 'beloved', 'rightful', 'swank', 'enthusiasm', 'efficacious', 'covenant', 'gratifies', 'saintliness', 'instantly', 'thoughtful', 'tickle', 'lean', 'gainful', 'liberation', 'pamperedness', 'pros', 'mightily', 'classic', 'promptly', 'nourishment', 'joyously', 'catchy', 'wholesome', 'tenacity', 'glimmer', 'sweet', 'monumental', 'entrust', 'fluent', 'counter-attack', 'gains', 'sensations', 'revival', 'awesome', 'imaculate', 'improvement', 'momentous', 'enjoyable', 'incredibly', 'righteous', 'evocative', 'sharp', 'robust', 'permissible', 'maneuverable', 'justly', 'righteously', 'accurate', 'ethical', 'surreal', 'thrilling', 'graciously', 'tenderly', 'festive', 'willing', 'ennoble', 'rewardingly', 'enraptured', 'safe', 'best-known', 'truthfulness', 'wonders', 'unequivocally', 'playfully', 'well-regarded', 'commitment', 'felicitous', 'industrious', 'cooperatively', 'notably', 'intimate', 'stability', 'vibrant', 'romanticize', 'harmonize', 'solicitously', 'victory', 'brainiest', 'eye-catch', 'indulgence', 'snappy', 'eulogize', 'dynamic', 'impeccably', 'peacefully', 'proficient', 'stimulates', 'charismatic', 'thriving', 'ambitiously', 'dead-cheap', 'excite', 'exaltedly', 'revel', 'advocated', 'exuberance', 'finely', 'promoter', 'gallant', 'supportive', 'nobly', 'competitive', 'pleasurably', 'manageable', 'painlessly', 'rejoicing', 'gooood', 'soundly', 'thumbs-up', 'revive', 'thumb-up', 'delectable', 'smoothes', 'kindliness', 'accurately', 'fave', 'sincere', 'jaw-dropping', 'vibrantly', 'inspiration', 'godlike', 'abundant', 'shimmeringly', 'wowing', 'self-respect', 'lifesaver', 'supremely', 'idol', 'regal', 'dignity', 'expertly', 'inexpensive', 'liberate', 'extraordinary', 'faster', 'stimulate', 'adventuresome', 'welcome', 'honoring', 'insightfully', 'overtake', 'treasure', 'wow', 'harmony', 'good'}, 'negative': {'apologist', 'cunts', 'inconsistencies', 'traitorous', 'complaining', 'ludicrously', 'improbably', 'rifts', 'depravedly', 'trauma', 'sneering', 'fabrication', 'illegal', 'infest', 'dreary', 'insupportably', 'thankless', 'sucker', 'asperse', 'broke', 'damages', 'lackadaisical', 'passiveness', 'absent-minded', 'inhibit', 'risky', 'wound', 'chaotic', 'annoys', 'harried', 'negative', 'tortured', 'tempest', 'guiltily', 'accuses', 'inattentive', 'tardy', 'enmity', 'shock', 'misbegotten', 'disses', 'fat-cats', 'unsustainable', 'expunge', 'fatalistic', 'gawk', 'imperfectly', 'toughness', 'destabilisation', 'argumentative', 'issues', 'spews', 'err', 'mischievous', 'unfit', 'genocide', 'stale', 'rude', 'invidiousness', 'coldly', 'brash', 'negation', 'disconcerting', 'laggy', 'troublesome', 'deceptively', 'hard-hit', 'refused', 'abused', 'bastard', 'furious', 'impetuously', 'daunt', 'mire', 'shirker', 'thumb-down', 'ding', 'belabor', 'strain', 'capriciousness', 'inflammation', 'immobilized', 'occlude', 'tangle', 'bitter', 'break-up', 'insurmountable', 'retract', 'solemn', 'wrong', 'leech', 'disown', 'fanatically', 'difficulty', 'haughtily', 'disrepute', 'domineering', 'defiantly', 'pariah', 'repressive', 'annihilate', 'careless', 'refutes', 'vilify', 'exploit', 'licentiously', 'suspicion', 'scandalize', 'crap', 'disagreement', 'imperil', 'contemptuously', 'impinge', 'radical', 'anarchistic', 'unsteadiness', 'quibble', 'discredit', 'grumpiest', 'uneven', 'loss', 'annoyance', 'demolisher', 'babble', 'dirty', 'brutalising', 'farfetched', 'hostility', 'prik', 'autocrat', 'renounce', 'deterrent', 'butcher', 'raging', 'syndrome', 'stab', 'disintegration', 'blistering', 'fails', 'punitive', 'unruly', 'thumbs-down', 'intimidatingly', 'breaking', 'bloodshed', 'indistinguishable', 'frenetic', 'overturn', 'venomous', 'betraying', 'peevish', 'conspirator', 'galls', 'uglier', 'hypocricy', 'invective', 'cheesy', 'subjection', 'tauntingly', 'declining', 'prickle', 'unwieldy', 'remorselessly', 'fallen', 'conservative', 'revenge', 'corrupted', 'extravagance', 'neurotically', 'ugh', 'raping', 'misconceptions', 'credulous', 'cheating', 'misguided', 'provocation', 'teasingly', 'regrettable', 'stumps', 'lonesome', 'impedance', 'burdensome', 'controversial', 'cuss', 'draconic', 'indiscreetly', 'insubstantially', 'neglect', 'defamations', 'peeved', 'refuse', 'remorselessness', 'flicker', 'brusque', 'layoff-happy', 'over-balanced', 'wildly', 'perturbed', 'dismal', 'heedless', 'lackey', 'arrogance', 'bleak', 'perversity', 'indeterminate', 'furor', 'unbelievable', 'unsavory', 'malcontented', 'blame', 'corrupts', 'uncontrolled', 'steal', 'propagandize', 'heartbreakingly', 'disprove', 'unjust', 'dishonorablely', 'incapable', 'reprimand', 'brazenly', 'bothering', 'straggler', 'discord', 'venomously', 'battered', 'disdained', 'uneasiness', 'misses', 'weariness', 'fatcat', 'untouched', 'blabber', 'impatience', 'unethical', 'conspiracies', 'alienation', 'overstatements', 'impenitent', 'showdown', 'disrespectable', 'devastation', 'fail', 'assault', 'devastate', 'overzelous', 'occludes', 'creep', 'unappealing', 'juddering', 'altercation', 'deceive', 'disastrously', 'trick', 'disputable', 'malevolently', 'savagery', 'infraction', 'heathen', 'imminently', 'unresponsive', 'flout', 'ghastly', 'ineptitude', 'rift', 'disruption', 'delaying', 'provoke', 'inaccuracies', 'douchebags', 'vent', 'distaste', 'hurt', 'decadence', 'cannibalize', 'stalls', 'seething', 'screwed-up', 'conspiratorial', 'flirt', 'infiltrators', 'lackluster', 'recession', 'recklessly', 'unimaginably', 'zap', 'protest', 'rejects', 'tenuously', 'intrusive', 'fearfully', 'bias', 'resent', 'nervously', 'scrambled', 'bug', 'improbable', 'murderous', 'darken', 'smoulder', 'spewed', 'impractical', 'boredom', 'hostilities', 'misbecome', 'overdo', 'wack', 'atrophy', 'audiciously', 'arduously', 'curses', 'enflame', 'inconsistence', 'slumping', 'damnable', 'insanely', 'malcontent', 'dirt', 'worthlessly', 'unobserved', 'costlier', 'refuting', 'racism', 'uncouth', 'amputate', 'groundless', 'bitterness', 'bribery', 'jutter', 'stuffy', '2-faced', 'combative', 'mundane', 'audaciously', 'tetchy', 'recourses', 'turbulent', 'kook', 'jumpy', 'unusably', 'pander', 'vindictive', 'droops', 'flairs', 'madman', 'egregious', 'dispirited', 'pickets', 'outbursts', 'thrash', 'ineffectually', 'dissolution', 'totalitarian', 'smudges', 'fateful', 'sacrificed', 'despotism', 'loathsomely', 'ignoble', 'unuseable', 'senseless', 'bothered', 'bashing', 'indelicate', 'lagging', 'unnerved', 'dejectedly', 'lackeys', 'fibber', 'inane', 'squealing', 'uneconomical', 'ragged', 'clumsy', 'steep', 'despicably', 'scariest', 'bloodthirsty', 'dubious', 'bearish', 'betrayer', 'agonizingly', 'facetious', 'filth', 'grainy', 'impossiblity', 'racy', 'creaking', 'unfortunately', 'reprovingly', 'lamentably', 'refute', 'scream', 'harasses', 'lorn', 'stern', 'bumpy', 'intoxicate', 'qualm', 'impudently', 'misguidance', 'scolded', 'plight', 'poisonous', 'degrading', 'allegation', 'cramping', 'extort', 'humiliating', 'lurk', 'spendy', 'beleaguer', 'presumptuously', 'gaff', 'bruised', 'diatribes', 'moot', 'doddering', 'dinky', 'dishonor', 'contradictory', 'drawback', 'misaligns', 'stupify', 'inequalities', 'despondent', 'symptom', 'crafty', 'unresolved', 'unthinkable', 'distasteful', 'despair', 'loser', 'spookier', 'downturn', 'perverts', 'bellicose', 'demonic', 'bleeding', 'scrambling', 'diabolical', 'discountenance', 'dizzing', 'slanders', 'unsound', 'accusing', 'fat-cat', 'interruption', 'repetitive', 'presumptuous', 'monstrous', 'enervate', 'covetous', 'break', 'flees', 'forgetfully', 'muscle-flexing', 'head-aches', 'squeak', 'defiance', 'incompatible', 'longing', 'dastard', 'anti-israeli', 'eviscerate', 'bereft', 'pertinaciously', 'startle', 'twist', 'vexing', 'haste', 'sarcastically', 'setback', 'mangles', 'wrest', 'brutalizing', 'rants', 'riled', 'unconvincing', 'fatefully', 'bedlamite', 'defiler', 'scams', 'tantrum', 'struggle', 'idiotically', 'fathomless', 'fusty', 'hoax', 'wrought', 'unlucky', 'chilly', 'meddlesome', 'dissatisfying', 'overbearing', 'condescending', 'hoodwink', 'insignificantly', 'disagree', 'impotent', 'fidget', 'inexcusably', 'sap', 'split', 'dislikes', 'undercut', 'oppressiveness', 'rascal', 'conspicuously', 'gimmicky', 'undersized', 'losses', 'scratchy', 'irreformable', 'misjudge', 'imposers', 'disallow', 'fraudulent', 'gnawing', 'heartbreaking', 'inteferes', 'racists', 'dense', 'cocky', 'upseting', 'choke', 'devilment', 'slanderous', 'disdainful', 'retards', 'excruciatingly', 'tragic', 'desertion', 'ranted', 'tyrannical', 'jeopardy', 'inept', 'infuriatingly', 'pretentious', 'rotten', 'indecently', 'agonies', 'eyesore', 'dissapointed', 'perverted', 'bullying', 'dented', 'penalize', 'irregular', 'irritable', 'hectic', 'disgust', 'persecute', 'repel', 'discontent', 'discrepant', 'sluts', 'cannibal', 'innuendo', 'lecherous', 'blinding', 'revoltingly', 'stuck', 'torturing', 'crushing', 'ambiguity', 'depression', 'uproarious', 'blunders', 'frustrations', 'flair', 'mislead', 'rip-off', 'ulterior', 'unseemly', 'bleed', 'felon', 'horrible', 'villian', 'scowl', 'isolation', 'treacherously', 'pugnacity', 'sunder', 'oversize', 'forebodingly', 'dissidence', 'impropriety', 'eschew', 'opposition', 'protests', 'struggles', 'diappointed', 'orphan', 'frightening', 'banal', 'disreputable', 'undermine', 'aground', 'demolish', 'contradict', 'deaf', 'engulf', 'deteriorate', 'sceptical', 'excessively', 'incongruous', 'loose', 'slowly', 'miss', 'despondency', 'nervous', 'unease', 'obscures', 'malaise', 'chide', 'hastily', 'plunderer', 'sloppily', 'crashing', 'breakup', 'oblivious', 'apprehension', 'incompetently', 'untruthful', 'fallacies', 'tenderness', 'offend', 'anarchism', 'cloudy', 'debasement', 'disappointing', 'vibrating', 'belligerently', 'polluter', 'fried', 'devastated', 'regretted', 'dissuade', 'taunt', 'pokey', 'headache', 'hesitant', 'impose', 'instigator', 'defiant', 'senselessly', 'cripples', 'glitch', 'stupidly', 'despondently', 'impulsively', 'treasonous', 'hype', 'ill-mannered', 'discrimination', 'haze', 'wheedle', 'wrongly', 'fake', 'hideous', 'partisan', 'subdued', 'dissatisfaction', 'injudicious', 'sourly', 'straggle', 'trivialize', 'outsider', 'foolish', 'scathingly', 'slump', 'controversy', 'challenging', 'confess', 'backaches', 'seriousness', 'belittle', 'complain', 'direly', 'unhealthy', 'diabolically', 'unscrupulous', 'doubtful', 'incognizant', 'bullshyt', 'topple', 'cruel', 'condescension', 'inhospitality', 'idiots', 'inefficacy', 'harbors', 'goon', 'complication', 'infirm', 'procrastinate', 'sensationalize', 'underpaid', 'wickedly', 'haughty', 'maltreatment', 'poorer', 'transgress', 'brood', 'contrived', 'mispronounces', 'sillily', 'drought', 'brazenness', 'uneventful', 'mope', 'snappish', 'susceptible', 'sorrowfully', 'imprison', 'abscond', 'judder', 'scandel', 'defective', 'obscenely', 'odd', 'snare', 'unproductive', 'dwindling', 'grievously', 'concen', 'racist', 'ridicules', 'addicted', 'catastrophies', 'hallucinate', 'lonely', 'humiliation', 'unkind', 'antithetical', 'desolately', 'discourteously', 'insignificant', 'harshly', 'reproachful', 'pathetically', 'acerbically', 'polarisation', 'grisly', 'antagonistic', 'puzzlement', 'finagle', 'choppy', 'expired', 'extremism', 'injury', 'obnoxious', 'swindle', 'rust', 'rot', 'irritate', 'lesser-known', 'perfidious', 'garish', 'enviousness', 'forbid', 'irrecoverablenesses', 'bloated', 'pettifog', 'hysterical', 'dissonant', 'water-down', 'brainless', 'gall', 'discontentedly', 'senile', 'discouragement', 'deadbeat', 'hacks', 'bash', 'stain', 'sob', 'discompose', 'outrageously', 'unsophisticated', 'embarrass', 'lagged', 'meaningless', 'second-class', 'prattle', 'wripped', 'lies', 'forbidden', 'picky', 'ultimatums', 'destitute', 'infuriate', 'stinging', 'flagrant', 'direness', 'eruptions', 'sticky', 'tricked', 'useless', 'demonize', 'underdog', 'belittled', 'languorous', 'slothful', 'horde', 'indifference', 'heavyhearted', 'madden', 'nuisance', 'strained', 'sueing', 'fallout', 'smelly', 'unwarranted', 'slowed', 'downsides', 'interference', 'bulkier', 'misstatement', 'scandalized', 'sullen', 'calamitous', 'uproarous', 'averse', 'overshadow', 'contentious', 'remorsefully', 'slogged', 'crueler', 'belated', 'disintegrated', 'cussed', 'fumes', 'lying', 'traumatize', 'bitterly', 'disappointingly', 'dictator', 'irritant', 'mocked', 'overtaxed', 'devilishly', 'faulty', 'pitiful', 'choleric', 'qualms', 'incorrectly', 'paltry', 'chaos', 'repression', 'rejecting', 'unwanted', 'irate', 'jealously', 'indignantly', 'needlessly', 'oppose', 'darkened', 'distracting', 'contagious', 'concerned', 'bum', 'spoil', 'dismaying', 'impasse', 'misguide', 'impugn', 'fruitlessly', 'hasseling', 'occluding', 'stark', 'depress', 'quack', 'smells', 'blurring', 'bruising', 'immoderately', 'predatory', 'rancor', 'temper', 'counter-productive', 'ironic', 'extravagant', 'ridiculous', 'dishonestly', 'shortcomings', 'mendacious', 'fetid', 'imprecate', 'bungle', 'degenerate', 'exasperated', 'frustrates', 'irk', 'unsuccessful', 'villainously', 'afraid', 'browbeat', 'flimflam', 'belie', 'idiocies', 'irretating', 'quarrellously', 'spitefully', 'backache', 'omit', 'troubles', 'bigotries', 'cartoonish', 'brimstone', 'nastily', 'conscons', 'deceptive', 'liability', 'scandels', 'stifle', 'unsteadily', 'daze', 'butchery', 'tenuous', 'pout', 'crushed', 'uncollectible', 'undissolved', 'dragoon', 'incoherent', 'exorbitant', 'irrepressible', 'illegitimate', 'monster', 'niggles', 'vileness', 'harmed', 'sloppy', 'squeaks', 'comical', 'suspect', 'tyrannically', 'displeasure', 'unimaginable', 'dissed', 'exhaust', 'slowest', 'deficiency', 'buzzing', 'banish', 'tattered', 'glower', 'imprecise', 'inaction', 'disquietude', 'disgustedly', 'paranoid', 'rumor', 'inveigle', 'scratched', 'setbacks', 'slooow', 'killed', 'avenge', 'sugarcoated', 'fissures', 'fudge', 'chasten', 'delays', 'indolent', 'suffered', 'unyielding', 'self-interested', 'fool', 'mortifying', 'woe', 'unexplained', 'aspersion', 'erosion', 'problems', 'creak', 'rue', 'bemused', 'tarnishing', 'jealousness', 'unreasonably', 'dilly-dally', 'ill-sorted', 'traduce', 'unuseably', 'exorbitantance', 'flighty', 'messes', 'stupor', 'suicide', 'scuff', 'precarious', 'frenzy', 'suppression', 'demoralizing', 'unorthodoxy', 'irreplacible', 'strike', 'imperiously', 'hysterically', 'plague', 'hurted', 'loner', 'selfish', 'sloww', 'ill-favored', 'un-viewable', 'unreasonable', 'vindictiveness', 'disconcerted', 'lunaticism', 'd*mn', 'lethargic', 'rebellious', 'spank', 'skepticism', 'dropout', 'subtract', 'delinquency', 'excuses', 'nepotism', 'bored', 'flaunt', 'rubbish', 'sty', 'quarrellous', 'usurper', 'insanity', 'narrower', 'paucity', 'retarded', 'irreversible', 'plea', 'solicitude', 'needy', 'glare', 'stranger', 'tacky', 'unforeseen', 'cripple', 'cruelty', 'invisible', 'jabber', 'loneliness', 'restlessness', 'obsolete', 'scoffingly', 'stammer', 'steals', 'heretical', 'unlawfully', 'disrespect', 'disturbing', 'offensiveness', 'fatal', 'pretentiously', 'unsafe', 'untested', 'madly', 'motley', 'disagreed', 'gloom', 'haunting', 'severity', 'commiserate', 'immovable', 'fearsome', 'anomaly', 'distraction', 'hallucination', 'unemployed', 'cloud', 'drained', 'immaterial', 'rigid', 'rupture', 'disrespectfulness', 'apathetically', 'toxic', 'aching', 'insufficient', 'lament', 'unthinkably', 'anxious', 'wrestle', 'disordered', 'break-ups', 'chronic', 'obsess', 'absence', 'wobbles', 'incessant', 'blemish', 'midget', 'overweight', 'darker', 'redundant', 'premeditated', 'ruthlessness', 'grudge', 'unavailable', 'ire', 'squander', 'desecrate', 'mischief', 'enfeeble', 'reckless', 'foul', 'mawkishly', 'aggressor', 'scuffs', 'tout', 'dislike', 'painful', 'flak', 'acrimonious', 'kooky', 'ultra-hardline', 'vicious', 'antipathy', 'bruises', 'corrosions', 'grieve', 'gasp', 'gruesome', 'prisoner', 'shameless', 'bid-rigging', 'neglected', 'urgent', 'delusions', 'stunted', 'superstitious', 'stifling', 'stagnation', 'admonish', 'soapy', 'hard', 'impiety', 'ill-natured', 'belligerent', 'joke', 'debase', 'infamy', 'powerless', 'puzzling', 'subordinate', 'poisonously', 'wretchedly', 'irksomeness', 'cringes', 'breakdown', 'extremists', 'strangest', 'scandalously', 'evil', 'indecisively', 'inconsequently', 'sagging', 'terror', 'jerk', 'unsettlingly', 'hasty', 'capriciously', 'mockeries', 'relapse', 'flaws', 'capitulate', 'peculiarly', 'misinform', 'yawn', 'unnerve', 'bombard', 'ax', 'smolder', 'revengeful', 'adversity', 'inadverent', 'smug', 'moronic', 'died', 'reluctant', 'dissemble', 'languor', 'loveless', 'timid', 'blasphemous', 'fiasco', 'gripes', 'anarchy', 'fiendish', 'harm', 'savage', 'famine', 'hurting', 'balk', 'expropriate', 'frozen', 'fiend', 'reprove', 'disconsolation', 'hooligan', 'crumble', 'plunder', 'languid', 'crooks', 'cruelness', 'trashed', 'viper', 'object', 'gainsay', 'drags', 'shocking', 'mortification', 'calumniate', 'obsessive', 'sinister', 'bombastic', 'viciousness', 'downcast', 'die', 'worsening', 'unsteady', 'insufficiently', 'offensively', 'virulence', 'taxing', 'rash', 'flabbergast', 'insults', 'deprive', 'refusing', 'burns', 'mishandle', 'deny', 'smudged', 'mendacity', 'taboo', 'wasting', 'mar', 'unavoidably', 'emaciated', 'harrow', 'unaccustomed', 'perplexity', 'meltdown', 'hoodium', 'dumbfound', 'inappropriately', 'funny', 'streaky', 'unrelentingly', 'ill-usage', 'annoyances', 'tetchily', 'stump', 'woeful', 'impulsive', 'accusation', 'rremediable', 'sorely', 'grim', 'craftily', 'ill-tempered', 'pestilent', 'sloth', 'moan', 'undermining', 'unproved', 'deviation', 'ineffectual', 'sh*t', 'coercion', 'inexpiable', 'exorbitantly', 'undercuts', 'detraction', 'lapse', 'shirk', 'miserably', 'deceivers', 'misgiving', 'disparage', 'disasterous', 'rumbling', 'degradation', 'hardhearted', 'over-priced', 'distraught', 'spew', 'cronyism', 'deceiving', 'violent', 'bewail', 'laughably', 'irresolvable', 'disobey', 'radicals', 'adverse', 'sub-par', 'doomsday', 'maddeningly', 'tarnished', 'offence', 'aggrivation', 'dejected', 'mess', 'unacceptable', 'rusty', 'gibber', 'anti-proliferation', 'ignorant', 'earsplitting', 'incongruously', 'peril', 'overthrow', 'restriction', 'rampant', 'pale', 'flagging', 'acrimony', 'equivocal', 'inexperienced', 'troubled', 'one-sided', 'second-tier', 'excoriate', 'friction', 'bother', 'nauseate', 'crash', 'smelt', 'complains', 'decay', 'disadvantageous', 'spurious', 'scandal', 'disquietingly', 'disquiet', 'despotic', 'destains', 'decayed', 'ambiguous', 'incomplete', 'insociable', 'clogged', 'repudiation', 'freakish', 'ill-designed', 'antagonism', 'repulse', 'harden', 'impoverished', 'hardship', 'absentee', 'frigid', 'precipitate', 'defects', 'sidetracked', 'intolerance', 'indoctrination', 'disconsolately', 'encroachment', 'vibrate', 'drawbacks', 'insulted', 'smudging', 'temptation', 'intolerable', 'picketed', 'oversimplified', 'lousy', 'damnation', 'humid', 'hellion', 'irritated', 'gimmicking', 'taint', 'embarrassingly', 'crumples', 'dread', 'menace', 'imperfection', 'stink', 'pessimistic', 'mania', 'quarrel', 'trap', 'allergies', 'exasperation', 'suffering', 'manipulative', 'obstinately', 'starve', 'jam', 'crazily', 'heartbreaker', 'flounder', 'scold', 'sly', 'confession', 'frazzled', 'cheaply', 'mushy', 'apocalypse', 'panic', 'lewd', 'bullshit', 'allergy', 'disgracefully', 'relentlessness', 'worried', 'touts', 'superficiality', 'ravage', 'crashed', 'overpaid', 'rant', 'flickering', 'wrinkled', 'berserk', 'wrip', 'rhetoric', 'fascism', 'fleed', 'ridiculously', 'contempt', 'disruptive', 'unauthentic', 'infiltrator', 'crippling', 'throttle', 'barbarically', 'discouragingly', 'screwy', 'detesting', 'haunt', 'foolishly', 'scrap', 'bores', 'liars', 'indifferent', 'substandard', 'unnervingly', 'sinfully', 'arrogantly', 'demise', 'grossly', 'interfere', 'conflicts', 'patronize', 'weakening', 'expensive', 'impure', 'impurity', 'arbitrary', 'disaffect', 'discriminate', 'miseries', 'penalty', 'impunity', 'abyss', 'dismally', 'exhort', 'inessential', 'injustices', 'pandering', 'slanderer', 'desultory', 'haggle', 'brutal', 'irresponsible', 'ingratitude', 'obscured', 'uproar', 'hegemony', 'burned', 'hiss', 'isolated', 'superficially', 'illogic', 'numb', 'unreachable', 'downfallen', 'backwood', 'ineligible', 'exaggerate', 'misgivings', 'harmful', 'perverse', 'dark', 'unpopular', 'semi-retarded', 'stressfully', 'insane', 'warped', 'frail', 'unfaithful', 'blindingly', 'disloyalty', 'obstinate', 'shun', 'illogical', 'insubstantial', 'sad', 'goof', 'lacked', 'anti-white', 'grumpish', 'calamity', 'misinformed', 'harangue', 'disdainfully', 'submissive', 'accursed', 'mockery', 'drones', 'affront', 'disproportionate', 'rattled', 'protracted', 'deadly', 'gossip', 'broken-hearted', 'faze', 'infected', 'dirtbag', 'importunate', 'womanizing', 'frenetically', 'mudslinging', 'disliked', 'impede', 'relentlessly', 'fib', 'worthless', 'insidiously', 'testy', 'incite', 'insufferably', 'inopportune', 'crashes', 'gibe', 'two-faces', 'squabble', 'cliche', 'evils', 'drastically', 'inexperience', 'shoddy', 'upheaval', 'mockingly', 'unforgiving', 'pessimism', 'biases', 'sober', 'snobs', 'irrationally', 'damage', 'deviously', 'lame', 'unkindly', 'hard-liner', 'doomed', 'dismayed', 'terrible', 'slogs', 'self-defeating', 'cons', 'heckle', 'judders', 'inaudible', 'misrepresentation', 'deprived', 'disrespectablity', 'dope', 'chunky', 'regreted', 'cuplrit', 'slur', 'ignominious', 'subjected', 'negatives', 'threat', 'bewitch', 'implacable', 'cataclysmic', 'rumple', 'dissatisfied', 'flimsy', 'slug', 'unintelligible', 'injure', 'cowardly', 'mournfully', 'refuted', 'disagreeable', 'incomprehensible', 'disavow', 'insensitively', 'misrepresent', 'sulk', 'overwhelmingly', 'tank', 'bulky', 'commotions', 'horrifies', 'brutality', 'impersonal', 'bitchy', 'rumors', 'arrogant', 'bait', 'calumniation', 'glut', 'blatantly', 'scrambles', 'shamefulness', 'dragging', 'bitch', 'fatigued', 'overlook', 'destitution', 'impeach', 'decrepit', 'sickening', 'junk', 'muddle', 'war-like', 'blatant', 'conceited', 'derision', 'passive', 'audaciousness', 'egocentric', 'miscalculate', 'incivility', 'instable', 'tense', 'grating', 'murder', 'utterly', 'primitive', 'disgraced', 'lowly', 'gangster', 'tiring', 'stereotypically', 'contaminating', 'untrue', 'blundering', 'demean', 'infection', 'unsupportive', 'disliking', 'imaginary', 'prejudge', 'reject', 'emptiness', 'tiresome', 'uprising', 'fever', 'polution', 'wreck', 'inflexible', 'jutters', 'frost', 'rivalry', 'tawdry', 'blasphemy', 'failing', 'skittish', 'avariciously', 'tanked', 'deride', 'ruts', 'unfinished', 'rabid', 'saggy', 'villianous', 'wearisome', 'tiringly', 'inevitably', 'womanizer', 'sanctimonious', 'bust', 'inefficacious', 'deceiver', 'spiritless', 'tentatively', 'wedge', 'overwhelms', 'abrupt', 'stew', 'blather', 'fooled', 'doubtfully', 'insular', 'negligent', 'dreadfulness', 'undignified', 'frustratingly', 'sue', 'sunk', 'paralize', 'startlingly', 'disturb', 'suppress', 'nasty', 'allegations', 'nonexistent', 'desert', 'monstrously', 'shortcoming', 'sleazy', 'faltered', 'bowdlerize', 'infuriating', 'drips', 'chatter', 'rampage', 'emasculate', 'crowdedness', 'tortuous', 'disconsolate', 'vagueness', 'venom', 'wince', 'stagnant', 'obese', 'dissolute', 'indiscriminately', 'obliterate', 'invidiously', 'inaccurately', 'dripped', 'imperfect', 'denigrate', 'notoriously', 'egotistically', 'brutally', 'funky', 'revengefully', 'confessions', 'uncivilized', 'dismay', 'gimmicks', 'fractiously', 'upsetting', 'knife', 'perturb', 'peeve', 'dispirit', 'self-criticism', 'criticisms', 'heckled', 'volatility', 'drunken', 'intolerablely', 'discordance', 'implode', 'maddening', 'condemned', 'monotonous', 'fallaciousness', 'strange', 'deviousness', 'gainsayer', 'rusts', 'fleer', 'alienated', 'deadweight', 'fatcats', 'indeterminably', 'menial', 'unravel', 'job-killing', 'unwell', 'aggressive', 'giddy', 'obtrusive', 'backward', 'droop', 'harms', 'fat', 'divisive', 'hater', 'misjudgment', 'shambles', 'slaughter', 'squash', 'angriness', 'overrated', 'waste', 'objections', 'puppet', 'frenzied', 'sarcasm', 'craziness', 'skinny', 'impertinent', 'smuttier', 'tension', 'tease', 'intrude', 'litigious', 'unclear', 'immoderate', 'raped', 'bleeds', 'censure', 'heavy-handed', 'frown', 'irresolute', 'bewildered', 'vengefulness', 'jolt', 'emphatically', 'reticent', 'imbroglio', 'illicit', 'breakups', 'dissing', 'accost', 'spoilled', 'restrictive', 'scary', 'tarnishes', 'uncomfy', 'contaminated', 'flareups', 'hothouse', 'declines', 'lurid', 'myth', 'dejection', 'meddle', 'suspicions', 'addict', 'uncompromising', 'abysmally', 'cunt', 'snappishly', 'condemns', 'hurts', 'panicky', 'antagonize', 'abysmal', 'disingenuous', 'coupists', 'betrayals', 'inadequate', 'tangled', 'obnoxiously', 'grate', 'languorously', 'irretrievable', 'mediocrity', 'onerously', 'trashy', 'carelessness', 'distract', 'knock', 'disrupt', 'violators', 'absurd', 'prickles', 'struck', 'unproves', 'furiously', 'helpless', 'contortions', 'incommensurate', 'vague', 'hazardous', 'infringements', 'taunting', 'revolting', 'sues', 'merciless', 'misconception', 'doubt', 'fragmented', 'illness', 'madder', 'prejudice', 'braggart', 'dump', 'unnerving', 'vomits', 'onerous', 'stolen', 'unnaturally', 'stresses', 'downturns', 'delay', 'futilely', 'blurry', 'criminal', 'impatiently', 'volatile', 'desperate', 'criticize', 'brashly', 'diabolic', 'abominate', 'exaggeration', 'idiot', 'sinking', 'travesties', 'unipolar', 'stiff', 'vestiges', 'anxiously', 'overbalance', 'bane', 'hypocrisy', 'avaricious', 'problematic', 'low-rated', 'curse', 'scarily', 'far-fetched', 'feckless', 'wasted', 'reprehensive', 'cruelest', 'handicapped', 'timidness', 'amiss', 'defunct', 'enslave', 'gripe', 'gullible', 'horrendous', 'sedentary', 'dehumanization', 'desolation', 'belligerence', 'hothead', 'rife', 'sadly', 'sore', 'scarce', 'distorts', 'escapade', 'barbarity', 'ostracize', 'reluctance', 'slanderously', 'spoiled', 'unfortunate', 'vulgar', 'depressed', 'dying', 'crude', 'back-wood', 'opportunistic', 'strict', 'intrusion', 'measly', 'reprehensibly', 'apathy', 'insensitivity', 'sharply', 'testily', 'blockage', 'disaccord', 'worthlessness', 'faults', 'slumpping', 'treason', 'disturbingly', 'inordinate', 'treachery', 'inability', 'badly', 'torture', 'disgruntled', 'catastrophe', 'decrement', 'hardliners', 'involuntarily', 'poverty', 'wretch', 'subversion', 'insolence', 'discourage', 'downside', 'contention', 'drain', 'polemize', 'pollute', 'untimely', 'spoon-fed', 'virulent', 'unrealistic', 'fastuous', 'mysteriously', 'lanky', 'chill', 'inactive', 'dissappointed', 'antagonist', 'scratches', 'sinful', 'bastards', 'hampered', 'partisans', 'indiscretion', 'toll', 'imprudence', 'unsuccessfully', 'bleakly', 'perilously', 'dimmer', 'deign', 'imperialist', 'fallacy', 'insincerity', 'lawbreaker', 'precariously', 'revile', 'misleading', 'impossible', 'demon', 'distrusting', 'bulkiness', 'betrayal', 'grudges', 'hazard', 'deterioration', 'enemy', 'manipulate', 'nightmare', 'insurmountably', 'revolt', 'bunk', 'cave', 'disorder', 'plebeian', 'shabby', 'betray', 'flagrantly', 'confused', 'repugn', 'threats', 'enjoin', 'frantic', 'lukewarm', 'distort', 'adulteration', 'inadverently', 'downbeat', 'apprehensions', 'complaint', 'draining', 'aggression', 'anti-us', 'grouch', 'thoughtlessness', 'wretchedness', 'incapably', 'incompliant', 'subservience', 'dreadful', 'adversary', 'exclusion', 'disgruntle', 'mournful', 'displace', 'phony', 'sicken', 'cataclysmically', 'lost', 'preposterously', 'sloow', 'crush', 'extortion', 'craftly', 'oversights', 'sorrow', 'sting', 'undermined', 'disinclined', 'conspire', 'stains', 'joker', 'wrath', 'haggard', 'snub', 'distrust', 'hoard', 'inadvisably', 'laid-off', 'diametrically', 'jobless', 'foe', 'suicidal', 'thorny', 'disadvantages', 'itch', 'pugnaciously', 'insultingly', 'poor', 'slow-moving', 'obstruction', 'danger', 'exasperating', 'junkyard', 'sour', 'matte', 'chafe', 'doom', 'fictitious', 'smouldering', 'sugar-coat', 'runaway', 'crooked', 'hassled', 'bitingly', 'persecution', 'adulterate', 'caricature', 'misunderstand', 'flickers', 'overzealous', 'terrorism', 'fatuous', 'ill-defined', 'crook', 'incoherently', 'disgustingly', 'sneaky', 'belittling', 'collude', 'deceitful', 'falter', 'fatuity', 'losing', 'congestion', 'incautious', 'consternation', 'misfit', 'condemn', 'mistified', 'grievous', 'inferiority', 'brutish', 'insecure', 'snagging', 'curt', 'zealous', 'aggravating', 'forsake', 'frets', 'snags', 'tumbles', 'costly', 'vain', 'fears', 'erratic', 'undesirable', 'addicts', 'barbarous', 'undocumented', 'vehemently', 'flaky', 'botch', 'chaff', 'disrespectful', 'refuses', 'halfheartedly', 'downheartedly', 'limitation', 'dodgey', 'siege', 'inevitable', 'inhuman', 'wickedness', 'dishonesty', 'static', 'lapsed', 'invasive', 'cheap', 'impoverish', 'effigy', 'flee', 'displease', 'difficult', 'delirious', 'guilty', 'rattles', 'inequities', 'lascivious', 'dismalness', 'tedious', 'maliciousness', 'discontinuity', 'oddly', 'disgustful', 'flat-out', 'unskilled', 'lurking', 'derisiveness', 'nebulously', 'lied', 'set-up', 'killer', 'undone', 'maladjustment', 'ill-fated', 'temerity', 'upsets', 'embarrassment', 'sufferer', 'arcane', 'dust', 'fainthearted', 'damaged', 'ignore', 'inexorably', 'puppets', 'losers', 'perplexing', 'stun', 'beggar', 'collusion', 'confrontation', 'inconsistent', 'pretense', 'imbalance', 'smash', 'blaspheme', 'invalidity', 'sneak', 'disheartening', 'unlawful', 'insatiable', 'aborts', 'funnily', 'cynical', 'loopholes', 'limited', 'mourn', 'archaic', 'contemptible', 'muddy', 'tumble', 'indignity', 'epidemic', 'rejected', 'condescend', 'throbs', 'disagreeing', 'false', 'stubbornness', 'obtuse', 'idiocy', 'oppressively', 'salacious', 'suffer', 'superstition', 'aggrieve', 'unspeakablely', 'fatuously', 'dangerous', 'downfall', 'debacle', 'insolently', 'neurotic', 'baffle', 'bumpping', 'anti-social', 'insensitive', 'murderer', 'scant', 'zapped', 'nemesis', 'expel', 'unfairly', 'goofy', 'bragger', 'so-cal', 'accidental', 'disgusted', 'lure', 'detestable', 'error', 'back-logged', 'fugitive', 'grapple', 'soreness', 'acridness', 'worry', 'malevolence', 'discourteous', 'begging', 'contend', 'imprecisely', 'skulk', 'disingenuously', 'dies', 'wallow', 'declaim', 'foully', 'repugnance', 'miscreants', 'absurdly', 'demonizes', 'provocative', 'blind', 'chintzy', 'mocks', 'mawkishness', 'mourner', 'smut', 'punish', 'unlamentably', 'unjustly', 'cold', 'harass', 'dissatisfies', 'liar', 'desiccated', 'abuses', 'mists', 'thug', 'deter', 'baffling', 'lambaste', 'pest', 'fastidious', 'cataclysm', 'frigging', 'spurn', 'anti-occupation', 'debilitate', 'fanciful', 'strut', 'frighten', 'paupers', 'impetuous', 'warlike', 'eccentric', 'flaking', 'discoutinous', 'worries', 'hate', 'incoherence', 'upsettingly', 'nightmarish', 'annoying', 'squeal', 'insecurity', 'lawless', 'snob', 'uncertain', 'aghast', 'weaken', 'disinterested', 'imposing', 'erodes', 'impudence', 'domineer', 'ambivalent', 'illusory', 'blab', 'distains', 'graft', 'imperfections', 'incompatability', 'screw-up', 'hell', 'jitters', 'obscurity', 'leak', 'strictly', 'thirst', 'threesome', 'clog', 'bewilderment', 'bungling', 'desperation', 'panicking', 'inadequately', 'forlornly', 'scaly', 'little-known', 'prate', 'unacceptablely', 'warp', 'deplorably', 'stiflingly', 'unilateralism', 'sass', 'shrill', 'obstructing', 'unprepared', 'touted', 'imprisonment', 'bloody', 'vex', 'incomparably', 'vexingly', 'inarticulate', 'ridicule', 'damper', 'overstated', 'slashing', 'stupidest', 'rantingly', 'inhumanity', 'disgusting', 'convoluted', 'wicked', 'seethe', 'occluded', 'rhapsodize', 'denied', 'grumpier', 'resentment', 'mistrust', 'grouchy', 'nauseating', 'spitefulness', 'avarice', 'fussy', 'wastefulness', 'disappoint', 'rhetorical', 'erratically', 'abort', 'incorrigibly', 'dents', 'gutless', 'breaks', 'contaminate', 'dubiously', 'servitude', 'trivial', 'lengthy', 'gloatingly', 'lull', 'swipe', 'bickering', 'beseech', 'watered-down', 'meager', 'maladjusted', 'stupified', 'hardheaded', 'pompous', 'torment', 'hostile', 'alarming', 'biased', 'devastatingly', 'exhausts', 'complex', 'rage', 'whiny', 'worn', 'displeasing', 'overstatement', 'havoc', 'ploy', 'recant', 'hateful', 'restricted', 'appallingly', 'retardedness', 'divisively', 'detests', 'childish', 'jeering', 'loathly', 'flake', 'imperious', 'decadent', 'bore', 'sued', 'spooky', 'scapegoat', 'nettle', 'shrug', 'bent', 'inconceivably', 'forceful', 'drastic', 'incredulously', 'nightmarishly', 'nauseatingly', 'criticism', 'superficial', 'dazed', 'bemoan', 'mispronounce', 'angry', 'offender', 'growl', 'implicate', 'screwed', 'blur', 'contravene', 'travesty', 'busts', 'floundering', 'insinuation', 'irreconcilable', 'onslaught', 'foreboding', 'fractious', 'scarred', 'uncaring', 'posturing', 'traumatized', 'frictions', 'shortness', 'tragedy', 'insidious', 'culpable', 'hostage', 'life-threatening', 'sardonic', 'bumping', 'knotted', 'hatefully', 'scoff', 'mindless', 'vice', 'warned', 'hopelessly', 'abrasive', 'corrupt', 'wild', 'dogged', 'hopelessness', 'cynicism', 'niggle', 'pig', 'melancholy', 'contamination', 'critics', 'miscellaneous', 'inexcusable', 'complicated', 'hassles', 'stumped', 'unable', 'unimportant', 'humming', 'untenable', 'dumb', 'disrespectfully', 'abominable', 'unsettle', 'shameful', 'hogs', 'dispiriting', 'heinous', 'sidetrack', 'donside', 'refutation', 'god-awful', 'shipwreck', 'darkness', 'disregard', 'irregularity', 'pretence', 'stalemate', 'subversively', 'worriedly', 'infamously', 'grimace', 'dizzingly', 'imminence', 'fluster', 'mad', 'obsessively', 'resignation', 'prideful', 'detracted', 'reactionary', 'tamper', 'disappoints', 'disregardful', 'incorrigible', 'inflammatory', 'pricier', 'prosecute', 'inefficient', 'shit', 'inflationary', 'devilry', 'complacent', 'defame', 'disparaging', 'dispute', 'insincere', 'extraneous', 'smokescreen', 'bothers', 'extinguish', 'uncomfortably', 'intransigent', 'simplistic', 'ironical', 'unwelcome', 'heretic', 'fruitless', 'regress', 'errors', 'extravagantly', 'restrict', 'illegally', 'lie', 'lugubrious', 'overstates', 'silly', 'slog', 'aversion', 'sneeringly', 'f**k', 'vengeful', 'warily', 'abomination', 'creeps', 'musty', 'subjugation', 'alarmingly', 'infuriated', 'wimpy', 'grumble', 'castigate', 'complicit', 'infringe', 'blindside', 'confounded', 'mawkish', 'perplex', 'dishearteningly', 'misleadingly', 'evasion', 'run-down', 'inimical', 'remorseless', 'struggling', 'bully', 'dud', 'irksomely', 'martyrdom-seeking', 'overplay', 'fatty', 'revoke', 'desolate', 'disturbed', 'bedlam', 'exhorbitant', 'fracture', 'screech', 'incorrect', 'cutthroat', 'disinterest', 'exasperate', 'drop-out', 'parasite', 'blotchy', 'pointless', 'bugs', 'ineptly', 'brutalities', 'lewdness', 'procrastinates', 'unscrupulously', 'inconvenience', 'infidel', 'overstate', 'paradoxically', 'unbearablely', 'blandish', 'emergency', 'madness', 'fiction', 'chatterbox', 'poorest', 'involuntary', 'ultimatum', 'sardonically', 'horrified', 'imprudent', 'lags', 'over-acted', 'spoon-feed', 'invader', 'damnably', 'delusion', 'admonishingly', 'authoritarian', 'hardened', 'intimidating', 'irragularity', 'halfhearted', 'miff', 'overdue', 'nervousness', 'crummy', 'outcry', 'skeptically', 'fleeting', 'angrily', 'contrariness', 'ferociously', 'commotion', 'spite', 'deformed', 'spoilages', 'unhappily', 'confuse', 'irrecoverableness', 'nitpick', 'friggin', 'boisterous', 'adulterated', 'perfunctory', 'recalcitrant', 'truant', 'inextricably', 'feebleminded', 'irritably', 'repugnantly', 'lechery', 'passe', 'exhaustion', 'reluctantly', 'uncooperative', 'abnormal', 'dissembler', 'rejection', 'petrified', 'obscene', 'unviewable', 'lier', 'struggled', 'cracked', 'tricky', 'delude', 'accusations', 'douchbag', 'pity', 'drippy', 'overreach', 'callous', 'concede', 'fanatic', 'gape', 'mudslinger', 'smear', 'unwise', 'contrive', 'bankrupt', 'malevolent', 'disagrees', 'ignorance', 'pervasive', 'irrelevance', 'deploringly', 'bumps', 'clunky', 'divergent', 'hamper', 'insufficiency', 'falls', 'laconic', 'exploitation', 'stymied', 'unfavorable', 'disunity', 'whine', 'evildoer', 'concession', 'clamor', 'liable', 'contradiction', 'disintegrate', 'malodorous', 'overbearingly', 'shortage', 'barren', 'ruthlessly', 'stereotypical', 'distressingly', 'dirtbags', 'farce', 'disillusion', 'fumble', 'rocky', 'strident', 'stutters', 'phobia', 'awkward', 'outlaw', 'indiscernible', 'dismissive', 'pitilessly', 'punch', 'insupportable', 'disapointing', 'abruptly', 'impious', 'destroyer', 'errant', 'flakey', 'unsatisfactory', 'wreaks', 'fret', 'misunderstanding', 'dictatorial', 'lag', 'improbability', 'irked', 'selfishly', 'unusual', 'regretfully', 'lethal', 'hegemonistic', 'unconvincingly', 'unequal', 'denunciate', 'frantically', 'misread', 'cheapen', 'dissatisfactory', 'fume', 'incomprehension', 'malicious', 'mangling', 'snobbish', 'disaffected', 'felonious', 'raving', 'whips', 'befoul', 'limits', 'traped', 'greed', 'helplessly', 'jarring', 'overheat', 'concerns', 'disadvantaged', 'villains', 'whining', 'wreak', 'dismayingly', 'fell', 'petty', 'sorry', 'agonize', 'anxiety', 'commonplace', 'disillusionment', 'manic', 'discomfititure', 'fierce', 'byzantine', 'discombobulate', 'explosive', 'glibly', 'overwhelming', 'acrid', 'idiotic', 'lemon', 'oppressors', 'irksomenesses', 'addicting', 'audacious', 'gauche', 'rail', 'spotty', 'dull', 'aggravation', 'tainted', 'anguish', 'traitorously', 'discontinued', 'outmoded', 'kills', 'unwillingly', 'abusive', 'dizzy', 'sloooow', 'inelegance', 'murky', 'entanglement', 'enemies', 'inextricable', 'ruinous', 'protesting', 'tingled', 'vibrates', 'grief', 'obstructs', 'gravely', 'goad', 'sully', 'scarier', 'harsh', 'troublingly', 'intractable', 'gruff', 'smugly', 'abuse', 'shockingly', 'underlings', 'timidity', 'poison', 'cautionary', 'gaudy', 'noise', 'defy', 'conspicuous', 'outbreak', 'wrongful', 'suffocate', 'irredeemable', 'frightfully', 'anarchist', 'selfishness', 'inexpertly', 'caustic', 'scarcely', 'snag', 'sugar-coated', 'traumatic', 'worryingly', 'molestation', 'difficulties', 'wayward', 'smoldering', 'troublesomely', 'assail', 'obscenity', 'calamities', 'bulkyness', 'exasperatingly', 'irrationals', 'junky', 'misunderstandings', 'fascist', 'killing', 'undetermined', 'rebuke', 'weep', 'fickle', 'effrontery', 'mistakes', 'omission', 'defamatory', 'ripped', 'damn', 'reviled', 'partiality', 'throbbed', 'ached', 'enviously', 'bland', 'evade', 'discomfort', 'objectionable', 'depraved', 'craze', 'despicable', 'incomparable', 'nagging', 'scoldingly', 'sufferers', 'skimpy', 'ghetto', 'gloomy', 'maniacal', 'overpriced', 'gaffe', 'repulsiveness', 'sag', 'irritations', 'two-faced', 'sporadic', 'taut', 'cramp', 'sneer', 'protested', 'sobering', 'isolate', 'dumps', 'lacks', 'interferes', 'scornfully', 'swelled', 'battering', 'regret', 'corruption', 'indecent', 'unprove', 'threatening', 'undecided', 'resurgent', 'incredulous', 'sweaty', 'feeble', 'ranting', 'vibration', 'creepy', 'overemphasize', 'confound', 'ricer', 'beggarly', 'audacity', 'insult', 'stuttering', 'fretful', 'grotesque', 'profane', 'steeply', 'ambush', 'sorrowful', 'futility', 'hated', 'jeopardize', 'petrify', 'shroud', 'stunt', 'disgraceful', 'stiffness', 'irrecoverably', 'accusingly', 'egotistical', 'smelling', 'slave', 'militancy', 'wrinkle', 'rigidity', 'garbage', 'shortsighted', 'inadequacy', 'unaffordable', 'worrisome', 'gracelessly', 'cravenly', 'fevers', 'deluge', 'detract', 'detriment', 'creeping', 'discriminatory', 'grumpy', 'hefty', 'hells', 'ineffectiveness', 'victimize', 'egomania', 'flabbergasted', 'deviate', 'anti-semites', 'ludicrous', 'dungeon', 'beastly', 'inadvisable', 'needless', 'crack', 'squeals', 'condemnable', 'instigators', 'nonresponsive', 'hobble', 'prevaricate', 'prison', 'stooges', 'inconsequentially', 'degrade', 'indefensible', 'unrest', 'floored', 'irrational', 'regrettably', 'toil', 'guile', 'hardball', 'hapless', 'devilish', 'cringe', 'hotheaded', 'propaganda', 'backbite', 'grind', 'inaccurate', 'uneasy', 'relentless', 'degeneration', 'overkill', 'rile', 'hissing', 'crabby', 'lividly', 'plagiarize', 'stringently', 'unprofitable', 'fatalistically', 'destruction', 'disbelieve', 'denial', 'distastefully', 'incompetence', 'crumpled', 'discontented', 'misbehave', 'mistrustful', 'asinininity', 'preposterous', 'remorseful', 'alarmed', 'lapses', 'concessions', 'congested', 'embarrassing', 'redundancy', 'obstacle', 'indoctrinate', 'oddity', 'scramble', 'pugnacious', 'uproariously', 'shrivel', 'inordinately', 'falsify', 'destroy', 'pique', 'undid', 'impatient', 'fury', 'traumatically', 'inglorious', 'scornful', 'distressed', 'dusty', 'failures', 'gruesomely', 'skeletons', 'martyrdom', 'reprehensible', 'implausibly', 'annoy', 'languish', 'immorality', 'spoonfed', 'jealousy', 'stupid', 'wail', 'castrated', 'mistakenly', 'repulsive', 'ineffective', 'pimple', 'tediously', 'unwatchable', 'heck', 'oppress', 'taunts', 'afflict', 'misunderstood', 'sagged', 'mock', 'retaliatory', 'hazy', 'overblown', 'scathing', 'evasive', 'oversight', 'staid', 'shimmy', 'frustration', 'contemptuous', 'barbarian', 'livid', 'tumbled', 'anomalous', 'pillage', 'immodest', 'regretful', 'confusions', 'obstruct', 'strangle', 'fraught', 'unstable', 'craven', 'slow', 'heckles', 'overthrows', 'incense', 'paradoxical', 'severe', 'grievances', 'woebegone', 'dissent', 'leakages', 'overacted', 'messing', 'corrosive', 'aggrieved', 'recoil', 'villianously', 'laughable', 'entrapment', 'intense', 'panick', 'embroilment', 'outburst', 'outcast', 'injurious', 'awfulness', 'lame-duck', 'weak', 'throb', 'forlorn', 'prohibit', 'desiccate', 'subservient', 'infringement', 'spiteful', 'appall', 'startling', 'bravado', 'dastardly', 'admonishment', 'disbeliever', 'scorn', 'sloooooooooooooow', 'inexorable', 'terror-genic', 'ruin', 'rut', 'tormented', 'tyranny', 'breach', 'perversely', 'prick', 'unnatural', 'delusional', 'scandals', 'iniquity', 'embroil', 'melodramatically', 'naïve', 'beware', 'brutalize', 'brazen', 'blunder', 'damning', 'throbbing', 'grumpily', 'bewilder', 'interruptions', 'suffers', 'distraughtly', 'attack', 'failure', 'frustrate', 'disgrace', 'asininely', 'beset', 'besiege', 'apprehensive', 'jerky', 'officious', 'inexplainable', 'mismanage', 'shunned', 'dogmatic', 'ugly', 'helplessness', 'trickery', 'forsaken', 'maniac', 'confounding', 'harassed', 'lunatic', 'hardliner', 'pretend', 'detracting', 'messed', 'disapprobation', 'enraging', 'unwillingness', 'rip', 'manipulators', 'vile', 'heresy', 'grievance', 'counterproductive', 'uproot', 'plasticky', 'spoilage', 'blurs', 'aloof', 'slogging', 'inaccuracy', 'ruining', 'infamous', 'arduous', 'dissuasive', 'despondence', 'loathe', 'noisier', 'inhibition', 'dreadfully', 'slaughtered', 'brainwash', 'anxieties', 'crowded', 'disable', 'doggedly', 'improperly', 'disloyal', 'invidious', 'disappointment', 'aimless', 'illogically', 'cry', 'deceitfulness', 'backaching', 'detestably', 'objection', 'threaten', 'hawkish', 'louder', 'apologists', 'broken', 'insufferable', 'skeptical', 'stubbornly', 'stringent', 'uncompetitive', 'undependability', 'blackmail', 'hates', 'chore', 'stingingly', 'carnage', 'disapointment', 'disapproving', 'worsen', 'predicament', 'faithless', 'achey', 'deplore', 'irritating', 'left-leaning', 'obstructed', 'picketing', 'scandalous', 'pandemonium', 'ruffian', 'latency', 'deficient', 'discontinuous', 'violently', 'implication', 'picket', 'wobble', 'mistake', 'wobbled', 'burn', 'critical', 'self-serving', 'mocking', 'unconstitutional', 'maliciously', 'hysterics', 'indecorum', 'acrimoniously', 'washed-out', 'corrosion', 'entrap', 'absurdity', 'mortify', 'fallacious', 'vomited', 'coward', 'pointlessly', 'fuzzy', 'bonkers', 'dishonorable', 'concens', 'anger', 'insubordinate', 'flare', 'jaded', 'berate', 'inconceivable', 'outraged', 'flawed', 'blurred', 'unknown', 'hedge', 'renunciation', 'glitches', 'baseless', 'hurtful', 'sermonize', 'shriek', 'degradingly', 'bumped', 'discomfit', 'unfaithfully', 'undercutting', 'nosey', 'retreat', 'defect', 'coarse', 'spookily', 'avalanche', 'pigs', 'pillory', 'ugliness', 'acerbic', 'stereotype', 'deplorable', 'dubitable', 'exagerated', 'blah', 'damned', 'expropriation', 'compulsive', 'sneakily', 'slowww', 'quibbles', 'cancer', 'odor', 'incitement', 'criticizing', 'defile', 'hustler', 'capsize', 'dumped', 'falsely', 'corrupting', 'irresponsibly', 'subversive', 'irksome', 'heartless', 'swagger', 'uninformed', 'unnecessary', 'deploring', 'feverish', 'suck', 'unbearable', 'wily', 'disorganized', 'impolitely', 'mistrustfully', 'oddest', 'dauntingly', 'hideousness', 'manipulation', 'leer', 'ironically', 'lovelorn', 'short-lived', 'sickness', 'drab', 'stress', 'disobedient', 'plot', 'stinks', 'pry', 'assassin', 'incompatibility', 'unfriendly', 'dawdle', 'farcical-yet-provocative', 'wounds', 'pervert', 'painfully', 'inconsolably', 'fatally', 'alienate', 'smuttiest', 'nebulous', 'swelling', 'dissenter', 'back-woods', 'poorly', 'preoccupy', 'unqualified', 'denounce', 'wreaked', 'snobby', 'dissappointing', 'naive', 'unconfirmed', 'dissonantly', 'forbidding', '2-faces', 'cruelties', 'jagged', 'bull----', 'allergic', 'leaky', 'uncompromisingly', 'leakage', 'dupe', 'leaking', 'imbecile', 'implausible', 'oversimplify', 'dearth', 'clogs', 'inequitably', 'loathing', 'pernicious', 'shimmer', 'unusually', 'massacres', 'laughingstock', 'high-priced', 'slower', 'meanness', 'dangerousness', 'crime', 'delirium', 'snarl', 'douchebag', 'quitter', 'drowning', 'geezer', 'stumble', 'unjustifiable', 'stodgy', 'lech', 'savaged', 'hating', 'din', 'ripoff', 'compulsion', 'dilemma', 'extermination', 'pitiless', 'rigidness', 'inescapably', 'exhausted', 'confined', 'acridly', 'forgetfulness', 'misuse', 'worse', 'pittance', 'vociferously', 'buggy', 'harridan', 'horrifying', 'misbehavior', 'inhumane', 'disoriented', 'chagrin', 'beguile', 'immature', 'impolite', 'licentious', 'headaches', 'overwhelm', 'seedy', 'shrilly', 'vehement', 'demoralizingly', 'burdensomely', 'unorthodox', 'irrationality', 'insolent', 'satirical', 'fear', 'lambast', 'unproven', 'oppression', 'blameworthy', 'disservice', 'bewildering', 'bristle', 'aborted', 'quarrels', 'inculcate', 'fundamentalism', 'shamelessly', 'bump', 'outrages', 'menacingly', 'gross', 'diss', 'starvation', 'terribleness', 'deluded', 'assassinate', 'debaucher', 'coerce', 'disconcert', 'unintelligile', 'confront', 'atrocity', 'warning', 'blurt', 'denies', 'eccentricity', 'infidels', 'attacks', 'oppressive', 'unsupported', 'insignificance', 'farcical', 'adversarial', 'missed', 'monstrosities', 'humiliate', 'unfunded', 'bigotry', 'illusion', 'mordant', 'slaves', 'strenuous', 'ignominiously', 'hassle', 'fleeing', 'impending', 'undue', 'facetiously', 'debt', 'derisive', 'misreading', 'disarray', 'adamant', 'downhill', 'apocalyptic', 'nefarious', 'dissension', 'agony', 'forfeit', 'beg', 'fallaciously', 'hung', 'snagged', 'virus', 'drunk', 'jeer', 'trapped', 'moron', 'anti-american', 'unpleasantries', 'horrifys', 'displeased', 'trouble', 'cheated', 'retard', 'illiterate', 'payback', 'recklessness', 'revulsion', 'shrew', 'fraud', 'wripping', 'despised', 'get-rich', 'zaps', 'dissident', 'inequitable', 'asinine', 'aweful', 'unproving', 'self-coup', 'wiles', 'limit', 'barbarously', 'cheats', 'demeaning', 'diatribe', 'miserableness', 'harassment', 'desperately', 'alarm', 'bad', 'shiver', 'shortsightedness', 'deject', 'randomly', 'blockhead', 'calamitously', 'combust', 'egotism', 'fidgety', 'hestitant', 'hotbeds', 'misinterpret', 'hard-line', 'confuses', 'ingrate', 'sick', 'parody', 'hiliarious', 'perilous', 'vengeance', 'boggle', 'deplete', 'noisy', 'torturous', 'abominably', 'infections', 'perplexed', 'depressions', 'cataclysmal', 'roadblocks', 'indignation', 'harboring', 'ill-formed', 'misery', 'dissention', 'misdirection', 'shortchange', 'hollow', 'aspersions', 'impermissible', 'disastrous', 'aggressiveness', 'insulting', 'bestial', 'brute', 'ho-hum', 'falsehood', 'erase', 'malady', 'unspeakable', 'fustigate', 'anemic', 'irredeemably', 'conflict', 'blasted', 'inconstant', 'deadlock', 'somber', 'bondage', 'inflict', 'unmoved', 'ungovernable', 'horrendously', 'incompetent', 'inescapable', 'jitter', 'obliterated', 'pratfall', 'puny', 'scolding', 'tingling', 'vomit', 'biting', 'repulsively', 'stubborn', 'swollen', 'wane', 'weird', 'shrouded', 'discouraging', 'excessive', 'nastiness', 'lacking', 'vindictively', 'gibberish', 'dissocial', 'cackle', 'brittle', 'crumbling', 'mangled', 'skeptic', 'figurehead', 'risk', 'savages', 'gimmicked', 'inimically', 'inoperable', 'repulsing', 'vexation', 'asunder', 'rumours', 'stormy', 'chastisement', 'leery', 'full-blown', 'mindlessly', 'reproach', 'endanger', 'mashed', 'awfully', 'disinclination', 'cringed', 'defrauding', 'demonizing', 'hairloss', 'backwardness', 'frustrated', 'inclement', 'craps', 'opponent', 'shady', 'drag', 'spookiest', 'abolish', 'horrify', 'obscure', 'insincerely', 'crazy', 'ailing', 'squeaky', 'foolishness', 'insensible', 'sunken', 'backwoods', 'violate', 'weed', 'draconian', 'puzzled', 'intimidation', 'revert', 'ill-treatment', 'self-interest', 'weirdly', 'lamentable', 'untrustworthy', 'failed', 'stole', 'vagrant', 'crept', 'clamorous', 'thoughtlessly', 'mystery', 'stumbled', 'galling', 'bomb', 'complained', 'smallish', 'stigmatize', 'retreated', 'affliction', 'irately', 'inequality', 'notoriety', 'rogue', 'cursed', 'bull****', 'pitiable', 'morbidly', 'over-hyped', 'scarcity', 'swamped', 'disvalue', 'imposition', 'tarnish', 'gimmick', 'irritation', 'overloaded', 'scar', 'dishearten', 'killjoy', 'stingy', 'inconsistency', 'undermines', 'mirage', 'smack', 'smell', 'disarm', 'straining', 'waning', 'huckster', 'tangles', 'envious', 'encroach', 'impossibly', 'worst', 'ailment', 'disabled', 'impair', 'melodramatic', 'despoil', 'bleakness', 'loud', 'rattle', 'shame', 'splatter', 'repulsed', 'resistance', 'subpoena', 'unworkable', 'molest', 'inanely', 'autocratic', 'despairing', 'loses', 'ominous', 'stuttered', 'itching', 'despise', 'adamantly', 'exterminate', 'viciously', 'skittishly', 'hypocritically', 'disadvantage', 'creaks', 'cancerous', 'nefariously', 'bugging', 'perish', 'stagnate', 'disapointed', 'invalidate', 'debts', 'grudging', 'torturously', 'burning', 'malignant', 'detrimental', 'pertinacity', 'scared', 'injustice', 'despot', 'standstill', 'indigent', 'greasy', 'freaking', 'annoyingly', 'messy', 'villify', 'fearful', 'ordeal', 'less-developed', 'dropouts', 'unreliable', 'debauchery', 'disavowal', 'unfulfilled', 'wary', 'debilitating', 'loath', 'boil', 'nitpicking', 'noises', 'rascals', 'bombardment', 'disagreeably', 'contaminates', 'emphatic', 'inefficiency', 'detracts', 'quarrelsome', 'concern', 'pedantic', 'fictional', 'perversion', 'delayed', 'underestimate', 'snobish', 'fanaticism', 'stridently', 'strife', 'smother', 'dislocated', 'hinder', 'inhospitable', 'mangle', 'trash', 'whore', 'bizarre', 'sucks', 'overrun', 'cruelly', 'hubris', 'buckle', 'burden', 'election-rigger', 'impediment', 'bereavement', 'incessantly', 'stumbles', 'slander', 'distrustful', 'inefficiently', 'acerbate', 'shamelessness', 'shallow', 'glib', 'absurdness', 'revulsive', 'oppositions', 'tyrant', 'sadden', 'scorching', 'unusable', 'scoundrel', 'turmoil', 'irascible', 'moody', 'odder', 'daunting', 'indiscriminate', 'disappointments', 'ill-conceived', 'ill-used', 'fatigue', 'entangle', 'hysteria', 'inelegant', 'plaything', 'hedonistic', 'jittery', 'scorchingly', 'atrocities', 'mispronounced', 'flareup', 'miserable', 'cumbersome', 'selfinterested', 'slack', 'indecency', 'hell-bent', 'spilling', 'frighteningly', 'kaput', 'thoughtless', 'zealot', 'disgustfully', 'ineloquently', 'misapprehend', 'egregiously', 'franticly', 'exagerates', 'impaired', 'overpower', 'scourge', 'sin', 'offensive', 'virulently', 'nettlesome', 'time-consuming', 'jeeringly', 'deficiencies', 'confrontational', 'disoobedient', 'dispensable', 'enraged', 'mystify', 'hissed', 'risks', 'scam', 'appalled', 'shocked', 'ail', 'mercilessly', 'trample', 'dehumanize', 'grudgingly', 'shark', 'pan', 'confusing', 'sarcastic', 'distortion', 'obsessiveness', 'troubling', 'self-destructive', 'busybody', 'death', 'scratch', 'shatter', 'monstrosity', 'symptoms', 'afflictive', 'mistress', 'askance', 'calumnious', 'betrays', 'intefere', 'antiquated', 'lifeless', 'jaundiced', 'wanton', 'gallingly', 'subjugate', 'demoralize', 'inconsiderate', 'inundate', 'mysterious', 'lone', 'insinuating', 'vainly', 'unaccessible', 'whimper', 'distraughtness', 'freakishly', 'haters', 'disintegrates', 'deprave', 'lewdly', 'scars', 'expulse', 'embroiled', 'hatred', 'negate', 'prejudices', 'nonsense', 'devastating', 'peeled', 'unjustifiably', 'inflammed', 'fall', 'weakness', 'bothersome', 'clique', 'annihilation', 'bafflement', 'gawky', 'unsure', 'batty', 'catastrophes', 'peevishly', 'repudiate', 'dim', 'problem', 'brashness', 'indignant', 'hypocrites', 'mortified', 'ruthless', 'blow', 'dings', 'underpowered', 'wilt', 'bullies', 'erode', 'thicker', 'ache', 'notorious', 'rankle', 'crisis', 'marginally', 'sink', 'unsettled', 'misbecoming', 'defamation', 'ambivalence', 'distress', 'mist', 'twists', 'violation', 'mishap', 'blister', 'condemnation', 'intimidate', 'conflicting', 'mulish', 'violator', 'stall', 'cramped', 'spade', 'ashamed', 'ominously', 'debatable', 'exile', 'ironies', 'kill', 'unexpectedly', 'long-winded', 'indeterminable', 'flakieness', 'famished', 'tepid', 'detested', 'abrade', 'excruciating', 'bullyingly', 'restless', 'undependable', 'pales', 'austere', 'conflicted', 'instigate', 'miserly', 'ineffectualness', 'intransigence', 'disdain', 'unsettling', 'foolhardy', 'outrage', 'deception', 'inexpert', 'lack', 'detest', 'boycott', 'dripping', 'massacre', 'repress', 'ghosting', 'longingly', 'overact', 'shamefully', 'devastates', 'misfortune', 'die-hard', 'dismissively', 'hardships', 'poky', 'pathetic', 'hangs', 'procrastination', 'bashed', 'explode', 'devious', 'limitations', 'unsecure', 'sever', 'dissonance', 'snarky', 'leaks', 'capricious', 'aggravate', 'downhearted', 'disturbance', 'feeblely', 'horrid', 'infested', 'torrent', 'unfamiliar', 'uneasily', 'damaging', 'malice', 'starkly', 'ruins', 'unwilling', 'sucky', 'spinster', 'unpredictable', 'corrode', 'admonisher', 'twisted', 'bashful', 'transgression', 'weary', 'sham', 'slap', 'wretched', 'importune', 'resigned', 'lose', 'cash-strapped', 'devoid', 'queer', 'unexpected', 'filthy', 'goading', 'sinisterly', 'succumb', 'sketchy', 'tramp', 'rival', 'listless', 'gutter', 'terribly', 'besmirch', 'coercive', 'degenerately', 'disobedience', 'forgetful', 'timidly', 'unlamentable', 'vengefully', 'prohibitive', 'raked', 'freaks', 'tragically', 'dungeons', 'critic', 'culprit', 'miser', 'tanks', 'oversimplification', 'quandary', 'ruined', 'maledict', 'naughty', 'over-awe', 'shadowy', 'touchy', 'displaced', 'menacing', 'deceitfully', 'layoff', 'frightful', 'overpayed', 'smoke', 'decrepitude', 'polluters', 'impudent', 'uncomfortable', 'disaffirm', 'calumniously', 'slut', 'zombie', 'boiling', 'indiscriminating', 'profanity', 'smudge', 'monotony', 'uninsured', 'unhelpful', 'dispiritedly', 'freezing', 'indiscreet', 'assult', 'jealous', 'unfounded', 'unfeeling', 'fanatics', 'greedy', 'villainous', 'dunce', 'devil', 'disillusions', 'fuck', 'deceit', 'atrocious', 'improper', 'mobster', 'overbalanced', 'stench', 'tired', 'impolitic', 'conceded', 'crippled', 'mistaken', 'ill-treated', 'falling', 'repugnant', 'bluring', 'faint', 'disrespecting', 'disorderly', 'hum', 'oblique', 'clueless', 'deteriorating', 'bicker', 'negativity', 'ramshackle', 'uproarously', 'zealously', 'ungrateful', 'anxiousness', 'demonized', 'unneeded', 'smutty', 'catastrophic', 'wrangle', 'upbraid', 'ferocity', 'terrorize', 'pitifully', 'slime', 'regressive', 'loathsome', 'malign', 'denunciation', 'opinionated', 'overawe', 'disorient', 'brat', 'pinch', 'fright', 'feint', 'freezes', 'banalize', 'unhappy', 'unrelenting', 'wariness', 'fastidiously', 'irony', 'bs', 'derisively', 'immoral', 'froze', 'uncreative', 'undefined', 'depressing', 'doldrums', 'dumping', 'lecher', 'agonizing', 'admonition', 'usurp', 'reprehension', 'overwhelmed', 'rebuff', 'ugliest', 'hopeless', 'troublemaker', 'disillusioned', 'backbiting', 'self-humiliation', 'scummy', 'bruise', 'disputed', 'drunkard', 'squirm', 'surrender', 'fatique', 'irrationalities', 'deform', 'hindrance', 'retaliate', 'spoils', 'unpleasant', 'deprecate', 'guilt', 'lumpy', 'graceless', 'tortures', 'unclean', 'mediocre', 'disfavor', 'sabotage', 'mordantly', 'appalling', 'flicering', 'contort', 'unreliability', 'tumultuous', 'annoyed', 'rough', 'inconveniently', 'frazzle', 'hatefulness', 'denying', 'misaligned', 'suspicious', 'forged', 'grouse', 'radicalization', 'unhappiness', 'limp', 'irking', 'drains', 'indecision', 'multi-polarization', 'smelled', 'catastrophically', 'lurch', 'wrinkles', 'allege', 'delinquent', 'indulge', 'panders', 'woefully', 'inundated', 'regrets', 'inconsequent', 'irrelevant', 'indecisive', 'last-ditch', 'long-time', 'strangely', 'downgrade', 'tentative', 'thwart', 'frustrating', 'freak', 'sags', 'stooge', 'spewing', 'prohibitively', 'rollercoaster', 'casualty', 'simplistically', 'invalid', 'stutter', 'destructive', 'anti-', 'unworthy', 'immorally', 'traitor', 'inconsequential', 'flirty', 'freeze', 'unacceptably', 'dullard', 'inferior', 'haphazard', 'precipitous', 'depressingly', 'oddities', 'caustically', 'inapt', 'proprietary', 'inappropriate', 'hegemonism', 'jeers', 'tin-y', 'whores', 'inconsolable', 'conceit', 'disaster', 'overzealously', 'disapprove', 'cheerless', 'painfull', 'refusal', 'upset', 'irrecoverable', 'cheat', 'sucked', 'dishonest', 'lawbreaking', 'flaw', 'animosity', 'stigma', 'peculiar', 'unjustified', 'pricey', 'appal', 'stressful', 'extremist', 'over-valuation', 'aches', 'hypocrite', 'scare', 'awful', 'uncivil', 'adulterier', 'dent', 'carp', 'dilapidated', 'banishment', 'knave', 'murderously', 'vomiting', 'horrific', 'downer', 'glum', 'excuse', 'divisiveness', 'unbelievably', 'dire', 'ineffectively', 'pain', 'questionable', 'bogus', 'embattled', 'fabricate', 'hysteric', 'blunt', 'insolvent', 'suspiciously', 'criticized', 'disappointed', 'itchy', 'lazy', 'grieving', 'issue', 'erroneously', 'fucking', 'boring', 'debaser', 'fault', 'licentiousness', 'loophole', 'vanity', 'hang', 'unraveled', 'cheater', 'clash', 'cliched', 'hack', 'elimination', 'baffled', 'negligence', 'offenses', 'prejudicial', 'dick', 'fragile', 'perfidity', 'secretive', 'shemale', 'interrupt', 'vulnerable', 'distorted', 'stricken', 'morons', 'idle', 'sputter', 'remorse', 'clouding', 'irreparable', 'macabre', 'loot', 'naively', 'exagerate', 'denunciations', 'motionless', 'overdone', 'shake', 'estranged', 'unreadable', 'bereave', 'sluggish', 'inconsiderately', 'calumny', 'farcically', 'vociferous', 'inflated', 'cracks', 'futile', 'collapse', 'desititute', 'enrage', 'miscreant', 'calumnies', 'satirize', 'condescendingly', 'dirts', 'lawlessness', 'stampede', 'barbaric', 'diffidence', 'flares', 'weaknesses', 'disapproval', 'superfluous', 'erroneous', 'incendiary', 'subvert', 'decline', 'intermittent', 'chastise', 'splitting', 'unlicensed', 'iniquitous', 'disconcertingly', 'gritty', 'bungler', 'debility', 'illusions', 'slowwww', 'unsuspecting', 'weaker', 'worrier', 'stupidity', 'pauper', 'treacherous', 'resentful', 'morbid', 'instability', 'pains', 'shaky', 'miscalculation', 'apathetic', 'fist', 'debauch', 'forswear', 'foulness', 'boastful', 'hideously', 'exacerbate', 'fanatical', 'nauseates', 'paralyzed', 'squabbling', 'unnoticed', 'complaints', 'bewilderingly', 'ill-advised', 'outrageousness', 'punk', 'wasteful', 'dragged', 'derogatory', 'offending', 'paranoia', 'sack', 'hypocritical', 'conspiracy', 'disbelief', 'confusion', 'non-confidence', 'feign', 'decry', 'execrate', 'dissatisfy', 'expire', 'misalign', 'moribund', 'recessionary', 'crappy', 'haywire', 'ignominy', 'worrying', 'glaringly', 'astray', 'harpy', 'unlawfulness', 'apprehensively', 'checkered', 'doubts', 'corruptted', 'defensive', 'despoiler', 'unachievable', 'crass', 'mischievously', 'unwisely', 'despairingly', 'distressing', 'finicky', 'pleas', 'disclaim', 'panicked', 'accuse', 'scum', 'imprecision', 'insinuate', 'fuss', 'rape', 'stealing', 'noxious', 'sickeningly', 'bemoaning', 'cranky', 'infernal', 'outrageous', 'awkwardness', 'marginal', 'dissidents', 'plotters', 'discordant', 'ineloquent', 'regression', 'disparagingly', 'fawningly', 'ruffle', 'quash', 'unlikely', 'vibrated', 'drop-outs', 'sadness', 'lethargy', 'pessimistically', 'inaptitude', 'nag', 'insouciance', 'sickly', 'subpoenas', 'top-heavy', 'inflame', 'fulminate', 'letch', 'insurrection', 'pertinacious', 'unleash', 'unspecified', 'dead', 'spook', 'mislike', 'writhe', 'phobic', 'unattractive', 'punishable', 'crumple', 'radically', 'irks', 'gabble', 'disquieting'}, 'wneg': {'expropriate', 'frozen', 'graft', 'strenuous', 'crumble', 'indistinctive', 'leak', 'viper', 'clog', 'inadequately', 'illegal', 'infest', 'warp', 'unsteady', 'forfeit', 'insufficiently', 'least', 'taxing', 'unprepared', 'broke', 'differ', 'bloody', 'imprisonment', 'incomparably', 'block', 'expedient', 'inhibit', 'risky', 'wound', 'trouble', 'negative', 'inexact', 'illiterate', 'retard', 'dwindle', 'tardy', 'tempest', 'fraud', 'rhapsodize', 'tortured', 'unavoidably', 'unaccustomed', 'fiat', 'unsustainable', 'withhold', 'wastefulness', 'limit', 'imperfectly', 'alarm', 'cursory', 'screw', 'division', 'contaminate', 'stump', 'abandon', 'sick', 'exclude', 'lull', 'negation', 'dash', 'hard-hit', 'perilous', 'deviation', 'hostile', 'ineffectual', 'deplete', 'strain', 'noisy', 'complex', 'worn', 'immobilized', 'negligible', 'spot', 'detraction', 'lapse', 'expediencies', 'insurmountable', 'restricted', 'retract', 'solemn', 'harboring', 'hungry', 'wrong', 'flake', 'repressive', 'impermissible', 'suspicion', 'nettle', 'divide', 'unsteadiness', 'irresolvable', 'bent', 'shrug', 'erase', 'malady', 'adverse', 'forceful', 'anemic', 'tire', 'offence', 'uneven', 'conflict', 'loss', 'demolisher', 'dirty', 'demand', 'quit', 'unmoved', 'deterrent', 'implicate', 'vomit', 'butcher', 'blur', 'syndrome', 'stab', 'wane', 'disintegration', 'onslaught', 'punitive', 'decrease', 'overthrow', 'tragedy', 'restriction', 'pale', 'flagging', 'grill', 'inexperienced', 'hostage', 'life-threatening', 'overturn', 'second-tier', 'war', 'brittle', 'nauseate', 'figurehead', 'risk', 'scandal', 'subjection', 'wild', 'incomplete', 'declining', 'stormy', 'niggle', 'unsuccessfully', 'contamination', 'full-blown', 'wounds', 'repulse', 'harden', 'complicated', 'impoverished', 'unable', 'absentee', 'inclement', 'frigid', 'undo', 'encroachment', 'abolish', 'obscure', 'insensible', 'oversimplified', 'controversial', 'darkness', 'irregularity', 'restrictive', 'shipwreck', 'subversively', 'weed', 'intimidation', 'revert', 'wildly', 'fluster', 'indeterminate', 'resignation', 'stole', 'coping', 'quarrel', 'tamper', 'clamorous', 'uncontrolled', 'steal', 'inefficient', 'compulsory', 'bomb', 'inflationary', 'arguments', 'affliction', 'starve', 'flash', 'jam', 'extraneous', 'extinguish', 'addiction', 'scarcity', 'straggler', 'battered', 'regress', 'tarnish', 'thumb', 'restrict', 'illegally', 'conspiracies', 'alienation', 'lie', 'showdown', 'inconsistency', 'throw', 'devastation', 'disarm', 'fail', 'rhetoric', 'assault', 'unauthentic', 'infiltrator', 'battle', 'encroach', 'impossibly', 'confounded', 'ailment', 'altercation', 'disabled', 'haunt', 'evasion', 'substandard', 'infraction', 'dud', 'repulsed', 'resistance', 'revoke', 'interfere', 'fatty', 'expensive', 'discriminate', 'accountable', 'comedy', 'fracture', 'expose', 'impunity', 'incorrect', 'penalty', 'parasite', 'cancerous', 'inaccuracies', 'pointless', 'hurt', 'fading', 'flashy', 'hegemony', 'isolated', 'malignant', 'infiltrators', 'recession', 'numb', 'ineligible', 'indigent', 'retire', 'dark', 'messy', 'tenuously', 'warped', 'bug', 'fiction', 'frail', 'darken', 'less-developed', 'murderous', 'illiquid', 'involuntary', 'exposed', 'cautious', 'debilitating', 'hostilities', 'unfulfilled', 'juvenile', 'inefficiency', 'invader', 'reservations', 'concern', 'fictional', 'submissive', 'authoritarian', 'maneuver', 'dirt', 'hardened', 'storm', 'disproportionate', 'affectation', 'miff', 'unobserved', 'dislocated', 'racism', 'protracted', 'amputate', 'cut', 'deadly', 'faze', 'infected', 'combative', 'overrun', 'turbulent', 'fleeting', 'recourses', 'buckle', 'jumpy', 'inconclusive', 'stake', 'deformed', 'inefficiently', 'subside', 'shallow', 'incite', 'thrash', 'truant', 'treacherous', 'ineffectually', 'dissolution', 'inexperience', 'totalitarian', 'fatigue', 'entangle', 'exhaustion', 'reluctantly', 'battlefield', 'abnormal', 'thumbs', 'slack', 'bar', 'sober', 'misapprehend', 'damage', 'narrow', 'pedestrian', 'lame', 'uneconomical', 'overpower', 'steep', 'offensive', 'overreach', 'abate', 'bearish', 'confrontational', 'dispensable', 'self-defeating', 'bankrupt', 'impossiblity', 'mystify', 'smear', 'withheld', 'ail', 'peripheral', 'dope', 'subjected', 'divergent', 'extreme', 'pan', 'insufficiency', 'bumpy', 'threat', 'intoxicate', 'flimsy', 'death', 'injure', 'volatile', 'liable', 'concession', 'clamor', 'extort', 'poisonous', 'disintegrate', 'shortage', 'lifeless', 'need', 'moot', 'bulky', 'impersonal', 'dinky', 'fumble', 'rocky', 'symptom', 'urgently', 'inequalities', 'unresolved', 'avoid', 'indiscernible', 'glut', 'loser', 'fight', 'unsatisfactory', 'errant', 'expulse', 'flakey', 'negate', 'cartoon', 'dictatorial', 'avoidance', 'consume', 'indefinitely', 'lag', 'unusual', 'fall', 'junk', 'lethal', 'muddle', 'interruption', 'clique', 'repetitive', 'unsure', 'passive', 'miscalculate', 'defeat', 'dim', 'instable', 'break', 'problem', 'tense', 'murder', 'complicate', 'blow', 'felonious', 'incompatible', 'primitive', 'erode', 'helplessly', 'unsettled', 'crisis', 'disadvantaged', 'marginally', 'twists', 'lessen', 'commonplace', 'violation', 'uprising', 'fierce', 'explosive', 'intimidate', 'fever', 'wrought', 'polution', 'chilly', 'disease', 'inaccessible', 'wreck', 'cramped', 'insignificantly', 'rivalry', 'spotty', 'vanish', 'dull', 'split', 'exile', 'outmoded', 'kill', 'indeterminable', 'unfinished', 'murky', 'tepid', 'entanglement', 'fraudulent', 'captive', 'abrade', 'dominate', 'enemies', 'gnawing', 'restless', 'ruinous', 'choke', 'against', 'tentatively', 'wedge', 'abrupt', 'ineffectualness', 'intractable', 'sounding', 'abuse', 'rigor', 'inexpert', 'skyrocketing', 'boycott', 'diseased', 'fine', 'outbreak', 'insular', 'repress', 'wrongful', 'paralize', 'irregular', 'hectic', 'inexpertly', 'suppress', 'nonexistent', 'rat', 'diminish', 'discrepant', 'repel', 'try', 'difficulties', 'explode', 'assail', 'junky', 'crushing', 'depression', 'sever', 'vagueness', 'weep', 'undetermined', 'feeblely', 'omission', 'unfamiliar', 'infested', 'stagnant', 'bleed', 'felon', 'damaging', 'isolation', 'evade', 'divorce', 'discomfort', 'treacherously', 'incomparable', 'spinster', 'unpredictable', 'corrode', 'skimpy', 'ghetto', 'eliminate', 'imperfect', 'protests', 'transgression', 'orphan', 'weary', 'sag', 'eradicate', 'resigned', 'demolish', 'indistinct', 'knife', 'deaf', 'cash-strapped', 'lose', 'engulf', 'deteriorate', 'queer', 'isolate', 'sporadic', 'unexpected', 'volatility', 'battering', 'sketchy', 'tiny', 'dominance', 'slowly', 'rival', 'miss', 'threatening', 'undecided', 'feeble', 'alienated', 'prohibitive', 'malaise', 'indeterminably', 'menial', 'confound', 'abandoned', 'droop', 'oversimplification', 'fat', 'shadowy', 'steeply', 'slaughter', 'ambush', 'waste', 'stunt', 'barely', 'displaced', 'unavoidable', 'smelling', 'dig', 'adrift', 'tension', 'garbage', 'inadequacy', 'tease', 'headache', 'uncomfortable', 'unclear', 'deluge', 'detract', 'glitch', 'ineffectiveness', 'uninsured', 'discrimination', 'deviate', 'challenge', 'jolt', 'widespread', 'illicit', 'inadvisable', 'needless', 'accost', 'prison', 'subdued', 'hobble', 'less', 'overbalanced', 'hothouse', 'sourly', 'straggle', 'whatever', 'crackdown', 'outsider', 'addict', 'slump', 'faint', 'controversy', 'disorderly', 'challenging', 'oblique', 'deteriorating', 'exacting', 'unneeded', 'unhealthy', 'abjure', 'busy', 'unprofitable', 'inadequate', 'tangled', 'destruction', 'irretrievable', 'regressive', 'topple', 'distract', 'knock', 'pinch', 'scheme', 'overawe', 'icy', 'struck', 'feint', 'harbors', 'underpaid', 'complication', 'concessions', 'congested', 'helpless', 'redundancy', 'transgress', 'vague', 'hazardous', 'destroy', 'pique', 'snatch', 'undefined', 'undid', 'drought', 'fragmented', 'illness', 'dump', 'mope', 'uneventful', 'susceptible', 'dusty', 'failures', 'imprison', 'unproductive', 'artificial', 'odd', 'snare', 'stolen', 'dwindling', 'criminal', 'cow', 'sinking', 'violent', 'endless', 'insignificant', 'stiff', 'ineffective', 'overbalance', 'diminishing', 'afflict', 'bruise', 'finagle', 'retaliatory', 'choppy', 'surrender', 'extremism', 'force', 'deform', 'hazy', 'injury', 'retaliate', 'void', 'evasive', 'handicapped', 'oversight', 'rot', 'lesser-known', 'anomalous', 'obstruct', 'strangle', 'mind', 'sedentary', 'tumultuous', 'rough', 'unstable', 'slow', 'scarce', 'severe', 'escapade', 'incense', 'demands', 'argument', 'forged', 'dying', 'crude', 'stain', 'discompose', 'opportunistic', 'allege', 'corrosive', 'delinquent', 'intrusion', 'sharply', 'injurious', 'weak', 'prohibit', 'tentative', 'downgrade', 'inability', 'sticky', 'torture', 'useless', 'decrement', 'hardliners', 'involuntarily', 'low', 'subversion', 'horde', 'prohibitively', 'decreasing', 'casualty', 'ruin', 'strained', 'trying', 'breach', 'slight', 'interference', 'pollute', 'unnatural', 'lanky', 'beware', 'chill', 'inactive', 'overshadow', 'antagonist', 'trial', 'belated', 'eternal', 'haphazard', 'toll', 'blood', 'attack', 'failure', 'perilously', 'beset', 'besiege', 'dictator', 'irritant', 'precariously', 'overtaxed', 'stagger', 'faulty', 'hegemonism', 'slug', 'impossible', 'game', 'manipulate', 'hazard', 'enemy', 'deterioration', 'helplessness', 'repression', 'confounding', 'insurmountably', 'revolt', 'bunk', 'cave', 'disorder', 'hardliner', 'needlessly', 'refusal', 'upset', 'sharp', 'threats', 'contagious', 'bum', 'uproot', 'inadverently', 'inaccuracy', 'flaw', 'empty', 'unjustified', 'incompliant', 'pricey', 'adversary', 'exclusion', 'displace', 'sicken', 'depress', 'divorced', 'inhibition', 'extremist', 'crush', 'lost', 'over-valuation', 'slaughtered', 'sorrow', 'sting', 'crowded', 'disable', 'predatory', 'temper', 'murderously', 'threaten', 'although', 'uncompetitive', 'inadvisably', 'unsuccessful', 'jobless', 'suicidal', 'excuse', 'stringent', 'hole', 'blackmail', 'poor', 'ineffectively', 'chore', 'down', 'pain', 'embattled', 'obstruction', 'danger', 'slow-moving', 'sour', 'omit', 'urgent', 'fabricate', 'insolvent', 'deficient', 'violently', 'implication', 'supposed', 'unsteadily', 'tenuous', 'uncollectible', 'terrorism', 'unconstitutional', 'illegitimate', 'sneaky', 'comical', 'suspect', 'vanity', 'corrosion', 'clash', 'congestion', 'deficiency', 'exhaust', 'unraveled', 'elimination', 'imprecise', 'pointlessly', 'inaction', 'fuzzy', 'insecure', 'mistified', 'ill', 'curt', 'insubordinate', 'fragile', 'fissures', 'secretive', 'flawed', 'costly', 'warfare', 'interrupt', 'hurtful', 'undocumented', 'flaky', 'unexplained', 'erosion', 'problems', 'idle', 'retreat', 'constrain', 'siege', 'defect', 'motionless', 'coarse', 'limitation', 'shake', 'vocally', 'suicide', 'static', 'precarious', 'invasive', 'impoverish', 'sluggish', 'outdated', 'suppression', 'strike', 'difficult', 'close', 'guilty', 'lecture', 'inflated', 'moon', 'plague', 'collapse', 'expropriation', 'abandonment', 'unreasonable', 'lethargic', 'inertia', 'sneakily', 'stampede', 'cancer', 'unskilled', 'subtract', 'incitement', 'subversive', 'hustler', 'capsize', 'delinquency', 'excuses', 'killer', 'decline', 'subvert', 'undone', 'intermittent', 'splitting', 'rigorous', 'feverish', 'uninformed', 'resistant', 'unlicensed', 'unnecessary', 'divided', 'short-lived', 'gritty', 'debility', 'manipulation', 'plea', 'sickness', 'ignore', 'writhe', 'needy', 'unforeseen', 'stun', 'beggar', 'inconsistent', 'blast', 'incompatibility', 'pry', 'obsolete', 'restlessness', 'deep', 'smash', 'painfully', 'instability', 'fatally', 'alienate', 'sneak', 'fatal', 'unlawfully', 'unlawful', 'unsafe', 'untested', 'preoccupy', 'limited', 'shaky', 'muddy', 'miscalculation', 'fist', 'epidemic', 'unconfirmed', 'collide', 'anomaly', 'suffer', 'forbidding', 'rigid', 'rupture', 'leaky', 'allergic', 'dangerous', 'leakage', 'paralyzed', 'oversimplify', 'toxic', 'insufficient', 'unnoticed', 'wrestle', 'wasteful', 'constraint', 'scant', 'swoon', 'disordered', 'crime', 'snarl', 'chronic', 'conspiracy', 'absence', 'expel', 'blemish', 'feign', 'drowning', 'redundant', 'shred', 'stumble', 'recessionary', 'unavailable', 'accidental', 'fugitive', 'error', 'astray', 'din', 'foul', 'grapple', 'gamble', 'dilemma', 'soreness', 'black', 'unlawfulness', 'imprecisely', 'defensive', 'painful', 'wallow', 'jar', 'blind', 'slightly', 'prisoner', 'cold', 'bid-rigging', 'harass', 'abdicate', 'immature', 'overwhelm', 'imprecision', 'headaches', 'oversized', 'abuses', 'stunted', 'hard', 'deter', 'stealing', 'powerless', 'subordinate', 'poisonously', 'breakdown', 'debilitate', 'esoteric', 'extremists', 'marginal', 'regression', 'fundamentalism', 'ruffle', 'unlikely', 'eccentric', 'too', 'hasty', 'lethargy', 'relapse', 'gross', 'flaws', 'indefinite', 'capitulate', 'starvation', 'assassinate', 'bombard', 'insurrection', 'unspecified', 'confront', 'dead', 'blindness', 'eccentricity', 'inadverent', 'airs', 'lesser', 'uncertain', 'warning', 'disinterested', 'imposing', 'reluctant', 'unsupported', 'insignificance', 'crumple', 'adversarial', 'punishable', 'unfunded'}, 'wpos': {'optimistic', 'cost-effective', 'resilient', 'lifelong', 'importantly', 'stimulative', 'adequate', 'affably', 'trust', 'accordantly', 'jollify', 'pre-eminent', 'productive', 'decent', 'definitive', 'adventurous', 'lenient', 'tantalize', 'distinctive', 'trim', 'appropriate', 'well-publicized', 'acceptance', 'security', 'upward', 'aptitude', 'less-expensive', 'allow', 'deflationary', 'potential', 'stand', 'decisiveness', 'sturdy', 'nourishing', 'benefit', 'purify', 'suit', 'victorious', 'dreamy', 'impetus', 'improve', 'revitalize', 'modern', 'vigorous', 'clear', 'rescue', 'calm', 'discretion', 'fairness', 'untrained', 'apt', 'resolved', 'blossom', 'genuine', 'progressive', 'strides', 'dreams', 'idealism', 'holy', 'conscience', 'achievements', 'innocence', 'success', 'reinforcement', 'fathom', 'meticulous', 'suffice', 'delicacy', 'definitely', 'devout', 'ripe', 'electrify', 'relevant', 'demand', 'innovative', 'intricate', 'beneficial', 'effectual', 'feasibly', 'renovation', 'educated', 'adaptive', 'relevance', 'heart', 'above', 'broad', 'enrich', 'easily', 'inventive', 'charity', 'press', 'just', 'reliability', 'legendary', 'responsibly', 'attune', 'tradition', 'enhance', 'cooperative', 'attain', 'capable', 'impress', 'capability', 'cohesive', 'improved', 'portable', 'maturity', 'acceptable', 'energetic', 'humanity', 'liberalism', 'neat', 'plentiful', 'inalienable', 'easiest', 'comfortably', 'accomplishment', 'sparing', 'advantages', 'diplomatic', 'effective', 'thrive', 'protection', 'sustained', 'authoritative', 'responsible', 'remedy', 'acknowledgement', 'innocent', 'refresh', 'brotherly', 'shiny', 'vintage', 'careful', 'mend', 'suggest', 'gems', 'reasonably', 'value', 'influential', 'compatible', 'entertain', 'favor', 'affability', 'adherent', 'constructive', 'imperial', 'distinction', 'authentic', 'golden', 'lower-priced', 'untouched', 'soundness', 'charitable', 'advisable', 'headway', 'experienced', 'simplify', 'uplift', 'friends', 'correct', 'popular', 'warm', 'real', 'brisk', 'established', 'ambitious', 'attainable', 'unscathed', 'viability', 'care', 'drive', 'modesty', 'progress', 'salable', 'unbroken', 'bull', 'responsibility', 'afford', 'enliven', 'exclusive', 'rehabilitation', 'posterity', 'signify', 'sunny', 'farsighted', 'special', 'energize', 'even', 'purification', 'comfortable', 'sparingly', 'persistent', 'prospects', 'reputable', 'hard-working', 'enable', 'seasoned', 'concrete', 'appreciable', 'upscale', 'well-positioned', 'deal', 'cohesion', 'admission', 'satisfy', 'shield', 'abound', 'appeal', 'clean', 'patient', 'valuable', 'dance', 'facilitate', 'impression', 'semblance', 'unlimited', 'fairly', 'minister', 'best-selling', 'first-class', 'successful', 'foolproof', 'angel', 'affinity', 'logical', 'recover', 'selective', 'relaxed', 'high-quality', 'treat', 'fast-paced', 'low-cost', 'swift', 'buoyant', 'principled', 'piety', 'benign', 'self-sufficient', 'elite', 'coherent', 'feasible', 'commensurate', 'liberal', 'open', 'spirit', 'superior', 'unbiased', 'versatility', 'youthful', 'rationality', 'boost', 'usable', 'universal', 'principle', 'openness', 'alleviate', 'improving', 'vigilance', 'modest', 'aptly', 'stabilize', 'sufficient', 'well', 'warmth', 'comprehensive', 'unrestricted', 'gain', 'lawful', 'bullish', 'feat', 'thrift', 'conquer', 'commonsense', 'award', 'sweetness', 'capably', 'precision', 'responsive', 'restoration', 'achievable', 'essential', 'instrumental', 'substantive', 'colorful', 'vigilant', 'survive', 'revelation', 'comfort', 'loyal', 'distinguish', 'commonsensical', 'refinement', 'eligible', 'uniform', 'resolve', 'unique', 'non-violent', 'successfully', 'allowable', 'appease', 'practical', 'durability', 'beacon', 'reasoned', 'pamper', 'clarity', 'affluent', 'civilize', 'valid', 'adhesion', 'plain', 'speedy', 'suitable', 'envision', 'healthy', 'distinct', 'inclusive', 'well-established', 'content', 'guardian', 'wealthy', 'prominence', 'interest', 'utilitarian', 'sleek', 'stainless', 'discriminating', 'mentor', 'dream', 'brilliance', 'reparation', 'fruitful', 'breakthrough', 'humanists', 'leading', 'original', 'precise', 'normal', 'compromise', 'fair', 'crisp', 'painless', 'agility', 'liberally', 'enhanced', 'salivate', 'relieve', 'noticeable', 'resolute', 'booming', 'afloat', 'embolden', 'agilely', 'quench', 'dexterity', 'rehabilitate', 'outgoing', 'reliable', 'stood', 'important', 'peace', 'animated', 'decisive', 'invigorate', 'elate', 'impartial', 'unity', 'succeed', 'reaffirm', 'bask', 'venerate', 'heal', 'enjoy', 'magnetic', 'celebrity', 'openly', 'renewal', 'reunite', 'commonsensible', 'above-average', 'tolerant', 'neatly', 'fine', 'assertive', 'preemptive', 'resound', 'protective', 'savor', 'taste', 'nourish', 'dignify', 'versatile', 'precedent', 'famed', 'dependable', 'compromises', 'restore', 'proper', 'efficient', 'easy', 'ensure', 'fastest-growing', 'flair', 'bright', 'ability', 'expressive', 'decency', 'survival', 'instructive', 'meticulously', 'wide', 'shine', 'premier', 'durable', 'upgrade', 'abundance', 'diligent', 'eventful', 'recognition', 'upfront', 'amply', 'qualify', 'spare', 'prospect', 'approve', 'destine', 'equality', 'balanced', 'pleasantly', 'skill', 'worship', 'orderly', 'survivor', 'resurgent', 'significance', 'respect', 'gem', 'necessary', 'capitalize', 'competency', 'sensitive', 'indebted', 'encourage', 'compact', 'preeminent', 'voluntary', 'evident', 'advice', 'assurance', 'personages', 'go-ahead', 'tenderness', 'achievement', 'prolific', 'diligence', 'affordable', 'politeness', 'undisputed', 'subtle', 'dig', 'interests', 'viable', 'cleanse', 'democratic', 'defend', 'confer', 'accord', 'comeback', 'sweeten', 'adaptable', 'welfare', 'able', 'civilization', 'validity', 'hardy', 'gold', 'refined', 'asset', 'freedoms', 'mild', 'commodious', 'agreeable', 'lucrative', 'polite', 'convince', 'achieve', 'profit', 'reconcile', 'evenly', 'legitimacy', 'streamlined', 'co-operation', 'ease', 'luxuriate', 'natural', 'polished', 'full-fledged', 'conclusive', 'unconventional', 'reliably', 'acknowledge', 'amnesty', 'affirmative', 'unconditional', 'dawn', 'relax', 'self-sufficiency', 'okay', 'navigable', 'independent', 'originality', 'functional', 'empowerment', 'cordial', 'adeptly', 'defense', 'premium', 'justice', 'consistent', 'assurances', 'titillate', 'bloom', 'vastness', 'light', 'legitimate', 'agile', 'sustainability', 'intelligence', 'simplified', 'autonomous', 'prosperous', 'peacekeepers', 'informative', 'practicable', 'scenic', 'expert', 'advantage', 'prudence', 'effectiveness', 'innocently', 'qualified', 'grand', 'elevated', 'advanced', 'satisfying', 'powerfully', 'protect', 'gentle', 'asylum', 'accomplish', 'fertile', 'discreet', 'exhaustive', 'significant', 'suggestions', 'fresh', 'uniformly', 'enterprising', 'gush', 'substantially', 'empower', 'efficiency', 'reform', 'helpful', 'efficacious', 'demands', 'fortunate', 'placid', 'securely', 'covenant', 'independence', 'console', 'envisions', 'risk-free', 'subscribe', 'sweetly', 'hot', 'goodly', 'affluence', 'live', 'wide-open', 'tender', 'tickle', 'acquit', 'sparkling', 'lean', 'competitiveness', 'prompt', 'record-setting', 'recompense', 'liberation', 'myriad', 'upright', 'right', 'temperance', 'onward', 'historic', 'classic', 'spacious', 'amity', 'promptly', 'help', 'nourishment', 'brighten', 'competence', 'entrance', 'elevate', 'rich', 'accomplishments', 'accordance', 'sweet', 'values', 'interested', 'entrust', 'restful', 'fluent', 'adherence', 'guarantee', 'leverage', 'settle', 'readily', 'solid', 'colossal', 'enrichment', 'powerful', 'temperate', 'revival', 'properly', 'better', 'honest', 'top', 'improvement', 'maturely', 'freedom', 'aristocratic', 'exhaustively', 'necessarily', 'abilities', 'riches', 'robust', 'thorough', 'strong', 'ample', 'refine', 'permissible', 'vastly', 'free', 'groove', 'reestablish', 'diversified', 'accurate', 'sweetheart', 'fiery', 'rights', 'tenderly', 'usefulness', 'cleanliness', 'destined', 'germane', 'genial', 'well-educated', 'agreement', 'enlighten', 'contribution', 'timely', 'excuse', 'skilled', 'educational', 'safe', 'intact', 'luminous', 'driven', 'learned', 'cohere', 'low-risk', 'insistence', 'coddle', 'commitment', 'verifiable', 'economical', 'slender', 'repair', 'unencumbered', 'wide-ranging', 'industrious', 'cooperatively', 'lawfully', 'prosperity', 'intimate', 'competent', 'benefits', 'stability', 'voluntarily', 'smooth', 'assuage', 'heaven', 'toleration', 'complement', 'innovation', 'ready', 'reaffirmation', 'enrapture', 'emancipate', 'traditional', 'lighten', 'stable', 'victory', 'sound', 'sufficiently', 'kiss', 'prominent', 'pleasant', 'adventure', 'dynamic', 'peacefully', 'restraint', 'simple', 'useful', 'steady', 'educable', 'brightness', 'positive', 'impressions', 'thriving', 'ambitiously', 'unbound', 'neutralize', 'adept', 'excite', 'idealist', 'sense', 'breakthroughs', 'steadiness', 'honeymoon', 'reclaim', 'learning', 'white', 'literate', 'pro', 'conviction', 'non-violence', 'commonsensibly', 'reconciliation', 'diligently', 'vast', 'competitive', 'substantial', 'accept', 'manageable', 'renovate', 'swiftness', 'enhancement', 'painlessly', 'guidance', 'magnify', 'precisely', 'honor', 'impartially', 'fulfillment', 'definite', 'basic', 'famous', 'spirited', 'tolerate', 'grail', 'egalitarian', 'conducive', 'champion', 'leniently', 'reasonable', 'accommodative', 'slim', 'easiness', 'sustainable', 'boom', 'delicate', 'understanding', 'active', 'pure', 'naturally', 'back', 'champ', 'prestigious', 'continuity', 'revive', 'civil', 'backbone', 'popularity', 'legitimately', 'thrifty', 'accurately', 'adaptability', 'reason', 'objective', 'soft-spoken', 'abundant', 'fast-growing', 'shelter', 'secure', 'offset', 'large', 'objectively', 'cooperate', 'accessible', 'convenient', 'equitable', 'individuality', 'profitable', 'peaceful', 'sincerity', 'impartiality', 'amenity', 'favored', 'importance', 'cooperation', 'friend', 'calmness', 'inexpensive', 'support', 'chum', 'benefactor', 'pertinent', 'purity', 'straight', 'stimulate', 'enlightenment', 'integral', 'discriminatingly', 'flame', 'friendship', 'approval', 'prepared', 'intercede', 'vigorously', 'cost-saving', 'reinforce', 'welcome', 'easier', 'revolution', 'good', 'mature', 'rapprochement', 'bonus'}, 'wneu': {'constitutions', 'destiny', 'transparency', 'open-ended', 'simply', 'react', 'else', 'look', 'sleepy', 'expression', 'gigantic', 'corrective', 'full', 'rarely', 'specifically', 'further', 'relations', 'stronger-than-expected', 'primarily', 'claim', 'appearance', 'decide', 'statements', 'consciousness', 'might', 'move', 'reiterated', 'ignite', 'exclusively', 'whiff', 'particular', 'high-powered', 'likely', 'innumerous', 'consideration', 'hypnotize', 'attitudes', 'obvious', 'gestures', 'largely', 'possibility', 'quiet', 'seem', 'self-examination', 'speculate', 'transparent', 'heavy-duty', 'possibly', 'reiterates', 'vocal', 'notion', 'difference', 'nap', 'continuous', 'factual', 'high', 'emotions', 'pressure', 'commentator', 'informational', 'frequent', 'outlook', 'all-time', 'hefty', 'readiness', 'particularly', 'should', 'eyebrows', 'judgement', 'clandestine', 'proportionate', 'intensive', 'proportionately', 'show', 'point', 'remark', 'concerning', 'expound', 'fast', 'prime', 'floor', 'thought', 'player', 'massive', 'batons', 'sovereignty', 'stupefy', 'engage', 'predictable', 'prove', 'most', 'basically', 'realization', 'scholarly', 'conscience', 'persistence', 'halt', 'perspective', 'primary', 'stir', 'power', 'absorbed', 'matter', 'very', 'certified', 'immediate', 'apparent', 'apprehend', 'giants', 'innumerably', 'legacies', 'judgments', 'intensively', 'touch', 'swing', 'reiterate', 'could', 'analytical', 'mostly', 'judgements', 'completely', 'giant', 'replete', 'broad-based', 'intent', 'ceaseless', 'engross', 'funded', 'reputed', 'fully', 'intend', 'innumerable', 'invisible', 'entire', 'infectious', 'likelihood', 'looking', 'influence', 'deep', 'big', 'direct', 'enough', 'recognizable', 'outspoken', 'firmly', 'reaction', 'so', 'alert', 'minor', 'plenary', 'posture', 'nature', 'expectation', 'indication', 'much', 'inference', 'assessments', 'nonviolent', 'concerted', 'olympic', 'practically', 'rare', 'tendency', 'expressions', 'unaudited', 'legacy', 'would', 'reactions', 'implicit', 'specific', 'dominant', 'far-reaching', 'judgment', 'indirect', 'overtures', 'cognizance', 'emphasise', 'position', 'immune', 'however', 'extensive', 'chant', 'predictablely', 'amplify', 'pressures', 'obligation', 'legalistic', 'stands', 'intents', 'major', 'appear', 'assumption', 'central', 'intense', 'forthright', 'quick', 'large', 'firm', 'diplomacy', 'halfway', 'increasingly', 'motive', 'stance', 'signals', 'strength', 'distinctly', 'such', 'assessment', 'tall', 'pacify', 'beliefs', 'transport', 'stuffed', 'huge', 'reveal', 'taste', 'predominant', 'speculation', 'evaluation', 'prevalent', 'stances', 'overt', 'growing', 'covert', 'certain', 'duty', 'needs', 'blood', 'complete', 'intentions', 'memories', 'tale', 'intention', 'idea', 'still', 'intrigue', 'nascent', 'rather', 'learn', 'apparently', 'increasing', 'rapid', 'renewable', 'key', 'comment', 'effectively', 'full-scale', 'pivotal', 'dependent', 'galvanize', 'immense', 'systematic', 'familiar', 'affect', 'mean', 'possible', 'large-scale'}, 'sneg': {'apologist', 'inconsistencies', 'traitorous', 'complaining', 'ludicrously', 'improbably', 'rifts', 'depravedly', 'trauma', 'sneering', 'fabrication', 'dreary', 'insupportably', 'thankless', 'sucker', 'asperse', 'passiveness', 'lackadaisical', 'gloss', 'absent-minded', 'wound', 'chaotic', 'harried', 'guiltily', 'accuses', 'anti-American', 'inattentive', 'enmity', 'shock', 'misbegotten', 'worthlessness', 'expunge', 'fatalistic', 'gawk', 'toughness', 'destabilisation', 'argumentative', 'err', 'mischievous', 'unfit', 'genocide', 'stale', 'rude', 'invidiousness', 'coldly', 'brash', 'disconcerting', 'troublesome', 'deceptively', 'mire', 'bastard', 'furious', 'impetuously', 'daunt', 'shirker', 'belabor', 'capriciousness', 'lust', 'bitter', 'leech', 'disown', 'fanatically', 'difficulty', 'haughtily', 'disrepute', 'domineering', 'sympathize', 'defiantly', 'pariah', 'annihilate', 'careless', 'vilify', 'exploit', 'licentiously', 'scandalize', 'disagreement', 'imperil', 'contemptuously', 'impinge', 'radical', 'anarchistic', 'quibble', 'discredit', 'unwanted', 'annoyance', 'hostility', 'babble', 'brutalising', 'demand', 'farfetched', 'renounce', 'autocrat', 'raging', 'proscription', 'blistering', 'unruly', 'intimidatingly', 'bloodshed', 'frenetic', 'venomous', 'peevish', 'conspirator', 'rack', 'invective', 'tauntingly', 'unwieldy', 'prickle', 'remorselessly', 'revenge', 'extravagance', 'neurotically', 'ugh', 'misconceptions', 'credulous', 'misguided', 'empathize', 'provocation', 'regrettable', 'teasingly', 'lonesome', 'impedance', 'burdensome', 'indiscreetly', 'cuss', 'draconic', 'insubstantially', 'neglect', 'peeved', 'defamations', 'refuse', 'remorselessness', 'brusque', 'perturbed', 'dismal', 'heedless', 'lackey', 'arrogance', 'bleak', 'perversity', 'unbelievable', 'furor', 'unsavory', 'malcontented', 'blame', 'propagandize', 'heartbreakingly', 'disprove', 'unjust', 'dishonorablely', 'incapable', 'reprimand', 'brazenly', 'discord', 'venomously', 'uneasiness', 'weariness', 'blabber', 'impatience', 'unethical', 'overstatements', 'impenitent', 'disrespectable', 'devastate', 'deceive', 'disastrously', 'trick', 'disputable', 'malevolently', 'savagery', 'heathen', 'imminently', 'flout', 'ghastly', 'ineptitude', 'rift', 'disruption', 'provoke', 'vent', 'distaste', 'decadence', 'cannibalize', 'seething', 'conspiratorial', 'flirt', 'lackluster', 'unimaginably', 'recklessly', 'protest', 'intrusive', 'fearfully', 'bias', 'resent', 'nervously', 'improbable', 'smoulder', 'impractical', 'boredom', 'overdo', 'misbecome', 'atrophy', 'arduously', 'curses', 'enflame', 'inconsistence', 'damnable', 'insanely', 'malcontent', 'worthlessly', 'uncouth', 'overcome', 'groundless', 'bitterness', 'stuffy', 'glaring', 'mundane', 'audaciously', 'kook', 'vindictive', 'madman', 'egregious', 'dispirited', 'outbursts', 'fateful', 'despotism', 'loathsomely', 'ignoble', 'senseless', 'indelicate', 'unnerved', 'dejectedly', 'lackeys', 'fibber', 'inane', 'ragged', 'clumsy', 'despicably', 'scariest', 'bloodthirsty', 'dubious', 'betrayer', 'facetious', 'agonizingly', 'filth', 'unfortunately', 'reprovingly', 'lamentably', 'refute', 'scream', 'extreme', 'lorn', 'stern', 'impudently', 'misguidance', 'plight', 'degrading', 'allegation', 'humiliating', 'lurk', 'abase', 'beleaguer', 'presumptuously', 'gaff', 'diatribes', 'doddering', 'dishonor', 'villainous', 'contradictory', 'unthinkable', 'stupify', 'despondent', 'crafty', 'distasteful', 'abject', 'despair', 'spookier', 'bellicose', 'demonic', 'diabolical', 'discountenance', 'dizzing', 'slanders', 'unsound', 'accusing', 'presumptuous', 'monstrous', 'enervate', 'covetous', 'forgetfully', 'muscle-flexing', 'defiance', 'longing', 'dastard', 'eviscerate', 'startle', 'bereft', 'pertinaciously', 'twist', 'vexing', 'haste', 'sarcastically', 'wrest', 'brutalizing', 'unconvincing', 'riled', 'extremely', 'fatefully', 'bedlamite', 'defiler', 'tantrum', 'struggle', 'idiotically', 'fathomless', 'fusty', 'hoax', 'unlucky', 'meddlesome', 'dissatisfying', 'overbearing', 'condescending', 'hoodwink', 'disagree', 'impotent', 'fidget', 'inexcusably', 'sap', 'irreverence', 'oppressiveness', 'rascal', 'conspicuously', 'so-called', 'irreformable', 'misjudge', 'imposers', 'disallow', 'racists', 'heartbreaking', 'cocky', 'devilment', 'slanderous', 'disdainful', 'tragic', 'excruciatingly', 'desertion', 'tyrannical', 'intolerant', 'jeopardy', 'inept', 'infuriatingly', 'pretentious', 'rotten', 'indecently', 'agonies', 'perverted', 'penalize', 'irritable', 'disgust', 'persecute', 'discontent', 'cannibal', 'innuendo', 'lecherous', 'blinding', 'revoltingly', 'ambiguity', 'uproarious', 'blunders', 'mislead', 'ulterior', 'unseemly', 'horrible', 'villian', 'scowl', 'inexplicable', 'pugnacity', 'sunder', 'forebodingly', 'dissidence', 'impropriety', 'eschew', 'opposition', 'frightening', 'banal', 'disreputable', 'undermine', 'contradict', 'excessively', 'incongruous', 'despondency', 'nervous', 'unease', 'sloppily', 'chide', 'plunderer', 'oblivious', 'apprehension', 'incompetently', 'untruthful', 'fallacies', 'rid', 'offend', 'anarchism', 'disappointing', 'debasement', 'belligerently', 'polluter', 'devastated', 'dissuade', 'taunt', 'hesitant', 'impose', 'instigator', 'defiant', 'senselessly', 'stupidly', 'despondently', 'impulsively', 'treasonous', 'ill-mannered', 'wheedle', 'sheer', 'wrongly', 'fake', 'hideous', 'partisan', 'dissatisfaction', 'injudicious', 'abhorrent', 'trivialize', 'foolish', 'scathingly', 'confess', 'seriousness', 'belittle', 'complain', 'direly', 'diabolically', 'unscrupulous', 'doubtful', 'incognizant', 'sympathetically', 'cruel', 'condescension', 'inhospitality', 'idiots', 'inefficacy', 'infirm', 'procrastinate', 'sensationalize', 'wickedly', 'haughty', 'maltreatment', 'brood', 'lax', 'contrived', 'sillily', 'brazenness', 'sorrowfully', 'abscond', 'defective', 'obscenely', 'grievously', 'racist', 'lonely', 'hallucinate', 'unkind', 'humiliation', 'antithetical', 'desolately', 'discourteously', 'reproachful', 'harshly', 'pathetically', 'acerbically', 'polarisation', 'grisly', 'antagonistic', 'puzzlement', 'proscriptions', 'obnoxious', 'swindle', 'irritate', 'perfidious', 'garish', 'enviousness', 'forbid', 'bloated', 'brag', 'hysterical', 'pettifog', 'dissonant', 'gall', 'discontentedly', 'senile', 'discouragement', 'deadbeat', 'sob', 'outrageously', 'unsophisticated', 'anti-Semites', 'embarrass', 'meaningless', 'second-class', 'prattle', 'lies', 'forbidden', 'picky', 'ultimatums', 'destitute', 'infuriate', 'stinging', 'flagrant', 'direness', 'maxi-devaluation', 'demonize', 'underdog', 'belittled', 'languorous', 'slothful', 'indifference', 'heavyhearted', 'madden', 'nuisance', 'unwarranted', 'fallout', 'scandalized', 'misstatement', 'sullen', 'calamitous', 'uproarous', 'averse', 'pleading', 'contentious', 'remorsefully', 'lying', 'traumatize', 'bitterly', 'disappointingly', 'devilishly', 'qualms', 'pitiful', 'incorrectly', 'paltry', 'chaos', 'irate', 'jealously', 'indignantly', 'oppose', 'distracting', 'irreverently', 'concerned', 'spoil', 'dismaying', 'impasse', 'misguide', 'impugn', 'fruitlessly', 'stark', 'quack', 'immoderately', 'rancor', 'temper', 'ironic', 'extravagant', 'ridiculous', 'dishonestly', 'shortcomings', 'mendacious', 'fetid', 'imprecate', 'bungle', 'degenerate', 'villainously', 'irk', 'afraid', 'browbeat', 'flimflam', 'belie', 'idiocies', 'quarrellously', 'spitefully', 'cartoonish', 'brimstone', 'nastily', 'stifle', 'deceptive', 'liability', 'daze', 'butchery', 'pout', 'dragoon', 'incoherent', 'exorbitant', 'irrepressible', 'monster', 'vileness', 'sloppy', 'tyrannically', 'unimaginable', 'displeasure', 'tattered', 'banish', 'glower', 'paranoid', 'aberration', 'disquietude', 'disgustedly', 'rumor', 'inveigle', 'sugarcoated', 'avenge', 'fudge', 'chasten', 'indolent', 'unyielding', 'self-interested', 'fool', 'mortifying', 'woe', 'despite', 'aspersion', 'rue', 'bemused', 'keen', 'jealousness', 'unreasonably', 'dilly-dally', 'ill-sorted', 'traduce', 'exorbitantance', 'flighty', 'stupor', 'frenzy', 'demoralizing', 'abhors', 'unorthodoxy', 'irreplacible', 'imperiously', 'hysterically', 'plague', 'selfish', 'vindictiveness', 'ill-favored', 'unreasonable', 'disconcerted', 'lunaticism', 'rebellious', 'spank', 'skepticism', 'heartbreak', 'flaunt', 'sty', 'rubbish', 'quarrellous', 'usurper', 'insanity', 'narrower', 'paucity', 'irreversible', 'glare', 'stranger', 'cripple', 'cruelty', 'jabber', 'loneliness', 'scoffingly', 'stammer', 'heretical', 'disrespect', 'disturbing', 'offensiveness', 'pretentiously', 'madly', 'motley', 'gloom', 'haunting', 'severity', 'commiserate', 'immovable', 'fearsome', 'distraction', 'hallucination', 'cloud', 'immaterial', 'disrespectfulness', 'apathetically', 'lament', 'pine', 'unthinkably', 'anxious', 'obsess', 'incessant', 'rationalize', 'midget', 'ruthlessness', 'premeditated', 'grudge', 'ire', 'squander', 'desecrate', 'mischief', 'enfeeble', 'reckless', 'mere', 'foul', 'mawkishly', 'aggressor', 'dislike', 'flak', 'acrimonious', 'kooky', 'ultra-hardline', 'vicious', 'antipathy', 'grieve', 'gasp', 'gruesome', 'shameless', 'neglected', 'delusions', 'superstitious', 'stifling', 'stagnation', 'admonish', 'impiety', 'ill-natured', 'belligerent', 'debase', 'infamy', 'wretchedly', 'puzzling', 'strangest', 'scandalously', 'evil', 'indecisively', 'inconsequently', 'terror', 'unsettlingly', 'jerk', 'hasty', 'capriciously', 'mockeries', 'cross', 'peculiarly', 'misinform', 'yawn', 'unnerve', 'ax', 'smolder', 'digress', 'revengeful', 'adversity', 'yelp', 'smug', 'dissemble', 'languor', 'loveless', 'timid', 'blasphemous', 'fiasco', 'harm', 'fiendish', 'anarchy', 'mean', 'savage', 'famine', 'unqualified', 'balk', 'reprove', 'boast', 'fiend', 'disconsolation', 'plunder', 'languid', 'domination', 'object', 'gainsay', 'shocking', 'mortification', 'calumniate', 'obsessive', 'sinister', 'bombastic', 'viciousness', 'downcast', 'worsening', 'staggeringly', 'offensively', 'virulence', 'rash', 'flabbergast', 'deprive', 'mishandle', 'deny', 'mendacity', 'taboo', 'mar', 'emaciated', 'harrow', 'perplexity', 'dumbfound', 'inappropriately', 'unrelentingly', 'ill-usage', 'woeful', 'impulsive', 'accusation', 'sorely', 'grim', 'ill-tempered', 'pestilent', 'sloth', 'moan', 'coercion', 'inexpiable', 'exorbitantly', 'shirk', 'miserably', 'deceivers', 'misgiving', 'urgency', 'disparage', 'rumbling', 'degradation', 'hardhearted', 'enormity', 'distraught', 'hamstrung', 'deceiving', 'bewail', 'laughably', 'disobey', 'radicals', 'doomsday', 'maddeningly', 'dejected', 'mess', 'break-point', 'rusty', 'unacceptable', 'gibber', 'anti-proliferation', 'obsessions', 'ignorant', 'earsplitting', 'incongruously', 'peril', 'rampant', 'acrimony', 'equivocal', 'one-sided', 'excoriate', 'friction', 'bother', 'disadvantageous', 'decay', 'spurious', 'disquietingly', 'disquiet', 'despotic', 'somber', 'decayed', 'ambiguous', 'insociable', 'repudiation', 'scolding', 'freakish', 'antagonism', 'hardship', 'precipitate', 'sidetracked', 'intolerance', 'indoctrination', 'disconsolately', 'insulted', 'temptation', 'intolerable', 'lousy', 'damnation', 'hellion', 'horror', 'irritated', 'taint', 'embarrassingly', 'dread', 'menace', 'stink', 'pessimistic', 'mania', 'quarrel', 'exasperation', 'suffering', 'manipulative', 'obstinately', 'crazily', 'heartbreaker', 'flounder', 'scold', 'sly', 'confession', 'frazzled', 'panic', 'apocalypse', 'lewd', 'disgracefully', 'relentlessness', 'worried', 'superficiality', 'ravage', 'rant', 'berserk', 'fascism', 'ridiculously', 'contempt', 'disruptive', 'crippling', 'throttle', 'barbarically', 'discouragingly', 'foolishly', 'liars', 'indifferent', 'unnervingly', 'sinfully', 'arrogantly', 'demise', 'grossly', 'weakening', 'patronize', 'impure', 'impurity', 'arbitrary', 'disaffect', 'miseries', 'abyss', 'dismally', 'exhort', 'inessential', 'injustices', 'slanderer', 'desultory', 'haggle', 'brutal', 'irresponsible', 'ingratitude', 'unprecedent', 'hegemony', 'superficially', 'illogic', 'downfallen', 'perverse', 'exaggerate', 'misgivings', 'harmful', 'unpopular', 'stressfully', 'insane', 'abash', 'unfaithful', 'blindingly', 'disloyalty', 'obstinate', 'obsession', 'shun', 'illogical', 'insubstantial', 'sad', 'goof', 'anti-white', 'calamity', 'misinformed', 'harangue', 'disdainfully', 'accursed', 'mockery', 'drones', 'affront', 'gossip', 'broken-hearted', 'importunate', 'sympathy', 'frenetically', 'mudslinging', 'impede', 'relentlessly', 'fib', 'worthless', 'insidiously', 'covetingly', 'insufferably', 'inopportune', 'gibe', 'dragons', 'squabble', 'cliche', 'evils', 'drastically', 'shoddy', 'upheaval', 'mockingly', 'grandiose', 'pessimism', 'biases', 'forget', 'sober', 'irrationally', 'deviously', 'unkindly', 'hard-liner', 'dismayed', 'heckle', 'hunger', 'misrepresentation', 'deprived', 'disrespectablity', 'slur', 'cuplrit', 'shyly', 'ignominious', 'bewitch', 'implacable', 'cataclysmic', 'rumple', 'dissatisfied', 'mournfully', 'cowardly', 'disagreeable', 'incomprehensible', 'disavow', 'insensitively', 'misrepresent', 'coveting', 'sulk', 'overwhelmingly', 'brutality', 'bitchy', 'rumors', 'arrogant', 'bait', 'calumniation', 'blatantly', 'shamefulness', 'bitch', 'overlook', 'destitution', 'impeach', 'decrepit', 'sickening', 'war-like', 'blatant', 'conceited', 'derision', 'passive', 'audaciousness', 'egocentric', 'incivility', 'grating', 'utterly', 'disgraced', 'lowly', 'tiring', 'stereotypically', 'untrue', 'blundering', 'demean', 'imaginary', 'prejudge', 'reject', 'emptiness', 'inflexible', 'tawdry', 'blasphemy', 'failing', 'skittish', 'avariciously', 'deride', 'villianous', 'wearisome', 'tiringly', 'inevitably', 'sanctimonious', 'trivially', 'inefficacious', 'deceiver', 'spiritless', 'beast', 'gratuitously', 'stew', 'blather', 'doubtfully', 'negligent', 'dreadfulness', 'undignified', 'frustratingly', 'startlingly', 'disturb', 'nasty', 'allegations', 'desert', 'monstrously', 'shortcoming', 'fraternize', 'sleazy', 'bowdlerize', 'infuriating', 'rampage', 'chatter', 'emasculate', 'tortuous', 'disconsolate', 'venom', 'wince', 'obviously', 'obese', 'dissolute', 'indiscriminately', 'obliterate', 'invidiously', 'inaccurately', 'ejaculate', 'notoriously', 'denigrate', 'egotistically', 'brutally', 'revengefully', 'confessions', 'uncivilized', 'dismay', 'upsetting', 'fractiously', 'perturb', 'peeve', 'dispirit', 'self-criticism', 'criticisms', 'drunken', 'intolerablely', 'discordance', 'implode', 'maddening', 'monotonous', 'fallaciousness', 'strange', 'deviousness', 'gainsayer', 'fleer', 'deadweight', 'unravel', 'aggressive', 'obtrusive', 'agitate', 'backward', 'harms', 'shambles', 'hater', 'divisive', 'squash', 'misjudgment', 'ugliness', 'angriness', 'objections', 'puppet', 'frenzied', 'sarcasm', 'craziness', 'smuttier', 'impertinent', 'intrude', 'litigious', 'immoderate', 'irresolute', 'censure', 'heavy-handed', 'frown', 'bewildered', 'vengefulness', 'emphatically', 'reticent', 'imbroglio', 'scary', 'lurid', 'myth', 'dejection', 'meddle', 'serious', 'suspicions', 'uncompromising', 'abysmally', 'alas', 'panicky', 'antagonize', 'abysmal', 'disingenuous', 'coupists', 'betrayals', 'obnoxiously', 'grate', 'languorously', 'mediocrity', 'onerously', 'carelessness', 'disrupt', 'absurd', 'prickles', 'furiously', 'contortions', 'incommensurate', 'infringements', 'taunting', 'revolting', 'merciless', 'misconception', 'doubt', 'madder', 'prejudice', 'braggart', 'unnerving', 'onerous', 'gaggle', 'unnaturally', 'horribly', 'futilely', 'impatiently', 'desperate', 'criticize', 'brashly', 'diabolic', 'abominate', 'exaggeration', 'idiot', 'travesties', 'unipolar', 'vestiges', 'anxiously', 'bane', 'hypocrisy', 'avaricious', 'problematic', 'low-rated', 'curse', 'scarily', 'far-fetched', 'feckless', 'reprehensive', 'stinking', 'timidness', 'amiss', 'defunct', 'enslave', 'gripe', 'gullible', 'horrendous', 'dehumanization', 'desolation', 'belligerence', 'hothead', 'rife', 'sadly', 'sore', 'barbarity', 'ostracize', 'reluctance', 'slanderously', 'unfortunate', 'vulgar', 'depressed', 'strict', 'reprehensibly', 'apathy', 'insensitivity', 'disaccord', 'treason', 'disturbingly', 'inordinate', 'treachery', 'badly', 'disgruntled', 'catastrophe', 'cajole', 'poverty', 'wretch', 'insolence', 'discourage', 'downside', 'contention', 'drain', 'polemize', 'untimely', 'spoon-fed', 'virulent', 'unrealistic', 'fastuous', 'mysteriously', 'imploringly', 'sinful', 'partisans', 'indiscretion', 'imprudence', 'bleakly', 'lawbreaker', 'deign', 'imperialist', 'fallacy', 'insincerity', 'revile', 'misleading', 'demon', 'distrusting', 'grudges', 'betrayal', 'nightmare', 'sympathies', 'plebeian', 'shabby', 'betray', 'flagrantly', 'confused', 'repugn', 'enjoin', 'frantic', 'lukewarm', 'distort', 'adulteration', 'downbeat', 'apprehensions', 'complaint', 'thoughtlessness', 'aggression', 'wretchedness', 'grouch', 'incapably', 'subservience', 'dreadful', 'mournful', 'disgruntle', 'phony', 'cataclysmically', 'preposterously', 'sorrow', 'extortion', 'sting', 'disinclined', 'conspire', 'joker', 'wrath', 'haggard', 'snub', 'distrust', 'hoard', 'horrifyingly', 'thorny', 'diametrically', 'foe', 'infatuated', 'itch', 'pugnaciously', 'insultingly', 'exasperating', 'chafe', 'doom', 'fictitious', 'smouldering', 'sugar-coat', 'runaway', 'watchdog', 'crooked', 'bitingly', 'persecution', 'adulterate', 'caricature', 'misunderstand', 'overzealous', 'fatuous', 'crook', 'incoherently', 'disgustingly', 'belittling', 'collude', 'fatuity', 'deceitful', 'falter', 'losing', 'abjectly', 'consternation', 'incautious', 'misfit', 'condemn', 'grievous', 'inferiority', 'brutish', 'zealous', 'aggravating', 'forsake', 'vain', 'fears', 'abhor', 'erratic', 'sympathetic', 'rank', 'undesirable', 'barbarous', 'vehemently', 'botch', 'chaff', 'disrespectful', 'halfheartedly', 'downheartedly', 'dodgey', 'inevitable', 'inhuman', 'wickedness', 'dishonesty', 'maverick', 'cheap', 'effigy', 'displease', 'delirious', 'inequities', 'lascivious', 'dismalness', 'tedious', 'maliciousness', 'discontinuity', 'oddly', 'disgustful', 'flat-out', 'enormously', 'lurking', 'derisiveness', 'nebulously', 'set-up', 'maladjustment', 'ill-fated', 'temerity', 'embarrassment', 'sufferer', 'enormous', 'arcane', 'fainthearted', 'inexorably', 'puppets', 'perplexing', 'pretense', 'collusion', 'confrontation', 'imbalance', 'blaspheme', 'invalidity', 'disheartening', 'insatiable', 'cynical', 'little', 'loopholes', 'mourn', 'archaic', 'contemptible', 'agitator', 'indignity', 'condescend', 'false', 'stubbornness', 'superstition', 'obtuse', 'idiocy', 'oppressively', 'salacious', 'unspeakablely', 'aggrieve', 'fatuously', 'downfall', 'debacle', 'insolently', 'neurotic', 'baffle', 'anti-social', 'insensitive', 'nemesis', 'unfairly', 'bragger', 'so-cal', 'disgusted', 'lure', 'detestable', 'acridness', 'worry', 'malevolence', 'discourteous', 'begging', 'contend', 'skulk', 'disingenuously', 'declaim', 'foully', 'repugnance', 'miscreants', 'absurdly', 'provocative', 'mourner', 'mawkishness', 'smut', 'punish', 'unlamentably', 'unjustly', 'liar', 'desiccated', 'swore', 'horrifically', 'baffling', 'contrary', 'lambaste', 'fastidious', 'pest', 'cataclysm', 'spurn', 'anti-occupation', 'fanciful', 'strut', 'frighten', 'paupers', 'impetuous', 'argue', 'staggering', 'warlike', 'worries', 'hate', 'incoherence', 'upsettingly', 'nightmarish', 'annoying', 'insecurity', 'lawless', 'aghast', 'weaken', 'disinterested', 'puzzle', 'impudence', 'domineer', 'ambivalent', 'imploring', 'illusory', 'blab', 'hell', 'obscurity', 'strictly', 'thirst', 'bewilderment', 'desperation', 'forlornly', 'unacceptablely', 'little-known', 'prate', 'deplorably', 'stiflingly', 'unilateralism', 'sass', 'shrill', 'vexingly', 'vex', 'inarticulate', 'ridicule', 'battle-lines', 'slashing', 'rantingly', 'inhumanity', 'disgusting', 'convoluted', 'wicked', 'seethe', 'dumbfounded', 'resentment', 'mistrust', 'grouchy', 'nauseating', 'spitefulness', 'avarice', 'fussy', 'disappoint', 'rhetorical', 'erratically', 'incorrigibly', 'dubiously', 'servitude', 'trivial', 'gloatingly', 'swipe', 'bickering', 'beseech', 'meager', 'maladjusted', 'stupified', 'hardheaded', 'pompous', 'torment', 'alarming', 'biased', 'devastatingly', 'rage', 'displeasing', 'overstatement', 'havoc', 'ploy', 'recant', 'hateful', 'appallingly', 'divisively', 'childish', 'jeering', 'loathly', 'imperious', 'plead', 'decadent', 'bore', 'spooky', 'scapegoat', 'inconceivably', 'drastic', 'incredulously', 'nightmarishly', 'nauseatingly', 'criticism', 'superficial', 'dazed', 'bemoan', 'angry', 'growl', 'contravene', 'travesty', 'insinuation', 'floundering', 'irreconcilable', 'scarred', 'foreboding', 'fractious', 'posturing', 'traumatized', 'unfair', 'frictions', 'insidious', 'culpable', 'sardonic', 'hatefully', 'scoff', 'mindless', 'vice', 'hopelessly', 'abrasive', 'corrupt', 'dogged', 'hopelessness', 'cynicism', 'melancholy', 'critics', 'inexcusable', 'unimportant', 'untenable', 'dumb', 'disrespectfully', 'abominable', 'unsettle', 'shameful', 'dispiriting', 'heinous', 'sidetrack', 'condolence', 'refutation', 'god-awful', 'pretence', 'disregard', 'stalemate', 'worriedly', 'condolences', 'infamously', 'grimace', 'dizzingly', 'imminence', 'mad', 'obsessively', 'prideful', 'reactionary', 'incorrigible', 'disregardful', 'inflammatory', 'prosecute', 'devilry', 'complacent', 'defame', 'disparaging', 'dispute', 'insincere', 'smokescreen', 'intransigent', 'simplistic', 'ferocious', 'heretic', 'fruitless', 'unwelcome', 'extravagantly', 'silly', 'lie', 'lugubrious', 'vengeful', 'sneeringly', 'aversion', 'warily', 'abomination', 'subjugation', 'alarmingly', 'infuriated', 'grumble', 'castigate', 'complicit', 'infringe', 'blindside', 'mawkish', 'perplex', 'dishearteningly', 'edgy', 'misleadingly', 'run-down', 'inimical', 'remorseless', 'bully', 'martyrdom-seeking', 'overplay', 'desolate', 'disturbed', 'bedlam', 'screech', 'cutthroat', 'disinterest', 'exasperate', 'ineptly', 'unscrupulously', 'brutalities', 'lewdness', 'inconvenience', 'infidel', 'overstate', 'paradoxically', 'unbearablely', 'blandish', 'madness', 'chatterbox', 'ultimatum', 'sardonically', 'over-acted', 'imprudent', 'spoon-feed', 'damnably', 'delusion', 'admonishingly', 'intimidating', 'heartrending', 'halfhearted', 'overdue', 'dragon', 'nervousness', 'outcry', 'skeptically', 'angrily', 'contrariness', 'ferociously', 'debate', 'commotion', 'spite', 'unhappily', 'confuse', 'friggin', 'boisterous', 'adulterated', 'perfunctory', 'recalcitrant', 'inextricably', 'feebleminded', 'irritably', 'repugnantly', 'lechery', 'passe', 'dissembler', 'rejection', 'petrified', 'obscene', 'lier', 'tricky', 'delude', 'accusations', 'pity', 'callous', 'concede', 'fanatic', 'gape', 'mudslinger', 'unwise', 'contrive', 'malevolent', 'ignorance', 'pervasive', 'irrelevance', 'deploringly', 'hamper', 'unfavorable', 'laconic', 'exploitation', 'disunity', 'whine', 'evildoer', 'terrible', 'malodorous', 'contradiction', 'overbearingly', 'stereotypical', 'barren', 'ruthlessly', 'charisma', 'distressingly', 'farce', 'disillusion', 'strident', 'phobia', 'awkward', 'outlaw', 'dismissive', 'pitilessly', 'punch', 'insupportable', 'impious', 'destroyer', 'fret', 'misunderstanding', 'improbability', 'regretfully', 'hegemonistic', 'unconvincingly', 'unequal', 'denunciate', 'frantically', 'misread', 'cheapen', 'dissatisfactory', 'fume', 'incomprehension', 'malicious', 'disaffected', 'raving', 'whips', 'befoul', 'greed', 'villains', 'concerns', 'fell', 'dismayingly', 'petty', 'sorry', 'agonize', 'anxiety', 'manic', 'discomfititure', 'byzantine', 'discombobulate', 'overwhelming', 'glibly', 'acrid', 'idiotic', 'oppressors', 'audacious', 'gauche', 'rail', 'aggravation', 'tainted', 'anguish', 'traitorously', 'unwillingly', 'abusive', 'goddamn', 'dizzy', 'inelegance', 'inextricable', 'grief', 'gravely', 'goad', 'sully', 'scarier', 'harsh', 'troublingly', 'smugly', 'gruff', 'abuse', 'shockingly', 'underlings', 'timidity', 'poison', 'cautionary', 'gaudy', 'defy', 'conspicuous', 'suffocate', 'irredeemable', 'frightfully', 'anarchist', 'selfishness', 'traumatic', 'caustic', 'scarcely', 'sugar-coated', 'worryingly', 'molestation', 'wayward', 'smoldering', 'troublesomely', 'obscenity', 'calamities', 'darn', 'exasperatingly', 'misunderstandings', 'fascist', 'rebuke', 'fickle', 'effrontery', 'mistakes', 'defamatory', 'damn', 'reviled', 'partiality', 'enviously', 'wee', 'bland', 'sufferers', 'objectionable', 'depraved', 'craze', 'despicable', 'nagging', 'scoldingly', 'tiresome', 'gloomy', 'maniacal', 'gaffe', 'repulsiveness', 'imminent', 'sneer', 'sobering', 'scornfully', 'gaga', 'regret', 'corruption', 'indecent', 'incredulous', 'ranting', 'overemphasize', 'beggarly', 'audacity', 'insult', 'fretful', 'grotesque', 'profane', 'sorrowful', 'futility', 'jeopardize', 'petrify', 'shroud', 'disgraceful', 'accusingly', 'egotistical', 'militancy', 'shortsighted', 'worrisome', 'gracelessly', 'cravenly', 'discriminatory', 'detriment', 'victimize', 'egomania', 'flabbergasted', 'ludicrous', 'dungeon', 'beastly', 'condemnable', 'instigators', 'prevaricate', 'stooges', 'inconsequentially', 'degrade', 'indefensible', 'unrest', 'long', 'floored', 'irrational', 'regrettably', 'toil', 'guile', 'hardball', 'hapless', 'devilish', 'cringe', 'hotheaded', 'propaganda', 'backbite', 'grind', 'inaccurate', 'uneasy', 'relentless', 'degeneration', 'horrors', 'overkill', 'overworked', 'rile', 'lividly', 'plagiarize', 'fatalistically', 'disbelieve', 'denial', 'distastefully', 'incompetence', 'discontented', 'misbehave', 'mistrustful', 'preposterous', 'asinininity', 'remorseful', 'alarmed', 'embarrassing', 'uproariously', 'shyness', 'obstacle', 'indoctrinate', 'oddity', 'pugnacious', 'shrivel', 'inordinately', 'falsify', 'impatient', 'fury', 'traumatically', 'sacrifice', 'envy', 'inglorious', 'scornful', 'distressed', 'gruesomely', 'skeletons', 'martyrdom', 'kick', 'reprehensible', 'implausibly', 'annoy', 'languish', 'immorality', 'spoonfed', 'jealousy', 'stupid', 'wail', 'mistakenly', 'repulsive', 'tediously', 'heck', 'oppress', 'taunts', 'misunderstood', 'mock', 'overblown', 'scathing', 'staid', 'frustration', 'contemptuous', 'barbarian', 'livid', 'pillage', 'immodest', 'regretful', 'fraught', 'craven', 'severe', 'paradoxical', 'grievances', 'woebegone', 'dissent', 'overacted', 'villianously', 'aggrieved', 'recoil', 'laughable', 'entrapment', 'embroilment', 'outburst', 'outcast', 'awfulness', 'lame-duck', 'forlorn', 'desiccate', 'subservient', 'infringement', 'spiteful', 'appall', 'startling', 'bravado', 'dastardly', 'admonishment', 'disbeliever', 'scorn', 'terror-genic', 'inexorable', 'tormented', 'tyranny', 'uproar', 'perversely', 'abhorrence', 'delusional', 'scandals', 'iniquity', 'embroil', 'melodramatically', 'brutalize', 'nationalism', 'brazen', 'blunder', 'damning', 'bewilder', 'distraughtly', 'frustrate', 'disgrace', 'asininely', 'apprehensive', 'officious', 'inexplainable', 'mismanage', 'shunned', 'dogmatic', 'ugly', 'trickery', 'forsaken', 'maniac', 'lunatic', 'pretend', 'disapprobation', 'unwillingness', 'vile', 'manipulators', 'heresy', 'grievance', 'counterproductive', 'aloof', 'infamous', 'arduous', 'dissuasive', 'despondence', 'loathe', 'dreadfully', 'brainwash', 'anxieties', 'doggedly', 'improperly', 'invidious', 'disloyal', 'disappointment', 'aimless', 'illogically', 'cry', 'deceitfulness', 'objection', 'detestably', 'hawkish', 'skeptical', 'apologists', 'insufferable', 'stubbornly', 'undependability', 'stingingly', 'carnage', 'disapproving', 'worsen', 'predicament', 'faithless', 'deplore', 'irritating', 'left-leaning', 'scandalous', 'pandemonium', 'ruffian', 'gratuitous', 'mistake', 'burn', 'critical', 'self-serving', 'mocking', 'maliciously', 'hysterics', 'indecorum', 'acrimoniously', 'entrap', 'absurdity', 'mortify', 'fallacious', 'coward', 'agitated', 'bonkers', 'dishonorable', 'anger', 'jaded', 'outraged', 'berate', 'inconceivable', 'gloat', 'hedge', 'renunciation', 'baseless', 'sermonize', 'shriek', 'degradingly', 'discomfit', 'unfaithfully', 'nosey', 'spookily', 'avalanche', 'pillory', 'acerbic', 'stereotype', 'deplorable', 'dubitable', 'blah', 'damned', 'indisposed', 'compulsive', 'frivolous', 'irresponsibly', 'defile', 'falsely', 'irksome', 'heartless', 'swagger', 'wily', 'deploring', 'unbearable', 'disorganized', 'impolitely', 'mistrustfully', 'oddest', 'dauntingly', 'hideousness', 'whimper', 'leer', 'lovelorn', 'stress', 'drab', 'disobedient', 'plot', 'assassin', 'unfriendly', 'dawdle', 'farcical-yet-provocative', 'pervert', 'inconsolably', 'drama', 'smuttiest', 'nebulous', 'dissenter', 'poorly', 'denounce', 'naive', 'dissonantly', 'cruelties', 'abhorred', 'supremacy', 'uncompromisingly', 'dupe', 'superiority', 'imbecile', 'implausible', 'dearth', 'loathing', 'inequitably', 'unusually', 'pernicious', 'massacres', 'laughingstock', 'meanness', 'dangerousness', 'delirium', 'quitter', 'unjustifiable', 'geezer', 'lech', 'savaged', 'swear', 'compulsion', 'extermination', 'pitiless', 'inescapably', 'acridly', 'forgetfulness', 'misuse', 'worse', 'pittance', 'vociferously', 'harridan', 'horrifying', 'misbehavior', 'inhumane', 'disoriented', 'chagrin', 'beguile', 'impolite', 'licentious', 'seedy', 'shrilly', 'vehement', 'demoralizingly', 'burdensomely', 'unorthodox', 'irrationality', 'insolent', 'satirical', 'fear', 'lambast', 'oppression', 'blameworthy', 'disservice', 'bewildering', 'bristle', 'quarrels', 'inculcate', 'shamelessly', 'outrages', 'menacingly', 'empathy', 'terribleness', 'deluded', 'debaucher', 'disconcert', 'coerce', 'atrocity', 'blurt', 'infidels', 'oppressive', 'farcical', 'monstrosities', 'humiliate', 'savagely', 'illusion', 'mordant', 'slaves', 'ignominiously', 'hassle', 'undue', 'impending', 'facetiously', 'derisive', 'misreading', 'disarray', 'adamant', 'nefarious', 'apocalyptic', 'dissension', 'agony', 'beg', 'fallaciously', 'virus', 'drunk', 'jeer', 'unpleasantries', 'trouble', 'recklessness', 'payback', 'revulsion', 'shrew', 'despised', 'get-rich', 'dissident', 'inequitable', 'asinine', 'wiles', 'self-coup', 'barbarously', 'demeaning', 'diatribe', 'miserableness', 'harassment', 'desperately', 'bad', 'shiver', 'shortsightedness', 'deject', 'implore', 'blockhead', 'calamitously', 'egotism', 'fidgety', 'hotbeds', 'misinterpret', 'hard-line', 'ingrate', 'shadow', 'parody', 'seriously', 'deepening', 'nix', 'vengeance', 'boggle', 'torturous', 'abominably', 'perplexed', 'cataclysmal', 'roadblocks', 'indignation', 'misery', 'dissention', 'misdirection', 'shortchange', 'hollow', 'aspersions', 'disastrous', 'aggressiveness', 'insulting', 'bestial', 'brute', 'fun', 'falsehood', 'unspeakable', 'fustigate', 'irredeemably', 'inconstant', 'blasted', 'deadlock', 'bondage', 'inflict', 'ungovernable', 'horrendously', 'incompetent', 'inescapable', 'puny', 'obliterated', 'pratfall', 'biting', 'repulsively', 'stubborn', 'weird', 'shrouded', 'discouraging', 'excessive', 'nastiness', 'lacking', 'vindictively', 'gibberish', 'dissocial', 'cackle', 'savages', 'exclaim', 'inimically', 'repulsing', 'vexation', 'asunder', 'rumours', 'chastisement', 'leery', 'reproach', 'mindlessly', 'stodgy', 'endanger', 'awfully', 'disinclination', 'defrauding', 'backwardness', 'frustrated', 'opponent', 'shady', 'enormities', 'spookiest', 'horrify', 'obscure', 'insincerely', 'crazy', 'foolishness', 'violate', 'draconian', 'puzzled', 'ill-treatment', 'self-interest', 'severely', 'lamentable', 'weirdly', 'untrustworthy', 'vagrant', 'covet', 'ego', 'abhorrently', 'thoughtlessly', 'mystery', 'galling', 'stigmatize', 'irately', 'inequality', 'rogue', 'cursed', 'one-side', 'pitiable', 'morbidly', 'swamped', 'disvalue', 'dangle', 'imposition', 'irritation', 'scar', 'dishearten', 'killjoy', 'mirage', 'smack', 'waning', 'huckster', 'envious', 'worst', 'melodramatic', 'impair', 'despoil', 'bleakness', 'rattle', 'shame', 'unworkable', 'molest', 'inanely', 'autocratic', 'despairing', 'ominous', 'despise', 'adamantly', 'exterminate', 'viciously', 'skittishly', 'hypocritically', 'disadvantage', 'nefariously', 'perish', 'merely', 'stagnate', 'invalidate', 'grudging', 'torturously', 'detrimental', 'pertinacity', 'scared', 'injustice', 'despot', 'standstill', 'annoyingly', 'villify', 'fearful', 'ordeal', 'unreliable', 'debauchery', 'disavowal', 'wary', 'loath', 'boil', 'bombardment', 'disagreeably', 'emphatic', 'quarrelsome', 'concern', 'pedantic', 'perversion', 'underestimate', 'fanaticism', 'stridently', 'strife', 'smother', 'hinder', 'inhospitable', 'mangle', 'bizarre', 'hubris', 'burden', 'election-rigger', 'impediment', 'bereavement', 'incessantly', 'slander', 'distrustful', 'acerbate', 'shamelessness', 'glib', 'absurdness', 'revulsive', 'oppositions', 'tyrant', 'sadden', 'scorching', 'scoundrel', 'turmoil', 'moody', 'odder', 'daunting', 'indiscriminate', 'ill-conceived', 'inelegant', 'ill-used', 'plaything', 'selfishly', 'hysteria', 'scorchingly', 'hedonistic', 'jittery', 'atrocities', 'miserable', 'cumbersome', 'selfinterested', 'indecency', 'hell-bent', 'spilling', 'frighteningly', 'kaput', 'thoughtless', 'zealot', 'disgustfully', 'ineloquently', 'egregiously', 'franticly', 'impaired', 'scourge', 'sin', 'virulently', 'nettlesome', 'jeeringly', 'enraged', 'formidable', 'trample', 'appalled', 'utter', 'mercilessly', 'dehumanize', 'grudgingly', 'shark', 'confusing', 'sarcastic', 'distortion', 'obsessiveness', 'troubling', 'self-destructive', 'busybody', 'shatter', 'monstrosity', 'afflictive', 'askance', 'calumnious', 'antiquated', 'jaundiced', 'wanton', 'gallingly', 'anti-US', 'subjugate', 'demoralize', 'inconsiderate', 'inundate', 'mysterious', 'lone', 'insinuating', 'vainly', 'agitation', 'distraughtness', 'freakishly', 'deprave', 'lewdly', 'scars', 'embroiled', 'hatred', 'nonsense', 'devastating', 'unjustifiably', 'weakness', 'bothersome', 'annihilation', 'bafflement', 'gawky', 'batty', 'catastrophes', 'peevishly', 'repudiate', 'dim', 'brashness', 'indignant', 'hypocrites', 'mortified', 'ruthless', 'wilt', 'bullies', 'ache', 'notorious', 'rankle', 'misbecoming', 'defamation', 'ambivalence', 'distress', 'humbling', 'mishap', 'blister', 'condemnation', 'mulish', 'violator', 'spade', 'ashamed', 'ominously', 'debatable', 'ironies', 'unexpectedly', 'famished', 'excruciating', 'bullyingly', 'undependable', 'grave', 'hamstring', 'austere', 'instigate', 'miserly', 'intransigence', 'unsettling', 'disdain', 'foolhardy', 'outrage', 'deception', 'unprecedented', 'lack', 'detest', 'massacre', 'longingly', 'overact', 'shamefully', 'misfortune', 'dismissively', 'hardships', 'pathetic', 'procrastination', 'devious', 'dissonance', 'capricious', 'aggravate', 'downhearted', 'horrid', 'torrent', 'hardly', 'uneasily', 'malice', 'starkly', 'unwilling', 'admonisher', 'twisted', 'bashful', 'weary', 'sham', 'slap', 'wretched', 'importune', 'heavily', 'compel', 'devoid', 'filthy', 'goading', 'sinisterly', 'succumb', 'tramp', 'listless', 'terribly', 'besmirch', 'coercive', 'degenerately', 'disobedience', 'forgetful', 'timidly', 'unlamentable', 'vengefully', 'tragically', 'dungeons', 'critic', 'miser', 'quandary', 'maledict', 'naughty', 'touchy', 'menacing', 'deceitfully', 'frightful', 'decrepitude', 'polluters', 'impudent', 'disaffirm', 'calumniously', 'emotional', 'boiling', 'indiscriminating', 'profanity', 'monotony', 'dispiritedly', 'indiscreet', 'jealous', 'unfounded', 'unfeeling', 'fanatics', 'greedy', 'dunce', 'devil', 'improper', 'deceit', 'atrocious', 'stench', 'tired', 'impolitic', 'mistaken', 'repugnant', 'ill-treated', 'disrespecting', 'bicker', 'ramshackle', 'uproarously', 'zealously', 'ungrateful', 'anxiousness', 'wrangle', 'smutty', 'catastrophic', 'upbraid', 'ferocity', 'terrorize', 'pitifully', 'slime', 'vie', 'loathsome', 'malign', 'denunciation', 'opinionated', 'disorient', 'brat', 'fright', 'unhappy', 'banalize', 'unrelenting', 'wariness', 'fastidiously', 'irony', 'immoral', 'derisively', 'depressing', 'doldrums', 'lecher', 'agonizing', 'admonition', 'usurp', 'reprehension', 'rebuff', 'simmer', 'hopeless', 'troublemaker', 'disillusioned', 'backbiting', 'self-humiliation', 'abasement', 'scummy', 'disputed', 'drunkard', 'squirm', 'hindrance', 'unpleasant', 'deprecate', 'guilt', 'graceless', 'unclean', 'mediocre', 'disfavor', 'sabotage', 'mordantly', 'appalling', 'unreliability', 'contort', 'annoyed', 'inconveniently', 'frazzle', 'hatefulness', 'suspicious', 'grouse', 'radicalization', 'unhappiness', 'limp', 'indecision', 'multi-polarization', 'catastrophically', 'lurch', 'indulge', 'woefully', 'inundated', 'pressing', 'inconsequent', 'irrelevant', 'indecisive', 'last-ditch', 'strangely', 'thwart', 'frustrating', 'freak', 'stooge', 'laugh', 'rollercoaster', 'simplistically', 'invalid', 'destructive', 'anti-', 'unworthy', 'immorally', 'traitor', 'inconsequential', 'flirty', 'dullard', 'inferior', 'precipitous', 'depressingly', 'oddities', 'caustically', 'inapt', 'inappropriate', 'jeers', 'inconsolable', 'conceit', 'disaster', 'overzealously', 'disapprove', 'cheerless', 'cheat', 'dishonest', 'lawbreaking', 'animosity', 'stigma', 'inconvenient', 'peculiar', 'appal', 'stressful', 'scare', 'anti-Israeli', 'hypocrite', 'awful', 'uncivil', 'knave', 'dilapidated', 'carp', 'banishment', 'horrific', 'downer', 'glum', 'divisiveness', 'unbelievably', 'dire', 'pain', 'questionable', 'bogus', 'hysteric', 'blunt', 'suspiciously', 'disappointed', 'lazy', 'grieving', 'erroneously', 'boring', 'debaser', 'fault', 'licentiousness', 'battleground', 'loophole', 'pleadingly', 'cheater', 'cliched', 'baffled', 'negligence', 'offenses', 'veto', 'prejudicial', 'perfidity', 'dummy', 'stricken', 'sputter', 'remorse', 'irreparable', 'macabre', 'loot', 'naively', 'denunciations', 'overdone', 'laughter', 'estranged', 'bereave', 'inconsiderately', 'calumny', 'farcically', 'vociferous', 'satirize', 'futile', 'enrage', 'miscreant', 'calumnies', 'condescendingly', 'lawlessness', 'barbaric', 'diffidence', 'weaknesses', 'disapproval', 'superfluous', 'erroneous', 'incendiary', 'chastise', 'presume', 'iniquitous', 'ape', 'disconcertingly', 'fawn', 'bungler', 'illusions', 'scheming', 'unsuspecting', 'worrier', 'stupidity', 'pauper', 'resentful', 'morbid', 'pains', 'covetously', 'apathetic', 'debauch', 'forswear', 'foulness', 'boastful', 'hideously', 'shy', 'exacerbate', 'fanatical', 'squabbling', 'complaints', 'bewilderingly', 'ill-advised', 'outrageousness', 'paranoia', 'derogatory', 'offending', 'hypocritical', 'disbelief', 'confusion', 'non-confidence', 'decry', 'execrate', 'dissatisfy', 'expire', 'moribund', 'ignominy', 'disturbed-let', 'worrying', 'glaringly', 'harpy', 'apprehensively', 'doubts', 'despoiler', 'crass', 'mischievously', 'unwisely', 'despairingly', 'goddam', 'distressing', 'pleas', 'disclaim', 'accuse', 'scum', 'insinuate', 'fuss', 'sickeningly', 'bemoaning', 'cranky', 'infernal', 'outrageous', 'chit', 'awkwardness', 'dissidents', 'plotters', 'discordant', 'ineloquent', 'disparagingly', 'fawningly', 'quash', 'sadness', 'pessimistically', 'inaptitude', 'nag', 'insouciance', 'sickly', 'inflame', 'fulminate', 'letch', 'pertinacious', 'unleash', 'spook', 'mislike', 'phobic', 'unattractive', 'radically', 'gabble', 'irreverent', 'disquieting'}, 'spos': {'hallowed', 'terrifically', 'adoringly', 'renowned', 'ovation', 'effusion', 'superbly', 'generously', 'rational', 'best', 'redeeming', 'gorgeously', 'pinnacle', 'steadfast', 'moderate', 'lovable', 'unselfish', 'hearten', 'protector', 'miracle', 'wonderful', 'master', 'edify', 'candid', 'indomitable', 'moralize', 'reassure', 'affection', 'irrefutable', 'lust', 'tempting', 'dare', 'rapturously', 'astutely', 'mesmerize', 'revere', 'nifty', 'exceptional', 'ascendant', 'esteem', 'uttermost', 'amazement', 'demand', 'merit', 'frank', 'trusting', 'grateful', 'charmingly', 'famously', 'adulation', 'charming', 'lovely', 'tolerance', 'appealing', 'beneficent', 'marvel', 'altruistically', 'poignant', 'arousing', 'luxurious', 'squarely', 'romantically', 'admirable', 'catalyst', 'excellently', 'chivalry', 'trustingly', 'courageously', 'rectify', 'fantastic', 'handsome', 'resounding', 'masterpiece', 'uncommonly', 'radiant', 'incredible', 'intriguing', 'explicitly', 'forgive', 'mercifully', 'kid', 'truculent', 'rousing', 'promising', 'reward', 'understatedly', 'intriguingly', 'lucidly', 'rosy', 'law-abiding', 'preaching', 'clout', 'lavishly', 'dreamland', 'thoughtfully', 'valuable', 'noble', 'endorser', 'paradise', 'insistently', 'articulate', 'rapport', 'expansive', 'heartening', 'awesomely', 'heartfelt', 'intimacy', 'stellar', 'forgivingly', 'hanker', 'inspire', 'profusely', 'glamorous', 'assertions', 'rectifying', 'exalted', 'skillful', 'greatness', 'praiseworthy', 'preferences', 'indubitable', 'glow', 'favorable', 'fervidly', 'harmoniously', 'pardon', 'overjoyed', 'loyalty', 'adore', 'assiduous', 'soften', 'unconcerned', 'beneficially', 'excusable', 'magnanimously', 'distinguished', 'steadfastness', 'willfully', 'comforting', 'shimmering', 'yearningly', 'gladly', 'realistic', 'seductive', 'unequivocal', 'prudent', 'prettily', 'hail', 'star', 'marvellous', 'benevolent', 'craving', 'outdo', 'undoubted', 're-conquest', 'graceful', 'exhilarate', 'humble', 'meek', 'dedicated', 'doubtless', 'prodigy', 'exaltation', 'delightfully', 'sophisticated', 'tolerable', 'effortlessly', 'amazing', 'ebulliently', 'flatteringly', 'famed', 'overachiever', 'ameliorate', 'beautiful', 'inspiring', 'jovial', 'fortunately', 'memorialize', 'extol', 'perspicuous', 'well-run', 'glowing', 'surpass', 'undisputable', 'trendy', 'discerning', 'renaissance', 'respect', 'hopes', 'saintly', 'sensible', 'manly', 'gorgeous', 'gallantly', 'beautifully', 'gusto', 'vivid', 'shrewdly', 'perseverance', 'integrity', 'smartly', 'civility', 'kindness', 'effusive', 'passionately', 'eloquent', 'indelible', 'dexterous', 'condone', 'supreme', 'keenly', 'deserved', 'delightfulness', 'sane', 'excitedness', 'smart', 'insightful', 'promise', 'consensus', 'hope', 'luckiest', 'adoring', 'flawless', 'humorously', 'meaningful', 'sparkle', 'raptureously', 'indisputable', 'lively', 'rapt', 'tremendous', 'devotee', 'gracious', 'tantalizing', 'straightforward', 'mastery', 'titillatingly', 'rightfully', 'cornerstone', 'solidarity', 'earnestness', 'truly', 'hopefully', 'greatest', 'well-connected', 'nurturing', 'closeness', 'beneficiary', 'tranquility', 'brag', 'worthiness', 'sagacity', 'immaculate', 'worthwhile', 'conciliate', 'hopeful', 'charm', 'trump', 'tolerantly', 'phenomenally', 'thrill', 'resourceful', 'unfettered', 'pro-Cuba', 'right', 'stupendously', 'understate', 'inspirational', 'eminent', 'amuse', 'keenness', 'irresistible', 'indispensable', 'safeguard', 'pleading', 'harmless', 'eclectic', 'rewarding', 'candor', 'sacred', 'quasi-ally', 'elated', 'reverent', 'incontrovertible', 'pleased', 'positiveness', 'triumphal', 'agreeability', 'agreeably', 'gratify', 'astonishingly', 'remarkable', 'righteousness', 'grandeur', 'opulent', 'unquestionably', 'stirring', 'super', 'precious', 'spellbound', 'foresight', 'surging', 'entranced', 'celebratory', 'lover', 'solicitous', 'endearing', 'outshine', 'chivalrous', 'bold', 'fancy', 'heroic', 'nicely', 'pacifists', 'keen', 'exhilaratingly', 'correctly', 'satisfactory', 'mesmerizing', 'preference', 'wondrous', 'fascination', 'amicable', 'generosity', 'stride', 'forgiven', 'irrefutably', 'overture', 'vouch', 'solicitude', 'indulgent', 'admirably', 'allay', 'fearlessly', 'affirmation', 'feisty', 'engaging', 'marvels', 'captivate', 'effortless', 'unpretentious', 'sage', 'indubitably', 'pious', 'quicken', 'simplicity', 'posh', 'outstanding', 'plausible', 'felicity', 'fervent', 'wellbeing', 'earnest', 'recommended', 'plush', 'likable', 'compassionate', 'personality', 'sociable', 'recommend', 'admirer', 'miraculous', 'convenient', 'enviable', 'truth', 'humor', 'captivating', 'bless', 'constancy', 'joke', 'wholeheartedly', 'fascinating', 'appreciativeness', 'respectable', 'amicably', 'enviably', 'brilliant', 'relish', 'unquestionable', 'talented', 'divine', 'matchless', 'repent', 'ingeniously', 'worth-while', 'tremendously', 'jauntily', 'admire', 'applaud', 'recommendation', 'excitement', 'boast', 'truthful', 'exuberant', 'relent', 'privileged', 'impregnable', 'accolades', 'exquisitely', 'spellbindingly', 'true', 'befit', 'splendor', 'zest', 'epic', 'eloquence', 'dazzling', 'regally', 'funny', 'uplifting', 'enchant', 'acclamation', 'bargain', 'jaunty', 'raptureous', 'ingenuously', 'fervid', 'pro-Beijing', 'enjoyably', 'unabashedly', 'praising', 'avidly', 'embellish', 'triumphantly', 'illuminati', 'aver', 'affable', 'cheery', 'impressive', 'alluring', 'guiltless', 'well-wishers', 'spur', 'honestly', 'encouragingly', 'heavenly', 'pro-American', 'fearless', 'world-famous', 'tact', 'flawlessly', 'allure', 'willingness', 'gratefully', 'preponderance', 'precaution', 'amaze', 'love', 'tenacious', 'conveniently', 'suave', 'exhilarating', 'trustworthy', 'indefatigable', 'kemp', 'brook', 'surmise', 'thrills', 'perfection', 'attractively', 'elegance', 'yearn', 'featly', 'dodge', 'friendliness', 'appreciate', 'beautify', 'elan', 'hospitable', 'pleasure', 'extoll', 'infallibly', 'poised', 'favorite', 'hopefulness', 'curiously', 'infallible', 'clearer', 'engrossing', 'favor', 'humourous', 'fond', 'deservedly', 'motivate', 'excited', 'laud', 'outstrip', 'ingenuous', 'relief', 'improvise', 'ecstasy', 'stately', 'euphoria', 'astute', 'strikingly', 'courageous', 'optimal', 'yearning', 'savvy', 'humankind', 'acclaim', 'inclined', 'excellence', 'captivation', 'dexterously', 'sure', 'prosper', 'amiable', 'imaginative', 'sumptuous', 'astounding', 'fantastically', 'mercy', 'sanction', 'mollify', 'covetingly', 'assuredly', 'kingmaker', 'upheld', 'ebullience', 'potent', 'resplendent', 'studiously', 'striving', 'masters', 'lush', 'talent', 'upside', 'stunningly', 'invincibility', 'venerably', 'realist', 'daringly', 'jubilation', 'coveting', 'enthral', 'deft', 'epitome', 'fabulously', 'moving', 'gutsy', 'enrapt', 'brilliantly', 'liking', 'splendid', 'devote', 'stylish', 'yep', 'astounded', 'dream', 'sentiments', 'cure-all', 'judicious', 'prodigious', 'gleeful', 'stylishly', 'agreeableness', 'advantageous', 'luckier', 'upbeat', 'remunerate', 'vanquish', 'refreshing', 'satisfaction', 'luster', 'illuminate', 'lionhearted', 'defender', 'astoundingly', 'torrid', 'smitten', 'insistent', 'wisely', 'magnificently', 'destiny', 'indelibly', 'propitious', 'tidy', 'well-informed', 'fortitude', 'astonishment', 'unforgettable', 'gratification', 'gaiety', 'inclination', 'prodigiously', 'recommendations', 'rectification', 'thoughtfulness', 'giddy', 'resourcefulness', 'humility', 'sweeping', 'courage', 'cogent', 'tolerably', 'especially', 'befriend', 'compliment', 'noteworthy', 'palliate', 'almighty', 'inviolable', 'conciliatory', 'valiantly', 'clearly', 'heroine', 'patiently', 'indomitably', 'euphorically', 'painstaking', 'fitting', 'mesmerizingly', 'redeem', 'entreatingly', 'fragrant', 'truculently', 'magnificence', 'vindicate', 'astound', 'joyless', 'crusade', 'exquisite', 'worthy', 'dote', 'lofty', 'excel', 'handily', 'fantasy', 'incorruptible', 'prestige', 'understood', 'breathtaking', 'glorious', 'idolized', 'avid', 'notable', 'manifest', 'sublime', 'mannerly', 'peaceable', 'eminence', 'fortunate', 'prefer', 'elation', 'attraction', 'ultimate', 'ingratiating', 'gratifying', 'satisfactorily', 'unfazed', 'flattering', 'pledge', 'sagely', 'effusiveness', 'glad', 'miraculously', 'smiling', 'fame', 'imploringly', 'herald', 'intrigue', 'vivacious', 'blameless', 'honest', 'heartily', 'excellency', 'innocuous', 'pride', 'outstandingly', 'breathlessness', 'invulnerable', 'apostle', 'sentimentally', 'cheerful', 'exceedingly', 'please', 'palatial', 'acumen', 'brains', 'genius', 'faithfully', 'infatuated', 'coax', 'delicious', 'fashionable', 'triumphant', 'jolly', 'sanity', 'better-known', 'oasis', 'rapture', 'goodwill', 'reminiscent', 'steadfastly', 'placate', 'complement', 'eager', 'tantalizingly', 'endorse', 'breathtakingly', 'majestic', 'entrancing', 'virtuous', 'masterfully', 'graciousness', 'fervor', 'first-rate', 'sentimentality', 'glitter', 'perfect', 'richly', 'opportunity', 'poetic', 'amiabily', 'terrific', 'poise', 'absolve', 'conscientious', 'quaint', 'wonderously', 'mighty', 'enchanted', 'arresting', 'fashionably', 'sanguine', 'hilarity', 'wonderous', 'forgave', 'fascinate', 'tenaciously', 'adroit', 'visionary', 'astonished', 'statuesque', 'hug', 'congratulations', 'beauteous', 'staunch', 'attractive', 'exemplary', 'enjoyment', 'providence', 'prize', 'commend', 'gaily', 'exultation', 'understandable', 'spiritual', 'persevere', 'earnestly', 'sexy', 'galore', 'ingratiatingly', 'terrify', 'privilege', 'opportune', 'yes', 'dashing', 'eagerly', 'fortune', 'gumption', 'persuasive', 'electrification', 'merciful', 'luck', 'memorable', 'flexible', 'gratitude', 'imploring', 'convincing', 'exceeding', 'undisputably', 'upliftment', 'sanctity', 'enthrall', 'bliss', 'shrewd', 'pragmatic', 'obedient', 'affirm', 'scruples', 'repentance', 'auspicious', 'lifeblood', 'sincerely', 'tingle', 'assent', 'honesty', 'luxuriant', 'courageousness', 'glisten', 'striking', 'respite', 'ideally', 'exult', 'enthusiastically', 'exemplar', 'kindly', 'realistically', 'pro-peace', 'crave', 'enthuse', 'plead', 'prowess', 'worth', 'justifiable', 'pithy', 'explicit', 'merriness', 'convincingly', 'amour', 'joyous', 'thinkable', 'wishes', 'stupendous', 'congratulate', 'stunning', 'daydreamer', 'uncommon', 'honorable', 'rave', 'adventurism', 'intelligible', 'excellent', 'dextrous', 'accede', 'proud', 'just', 'enduring', 'magnificent', 'humane', 'assiduously', 'foremost', 'blissful', 'impeccable', 'luckily', 'nice', 'generous', 'dear', 'flourishing', 'exonerate', 'grit', 'contentment', 'gladness', 'marvelousness', 'creative', 'novel', 'elatedly', 'coherence', 'inquisitive', 'magic', 'smilingly', 'vitality', 'regard', 'imperturbable', 'wish', 'invincible', 'glorify', 'warmly', 'patriotic', 'deserve', 'understand', 'redemption', 'veritable', 'invaluable', 'passionate', 'flourish', 'wise', 'excitedly', 'masterpieces', 'desirous', 'sumptuousness', 'priceless', 'comrades', 'eternity', 'desirable', 'phenomenal', 'richness', 'glee', 'magnanimous', 'lark', 'vouchsafe', 'sensitivity', 'vital', 'preferably', 'compelling', 'unbosom', 'bravery', 'pleasing', 'adulate', 'adulatory', 'dignified', 'unassailable', 'heady', 'dazzle', 'luxuriously', 'terrifyingly', 'morality', 'courteous', 'courtesy', 'exultingly', 'considerate', 'fondness', 'incisively', 'meritorious', 'ingratiate', 'determination', 'credence', 'indispensability', 'wisdom', 'justification', 'serenity', 'apotheosis', 'content', 'glossy', 'humour', 'blessing', 'well-intentioned', 'receptive', 'erudite', 'wink', 'amicability', 'endure', 'awe', 'righten', 'splendidly', 'fondly', 'rejoicingly', 'serene', 'assure', 'admittedly', 'faithfulness', 'lyrical', 'acclaimed', 'admiration', 'poeticize', 'surge', 'ardently', 'altruistic', 'laudable', 'curious', 'god-given', 'saint', 'jubilant', 'clear-cut', 'affectionate', 'healthful', 'painstakingly', 'insight', 'precautions', 'friendly', 'joy', 'frolic', 'lucid', 'heartwarming', 'justify', 'jubilantly', 'commendable', 'idealize', 'glory', 'mirth', 'zenith', 'credible', 'awed', 'virtue', 'astonish', 'outsmart', 'witty', 'enthusiast', 'halcyon', 'exceed', 'illumine', 'respectful', 'exhilaration', 'advocate', 'supurbly', 'enthusiastic', 'tempt', 'congratulatory', 'skillfully', 'agreeable', 'altruist', 'jest', 'chaste', 'thankful', 'everlasting', 'best-performing', 'blissfully', 'spectacular', 'carefree', 'sprightly', 'extraordinarily', 'masterful', 'beauty', 'salute', 'exalt', 'bolster', 'proficiently', 'inestimably', 'illuminating', 'jubilate', 'reverently', 'self-determination', 'intelligent', 'preach', 'self-satisfaction', 'beatify', 'illustrious', 'impervious', 'goodness', 'titillating', 'accolade', 'staunchly', 'offbeat', 'rightness', 'congenial', 'faithful', 'radiance', 'unparalleled', 'easygoing', 'mindful', 'whimsical', 'shrewdness', 'divinely', 'romantic', 'lovably', 'plenty', 'comely', 'hilarious', 'destinies', 'dazzled', 'inestimable', 'plausibility', 'loveliness', 'enchanting', 'idyllic', 'aspiration', 'merrily', 'better', 'cherished', 'thankfully', 'terrified', 'rapturous', 'exceptionally', 'enticing', 'delighted', 'patience', 'plainly', 'smile', 'laudably', 'arousal', 'gracefully', 'heros', 'celebration', 'liberty', 'well-received', 'handy', 'levity', 'exuberantly', 'felicitate', 'fit', 'toast', 'studious', 'tranquil', 'glimmering', 'gloat', 'knowledgeable', 'aspirations', 'cheer', 'profusion', 'respectfully', 'intuitive', 'obedience', 'darling', 'adroitly', 'gifted', 'wry', 'exalting', 'luckiness', 'amusingly', 'awestruck', 'exaltingly', 'benevolence', 'advocacy', 'motivation', 'fortuitous', 'fidelity', 'renown', 'merriment', 'hale', 'irresistibly', 'sanctify', 'encouraging', 'rejoice', 'flatter', 'luxury', 'ingenuity', 'immaculately', 'spectacularly', 'amazingly', 'prudently', 'winners', 'honor', 'entreat', 'harmonious', 'bonny', 'unanimous', 'shimmer', 'valiant', 'enchantingly', 'stellarly', 'warmhearted', 'persuasively', 'hardier', 'adorer', 'courtly', 'hero', 'pundits', 'inclinations', 'profound', 'ascertainable', 'commendably', 'reassurance', 'concur', 'devoted', 'favour', 'majesty', 'support', 'forgiving', 'pledges', 'willful', 'glistening', 'compliant', 'groundbreaking', 'well-being', 'impressiveness', 'palatable', 'enthralled', 'ultra', 'entice', 'picturesque', 'spotless', 'twinkly', 'rightly', 'sensitively', 'supurb', 'angelic', 'joyful', 'woo', 'sworn', 'sensationally', 'better-than-expected', 'hilariousness', 'celebrate', 'lustrous', 'might', 'indestructible', 'ebullient', 'wonder', 'outwit', 'urge', 'endear', 'euphoric', 'implore', 'utmost', 'amusement', 'proactive', 'appreciatively', 'attest', 'idolize', 'incontestable', 'terrifying', 'complimentary', 'perspicuously', 'fun', 'impressively', 'tribute', 'daring', 'amiability', 'beneficial', 'scrupulously', 'torridly', 'grin', 'smarter', 'invaluablely', 'want', 'bountiful', 'sensation', 'superb', 'preferable', 'humorous', 'temptingly', 'encouragement', 'wishing', 'enticingly', 'repay', 'deserving', 'penitent', 'wonderfully', 'homage', 'adorable', 'motivated', 'shiny', 'covet', 'uphold', 'chic', 'cherish', 'elegantly', 'invigorating', 'obey', 'thank', 'virtuously', 'ingenious', 'positively', 'ardor', 'indescribably', 'great', 'believable', 'fabulous', 'heroically', 'entertaining', 'marvelous', 'consummate', 'well-managed', 'marvelously', 'like', 'eloquently', 'sumptuously', 'fortuitously', 'indescribable', 'obviate', 'definitively', 'sensational', 'gratifyingly', 'calming', 'undaunted', 'alluringly', 'sensibly', 'surely', 'joyfully', 'brainy', 'winnable', 'adored', 'trustworthiness', 'dotingly', 'infallibility', 'magical', 'demystify', 'befitting', 'ardent', 'confute', 'glowingly', 'boundless', 'surmount', 'elegant', 'persuade', 'salutary', 'supporter', 'astonishing', 'ultimately', 'punctual', 'grace', 'soothingly', 'understated', 'delight', 'fanfare', 'nimble', 'solace', 'cute', 'monumentally', 'endurable', 'gladden', 'delightful', 'amenable', 'truthfully', 'profess', 'faith', 'appreciation', 'valor', 'patriot', 'insist', 'irreproachable', 'miracles', 'ecstatic', 'staunchness', 'nurture', 'zeal', 'rally', 'cherub', 'effusively', 'eagerness', 'gloriously', 'perceptive', 'perfectly', 'maximize', 'ecstatically', 'deference', 'clever', 'happily', 'agree', 'confidence', 'ecstasies', 'highlight', 'paramount', 'trepidation', 'arouse', 'kind', 'ideal', 'brave', 'excitingly', 'stimulating', 'hilariously', 'gleefully', 'thrillingly', 'passion', 'endorsement', 'daydream', 'stirringly', 'profoundly', 'abide', 'abidance', 'merry', 'fervently', 'workable', 'celebrated', 'pretty', 'confident', 'happiness', 'impassioned', 'unabashed', 'pleasurable', 'blithe', 'gainfully', 'light-hearted', 'court', 'trumpet', 'exciting', 'time-honored', 'amazed', 'incisive', 'compassion', 'praise', 'happy', 'interesting', 'boldly', 'haven', 'desire', 'crusader', 'upliftingly', 'lucky', 'inviolate', 'triumph', 'seamless', 'moderation', 'cozy', 'togetherness', 'miraculousness', 'pacifist', 'aspire', 'mellow', 'soothe', 'attentive', 'optimism', 'okay', 'propitiously', 'scrupulous', 'smartest', 'remarkably', 'stunned', 'dauntless', 'justifiably', 'fascinatingly', 'amusing', 'reverence', 'awesomeness', 'heroize', 'boldness', 'purposeful', 'pleasingly', 'undoubtedly', 'profuse', 'admiring', 'compensate', 'playful', 'spellbinding', 'admiringly', 'appreciative', 'vow', 'spellbind', 'peerless', 'lavish', 'beloved', 'rightful', 'enthusiasm', 'saintliness', 'greet', 'obediently', 'thoughtful', 'gainful', 'mightily', 'joyously', 'catchy', 'wholesome', 'tenacity', 'glimmer', 'monumental', 'embrace', 'incisiveness', 'sensations', 'awesome', 'momentous', 'obliged', 'enjoyable', 'incredibly', 'righteous', 'evocative', 'sanctuary', 'justly', 'righteously', 'ethical', 'thrilling', 'graciously', 'festive', 'willing', 'forgiveness', 'ennoble', 'impel', 'rewardingly', 'enraptured', 'best-known', 'truthfulness', 'salvation', 'conceivable', 'unequivocally', 'playfully', 'well-regarded', 'felicitous', 'notably', 'pleadingly', 'vibrant', 'moral', 'romanticize', 'vulnerable', 'sentiment', 'harmonize', 'solicitously', 'penetrating', 'indulgence', 'devotion', 'eulogize', 'will', 'evidently', 'impeccably', 'proficient', 'charismatic', 'exaltedly', 'revel', 'exuberance', 'fawn', 'finely', 'promoter', 'gallant', 'inoffensive', 'supportive', 'nobly', 'venerable', 'pleasurably', 'ally', 'covetously', 'rejoicing', 'superlative', 'delectable', 'kindliness', 'sincere', 'vibrantly', 'inspiration', 'godlike', 'shimmeringly', 'consent', 'self-respect', 'admit', 'pillar', 'stars', 'supremely', 'idol', 'refuge', 'regal', 'dignity', 'expertly', 'liberate', 'extraordinary', 'adventuresome', 'welcome', 'insightfully', 'treasure', 'wow', 'harmony'}, 'sneu': {'needful', 'scrutiny', 'therefore', 'proclaim', 'fundamental', 'confide', 'downright', 'imperative', 'know', 'quite', 'theoretize', 'ponder', 'prognosticate', 'knowing', 'immensely', 'revealing', 'mantra', 'seemingly', 'surprising', 'extemporize', 'opinions', 'presumably', 'air', 'fortress', 'considerable', 'precious', 'surprise', 'greatly', 'surprisingly', 'absolute', 'feelings', 'fixer', 'consider', 'knowledge', 'deduce', 'fundamentally', 'aware', 'indicative', 'immensity', 'oh', 'touches', 'intimate', 'fact', 'comprehend', 'dramatic', 'inkling', 'nuance', 'activist', 'evaluate', 'actuality', 'indeed', 'perhaps', 'felt', 'inarguable', 'altogether', 'extensively', 'assess', 'certainly', 'baby', 'anyhow', 'thus', 'aha', 'ought', 'emotion', 'stir', 'conjecture', 'splayed-finger', 'allusion', 'mum', 'feels', 'actual', 'insights', 'hmm', 'mm', 'deeply', 'tint', 'need', 'accentuate', 'anyways', 'orthodoxy', 'cogitate', 'inherent', 'soliloquize', 'irregardless', 'astronomically', 'anyway', 'astronomic', 'must', 'embodiment', 'thusly', 'awareness', 'utterances', 'considerably', 'contemplate', 'really', 'lastly', 'pray', 'allusions', 'elaborate', 'exact', 'scrutinize', 'consequently', 'philosophize', 'nuances', 'nevertheless', 'dramatically', 'imperatively', 'reflective', 'immediately', 'adolescents', 'believe', 'affected', 'needfully', 'besides', 'knew', 'glean', 'yeah', 'screamingly', 'thinking', 'entirely', 'suppose', 'views', 'alliances', 'alliance', 'perceptions', 'limitless', 'screaming', 'infer', 'disposition', 'belief', 'view', 'finally', 'tantamount', 'moreover', 'maybe', 'inarguably', 'regardlessly', 'cognizant', 'immensurable', 'supposing', 'though', 'foretell', 'regard', 'revelatory', 'discern', 'hm', 'mentality', 'entrenchment', 'furthermore', 'forsee', 'absolutely', 'exactly', 'feeling', 'feel', 'imply', 'think', 'facts', 'likewise', 'actually', 'regardless', 'metaphorize', 'rather', 'imagination', 'imagine', 'prophesy', 'opinion', 'knowingly', 'allegorize', 'reflecting', 'frankly', 'inklings', 'outright', 'attitude', 'astronomical', 'viewpoints'}}


SPECIALSYLLABLES_EN = """tottered 2
chummed 1
peeped 1
moustaches 2
shamefully 3
messieurs 2
satiated 4
sailmaker 4
sheered 1
disinterred 3
propitiatory 6
bepatched 2
particularized 5
caressed 2
trespassed 2
sepulchre 3
flapped 1
hemispheres 3
pencilled 2
motioned 2
poleman 2
slandered 2
sombre 2
etc 4
sidespring 2
mimes 1
effaces 2
mr 2
mrs 2
ms 1
dr 2
st 1
sr 2
jr 2
truckle 2
foamed 1
fringed 2
clattered 2
capered 2
mangroves 2
suavely 2
reclined 2
brutes 1
effaced 2
quivered 2
h'm 1
veriest 3
sententiously 4
deafened 2
manoeuvred 3
unstained 2
gaped 1
stammered 2
shivered 2
discoloured 3
gravesend 2
60 2
lb 1
unexpressed 3
greyish 2
unostentatious 5
"""

FALLBACK_CACHE = {}

FALLBACK_SUBSYL = ["cial", "tia", "cius", "cious", "gui", "ion", "iou",
                   "sia$", ".ely$"]

FALLBACK_ADDSYL = ["ia", "riet", "dien", "iu", "io", "ii",
                   "[aeiouy]bl$", "mbl$",
                   "[aeiou]{3}",
                   "^mc", "ism$",
                   "(.)(?!\\1)([aeiouy])\\2l$",
                   "[^l]llien",
                   "^coad.", "^coag.", "^coal.", "^coax.",
                   "(.)(?!\\1)[gq]ua(.)(?!\\2)[aeiou]",
                   "dnt$"]


MORAL_FOUNDATION_DICT = {'HarmVirtue': ['safe', 'peace', 'compassion', 'empath', 'sympath', 'care', 'caring', 'protect', 'shield', 'shelter', 'amity', 'secur', 'benefit', 'defen', 'guard', 'preserve'], 'HarmVice': ['harm', 'suffer', 'war', 'wars', 'warl', 'warring', 'fight', 'violen', 'hurt', 'kill', 'kills', 'killer', 'killed', 'killing', 'endanger', 'cruel', 'brutal', 'abuse', 'damag', 'ruin', 'ravage', 'detriment', 'crush', 'attack', 'annihilate', 'destroy', 'stomp', 'abandon', 'spurn', 'impair', 'exploit', 'exploits', 'exploited', 'exploiting', 'wound'], 'FairnessVirtue': ['fair', 'fairly', 'fairness', 'fair-', 'fairmind', 'fairplay', 'equal', 'justice', 'justness', 'justifi', 'reciproc', 'impartial', 'egalitar', 'rights', 'equity', 'evenness', 'equivalent', 'unbias', 'tolerant', 'equable', 'balance', 'homologous', 'unprejudice', 'reasonable', 'constant', 'honest'], 'FairnessVice': ['unfair', 'unequal', 'bias', 'unjust', 'injust', 'bigot', 'discriminat', 'disproportion', 'inequitable', 'prejud', 'dishonest', 'unscrupulous', 'dissociate', 'preference', 'favoritism', 'segregat', 'exclusion', 'exclud'], 'IngroupVirtue': ['segregat', 'together', 'nation', 'homeland', 'family', 'families', 'familial', 'group', 'loyal', 'patriot', 'communal', 'commune', 'communit', 'communis', 'comrad', 'cadre', 'collectiv', 'joint', 'unison', 'unite', 'fellow', 'guild', 'solidarity', 'devot', 'member', 'cliqu', 'cohort', 'ally', 'insider'], 'IngroupVice': ['abandon', 'foreign', 'enem', 'betray', 'treason', 'traitor', 'treacher', 'disloyal', 'individual', 'apostasy', 'apostate', 'deserted', 'deserter', 'deserting', 'deceiv', 'jilt', 'imposter', 'miscreant', 'spy', 'sequester', 'renegade', 'terroris', 'immigra'], 'AuthorityVirtue': ['preserve', 'loyal', 'obey', 'obedien', 'duty', 'law', 'lawful', 'legal', 'duti', 'honor', 'respect', 'respectful', 'respected', 'respects', 'order', 'father', 'mother', 'motherl', 'mothering', 'mothers', 'tradition', 'hierarch', 'authorit', 'permit', 'permission', 'status', 'rank', 'leader', 'class', 'bourgeoisie', 'caste', 'position', 'complian', 'command', 'supremacy', 'control', 'submi', 'allegian', 'serve', 'abide', 'defere', 'defer', 'revere', 'venerat', 'comply'], 'AuthorityVice': ['betray', 'treason', 'traitor', 'treacher', 'disloyal', 'apostasy', 'apostate', 'deserted', 'deserter', 'deserting', 'defian', 'rebel', 'dissent', 'subver', 'disrespect', 'disobe', 'sediti', 'agitat', 'insubordinat', 'illegal', 'lawless', 'insurgent', 'mutinous', 'defy', 'dissident', 'unfaithful', 'alienate', 'defector', 'heretic', 'nonconformist', 'oppose', 'protest', 'refuse', 'denounce', 'remonstrate', 'riot', 'obstruct'], 'PurityVirtue': ['preserve', 'piety', 'pious', 'purity', 'pure', 'clean', 'steril', 'sacred', 'chast', 'holy', 'holiness', 'saint', 'wholesome', 'celiba', 'abstention', 'virgin', 'virgins', 'virginity', 'virginal', 'austerity', 'integrity', 'modesty', 'abstinen', 'abstemiousness', 'upright', 'limpid', 'unadulterated', 'maiden', 'virtuous', 'refined', 'decen', 'immaculate', 'innocent', 'pristine', 'church'], 'PurityVice': ['ruin', 'exploit', 'exploits', 'exploited', 'exploiting', 'apostasy', 'apostate', 'heretic', 'disgust', 'deprav', 'disease', 'unclean', 'contagio', 'indecen', 'sin', 'sinful', 'sinner', 'sins', 'sinned', 'sinning', 'slut', 'whore', 'dirt', 'impiety', 'impious', 'profan', 'gross', 'repuls', 'sick', 'promiscu', 'lewd', 'adulter', 'debauche', 'defile', 'tramp', 'prostitut', 'unchaste', 'intemperate', 'wanton', 'profligate', 'filth', 'trashy', 'obscen', 'lax', 'taint', 'stain', 'tarnish', 'debase', 'desecrat', 'wicked', 'blemish', 'exploitat', 'pervert', 'wretched'], 'MoralityGeneral': ['honest', 'lawful', 'legal', 'piety', 'pious', 'wholesome', 'integrity', 'upright', 'decen', 'indecen', 'wicked', 'wretched', 'righteous', 'moral', 'ethic', 'value', 'upstanding', 'good', 'goodness', 'principle', 'blameless', 'exemplary', 'lesson', 'canon', 'doctrine', 'noble', 'worth', 'ideal', 'praiseworthy', 'commendable', 'character', 'proper', 'laudable', 'correct', 'wrong', 'evil', 'immoral', 'bad', 'offend', 'offensive', 'transgress']}


class FeatureFunctions(object):
    '''
    Functions for individual features or to support feature groups.
    '''
    # Constructor
    def __init__(self):
        # Compile our regular expressions
        for i in range(len(FALLBACK_SUBSYL)):
            FALLBACK_SUBSYL[i] = re.compile(FALLBACK_SUBSYL[i])
        for i in range(len(FALLBACK_ADDSYL)):
            FALLBACK_ADDSYL[i] = re.compile(FALLBACK_ADDSYL[i])

        # Read our syllable override file and stash that info in the cache
        for line in SPECIALSYLLABLES_EN.splitlines():
            line = line.strip()
            if line:
                toks = line.split()
                assert len(toks) == 2
                FALLBACK_CACHE[self._normalize_word(toks[0])] = int(toks[1])

    # Helper Functions
    def _normalize_word(self, word):
        return word.strip().lower()

    def get_filtered_words(self, tokens):
        special_chars = list(string.punctuation)
        filtered_words = []
        for tok in tokens:
            if tok in special_chars or tok == " ":
                continue
            else:
                new_word = "".join([c for c in tok if c not in special_chars])
                if new_word == "" or new_word == " ":
                    continue
                filtered_words.append(new_word)
        return filtered_words

    # Style Functions
    def POS_counts(self, words):
        pos_tags = ["CC", "CD", "DT", "EX", "FW", "IN", "JJ", "JJR", "JJS", "LS", "MD", "NN", "NNS", "NNP", "NNPS", "PDT",
					"POS", "PRP", "PRP$", "RB", "RBR", "RBS", "RP", "SYM", "TO", "UH", "WP$", "WRB", "VB", "VBD", "VBG",
					"VBN", "VBP", "VBZ", "WDT", "WP", "$", "''", "(", ")", ",", "--", ".", ":", "``"]
        tag_to_count = {t:0 for t in pos_tags} # init dict
        tagged_words = pos_tag(words)
        for word,tag in tagged_words: #count tags
            tag_to_count[tag] += 1
        tag_to_count_norm = {t:float(n)/len(words) for (t,n) in tag_to_count.items()} #normalize counts by num words in article
        return tag_to_count_norm

    def puncs_caps_stops(self, tokens):
        puncs = set(string.punctuation)
        quotes = float((tokens.count("\"") + tokens.count('``') + tokens.count("''"))) / len(tokens)
        exclaim = float(tokens.count("!")) / len(tokens)
        allpunc = 0
        for p in puncs:
        	allpunc += tokens.count(p)
        allpunc = float(allpunc) /  len(tokens)
        words_upper = 0
        words_upper = sum([1 for w in tokens if w.isupper()])
        allcaps = float(words_upper) / len(tokens)
        stopwords_eng = set(stopwords.words('english'))
        stops = float(len([s for s in tokens if s in stopwords_eng]))/len(tokens)
        return quotes, exclaim, allpunc, allcaps, stops

    # Complexity Functions
    def ttr(self, words):
        dif_words = len(set(words))
        tot_words = len(words)
        ttr = (float(dif_words) / tot_words)
        return ttr

    def count_syllables(self, word):
        word = self._normalize_word(word)
        if not word:
            return 0
        # Check for a cached syllable count
        count = FALLBACK_CACHE.get(word, -1)
        if count > 0:
            return count
        # Remove final silent 'e'
        if word[-1] == "e":
            word = word[:-1]
        # Count vowel groups
        count = 0
        prev_was_vowel = 0
        for c in word:
            is_vowel = c in ("a", "e", "i", "o", "u", "y")
            if is_vowel and not prev_was_vowel:
                count += 1
            prev_was_vowel = is_vowel
        # Add & subtract syllables
        for r in FALLBACK_ADDSYL:
            if r.search(word):
                count += 1
        for r in FALLBACK_SUBSYL:
            if r.search(word):
                count -= 1
        # Cache the syllable count
        FALLBACK_CACHE[word] = count
        return count

    def count_complex_words(self, tokens, sentences):
        words = tokens
        complex_words = 0
        found = False
        cur_word = []
        for word in words:
            if self.count_syllables(word)>= 3:
                #Checking proper nouns. If a word starts with a capital letter
                #and is NOT at the beginning of a sentence we don't add it
                #as a complex word.
                if not(word[0].isupper()):
                    complex_words += 1
                else:
                    for sentence in sentences:
                        if str(sentence).startswith(word):
                            found = True
                            break
                    if found:
                        complex_words += 1
                        found = False
        return complex_words

    def flesch_kincaid_grade_level(self, text, words, sentences):
        score = 0.0
        word_count = len(words)
        sentence_count = len(sentences)
        avg_words_p_sentence = word_count/sentence_count
        syllableCount = 0
        for word in words:
            syllableCount += self.count_syllables(word)
        if word_count > 0.0:
            score = 0.39 * (avg_words_p_sentence + 11.8 * (syllableCount/word_count)) - 15.59
        rounded_score = round(score, 4)
        return rounded_score

    def smog_index(self, text, words, sentences):
        score = 0.0
        word_count = len(words)
        sentence_count = len(sentences)
        complex_word_count = self.count_complex_words(words, sentences)
        if word_count > 0.0:
            score = (math.sqrt(complex_word_count*(30/sentence_count)) + 3)
        return score

    def coleman_liau_index(self, text, words, sentences):
        score = 0.0
        word_count = len(words)
        sentence_count = len(sentences)
        characters = 0
        for word in words:
            characters += len(word)
        if word_count > 0.0:
            score = (5.89*(characters/word_count))-(30*(sentence_count/word_count))-15.8
        rounded_score = round(score, 4)
        return rounded_score

    def lix(self, text, words, sentences):
        longwords = 0.0
        score = 0.0
        word_count = len(words)
        sentence_count = len(sentences)
        if word_count > 0.0:
            for word in words:
                if len(word) >= 7:
                    longwords += 1.0
            score = word_count / sentence_count + float(100 * longwords) / word_count
        return score

    # Affect Functions
    def vadersent(self, text): #dependent on vaderSentiment
        analyzer = SentimentIntensityAnalyzer()
        vs = analyzer.polarity_scores(text)
        return vs['neg'], vs['neu'], vs['pos']

    def acl_affect(self, words):
        wneg_count = float(sum([words.count(n) for n in ACL13_DICT['wneg']])) / len(words)
        wpos_count = float(sum([words.count(n) for n in ACL13_DICT['wpos']])) / len(words)
        wneu_count = float(sum([words.count(n) for n in ACL13_DICT['wneu']])) / len(words)
        sneg_count = float(sum([words.count(n) for n in ACL13_DICT['sneg']])) / len(words)
        spos_count = float(sum([words.count(n) for n in ACL13_DICT['spos']])) / len(words)
        sneu_count = float(sum([words.count(n) for n in ACL13_DICT['sneu']])) / len(words)
        return wneg_count, wpos_count, wneu_count, sneg_count, spos_count, sneu_count

    # Bias Functions
    def bias_words(self, words):
        bigrams = [" ".join(bg) for bg in ngrams(words, 2)]
        trigrams = [" ".join(tg) for tg in ngrams(words, 3)]
        bias = float(sum([words.count(b) for b in ACL13_DICT['bias_words']])) / len(words)
        assertatives = float(sum([words.count(a) for a in ACL13_DICT['assertatives']])) / len(words)
        factives = float(sum([words.count(f) for f in ACL13_DICT['factives']])) / len(words)
        hedges = sum([words.count(h) for h in ACL13_DICT['hedges']]) + \
            sum([bigrams.count(h) for h in ACL13_DICT['hedges']]) + \
            sum([trigrams.count(h) for h in ACL13_DICT['hedges']])
        hedges = float(hedges) / len(words)
        implicatives = float(sum([words.count(i) for i in ACL13_DICT['implicatives']])) / len(words)
        report_verbs = float(sum([words.count(r) for r in ACL13_DICT['report_verbs']])) / len(words)
        positive_op = float(sum([words.count(p) for p in ACL13_DICT['positive']])) / len(words)
        negative_op = float(sum([words.count(n) for n in ACL13_DICT['negative']])) / len(words)
        return bias, assertatives, factives, hedges, implicatives, report_verbs, positive_op, negative_op

    # Moral Functions
    def moral_foundations(self, words):
        foundation_counts_norm = {}
        stemmer = PorterStemmer()
        stemmed_tokens = [stemmer.stem(t) for t in words]
        for key in MORAL_FOUNDATION_DICT.keys():
        	foundation_counts_norm[key] = float(sum([stemmed_tokens.count(i) for i in MORAL_FOUNDATION_DICT[key]])) / len(words)
        return foundation_counts_norm

    # Event functions
    def get_continuous_NE_chunks(self, tokens):
        chunked = ne_chunk(pos_tag(tokens))
        continuous_chunk = []
        current_chunk = []
        for i in chunked:
         if hasattr(i, 'label'):
             if i.label() == 'GPE' or i.label() == 'LOC':
                 if type(i) == Tree:
                         current_chunk.append(" ".join([token for token, pos in i.leaves()]))
                 elif current_chunk:
                    named_entity = " ".join(current_chunk)
                    if named_entity not in continuous_chunk:
                        continuous_chunk.append(named_entity)
                        current_chunk = []
                 else:
                    continue
        norm_number_gpe_and_loc = float(len(continuous_chunk))/len(tokens)
        return norm_number_gpe_and_loc

    def count_dates(self, text, words):
        matches = list(datefinder.find_dates(text))
        norm_num_dates = float(len(matches))/len(words)
        return norm_num_dates

class NELAFeatureExtractor(object):
    '''
    Extract NELA features by group or all.
    '''
    # Constructor
    def __init__(self):
        self.Functions = FeatureFunctions()

    def extract_style(self, text, tokens=None, words=None):
        if tokens == None:
            tokens = word_tokenize(text)
        if words == None:
            words = self.Functions.get_filtered_words(tokens)
        quotes, exclaim, allpunc, allcaps, stops = self.Functions.puncs_caps_stops(tokens)
        normed_POS_count_dict = self.Functions.POS_counts(words)

        #build final vector and final names
        names = ['quotes', 'exclaim', 'allpunc', 'allcaps', 'stops']
        vect = [quotes, exclaim, allpunc, allcaps, stops]
        for (k,v) in normed_POS_count_dict.items():
            names.append(k)
            vect.append(v)
        return vect, names

    def extract_complexity(self, text, tokens=None, sentences=None, words=None):
        if tokens == None:
            tokens = word_tokenize(text)
        if sentences == None:
            sentences = sent_tokenize(text)
        if words == None:
            words = self.Functions.get_filtered_words(tokens)
        ttr = self.Functions.ttr(words)
        avg_wordlen = float(sum([len(w) for w in words]))/len(words)
        wc = len(words)
        fkgl = self.Functions.flesch_kincaid_grade_level(text, words, sentences)
        smog = self.Functions.smog_index(text, words, sentences)
        cli = self.Functions.coleman_liau_index(text, words, sentences)
        lix = self.Functions.lix(text, words, sentences)

        #build final vector and final names
        names = ['ttr', 'avg_wordlen', 'word_count',
            'flesch_kincaid_grade_level', 'smog_index', 'coleman_liau_index',
            'lix']
        vect = [ttr, avg_wordlen, wc, fkgl, smog, cli, lix]
        return vect, names

    def extract_bias(self, text, tokens=None, words=None):
        if tokens == None:
            tokens = word_tokenize(text)
        if words == None:
            words = self.Functions.get_filtered_words(tokens)
        words = self.Functions.get_filtered_words(tokens)
        bias, assertatives, factives, hedges, implicatives, report_verbs, \
            positive_op, negative_op = self.Functions.bias_words(words)

        #build final vector and final names
        names = ['bias_words', 'assertatives', 'factives', 'hedges',
            'implicatives', 'report_verbs', 'positive_opinion_words',
            'negative_opinion_words']
        vect = [bias, assertatives, factives, hedges, implicatives, report_verbs,
            positive_op, negative_op]
        return vect, names

    def extract_affect(self, text, tokens=None, words=None):
        if tokens == None:
            tokens = word_tokenize(text)
        if words == None:
            words = self.Functions.get_filtered_words(tokens)
        vadneg, vadneu, vadpos = self.Functions.vadersent(text)
        wneg, wpos, wneu, sneg, spos, sneu = self.Functions.acl_affect(words)

        #build final vector and final names
        names = ['vadneg', 'vadneu', 'vadpos', 'wneg', 'wpos', 'wneu', 'sneg',
        'spos', 'sneu']
        vect = [vadneg, vadneu, vadpos, wneg, wpos, wneu, sneg, spos, sneu]
        return vect, names

    def extract_moral(self, text, words=None):
        if words == None:
            tokens = word_tokenize(text)
            words = self.Functions.get_filtered_words(tokens)
        normed_moral_count_dict = self.Functions.moral_foundations(words)

        #build final vector and final names
        names = list(normed_moral_count_dict.keys())
        vect = list(normed_moral_count_dict.values())
        return vect, names

    def extract_event(self, text, tokens=None, words=None):
        names = []
        if tokens == None:
            tokens = word_tokenize(text)
        if words == None:
            words = self.Functions.get_filtered_words(tokens)
        percent_GPE_and_LOC = self.Functions.get_continuous_NE_chunks(tokens)
        percent_dates = self.Functions.count_dates(text, words)

        #build final vector and final names
        names = ['num_locations', 'num_dates']
        vect = [percent_GPE_and_LOC, percent_dates]
        return vect, names

    def extract_all(self, text):
        '''
        Compute each feature group, merge computed vectors and feature names for
        each vector. The names list can be used to create headers in a csv or a db.
        '''
        # Pretokenize to speed up, compute LIWC before hand to speed up
        tokens = word_tokenize(text)
        sentences = sent_tokenize(text)
        words = self.Functions.get_filtered_words(tokens)

        # Get each feature group
        svect, snames = self.extract_style(text, tokens)
        cvect, cnames = self.extract_complexity(text, tokens, sentences)
        bvect, bnames = self.extract_bias(text, tokens)
        avect, anames = self.extract_affect(text, tokens, words)
        mvect, mnames = self.extract_moral(text, tokens)
        evect, enames = self.extract_event(text, tokens, words)

        # Produce final vector and names
        computed_vectors = [svect, cvect, bvect, avect, mvect, evect]
        extracted_names = [snames, cnames, bnames, anames, mnames, enames]
        vect = [item for sublist in computed_vectors for item in sublist]
        names = [item for sublist in extracted_names for item in sublist]
        return vect, names

if __name__ == "__main__":
    '''
    Example text and functions below
    '''
    newsarticle = "Ireland Expected To Become World's First Country To Divest \
    From Fossil Fuels The Republic of Ireland took a crucial step Thursday \
    toward becoming the first country in the world to divest from fossil fuels.\
    Lawmakers in the Dail, the lower house of parliament, advanced a bill \
    requiring the Irish government's more than $10 billion national investment \
    fund to sell off stakes in coal, oil, gas and peat  and to do so \
    \"as soon as practicable.\"The bill now heads to the upper chamber, \
    known as Seanad, where it is expected to pass easily when it's taken up, \
    likely in September."

    nela = NELAFeatureExtractor()

    #extract by group
    #feature_vector, feature_names = nela.extract_style(newsarticle) # <--- tested
    #feature_vector, feature_names = nela.extract_complexity(newsarticle) # <--- tested
    #feature_vector, feature_names = nela.extract_bias(newsarticle) # <--- tested
    #feature_vector, feature_names = nela.extract_affect(newsarticle) # <--- tested
    #feature_vector, feature_names = nela.extract_moral(newsarticle) # <--- tested
    #feature_vector, feature_names = nela.extract_event(newsarticle) # <--- tested

    #extract all groups
    feature_vector, feature_names = nela.extract_all(newsarticle) # <--- tested

    print(feature_vector, feature_names)
